Module component_prelude

Module component_prelude 

Structs

ComponentId

Enums

ComponentScope
ComponentStatus
The ready status of this component.

Traits

Component
Implement this trait to define a UI component. This will allow you to derive RegisterComponent on it, in turn allowing you to preview the contents of the preview fn in workspace: open component preview.
Documented
Adds an associated constant DOCS on your type containing its documentation, allowing you to access its documentation at runtime.

Functions

example_group
example_group_with_title
single_example

Derive Macros

Documented
Derive proc-macro for Documented trait.
RegisterComponent
Registers components that implement the Component trait.