format_point_value

Function format_point_value 

pub fn format_point_value(value: f64) -> String
Format a point value without hiding precision behind a fixed six-place decimal display. Scientific notation is used for values that would be difficult to read accurately in the status bar.