pub enum Color {
Show 25 variants
Default,
Accent,
Conflict,
Created,
Custom(Hsla),
Debugger,
Deleted,
Disabled,
Error,
Hidden,
Hint,
Ignored,
Info,
Modified,
Muted,
Placeholder,
Player(u32),
Selected,
Success,
VersionControlAdded,
VersionControlConflict,
VersionControlDeleted,
VersionControlIgnored,
VersionControlModified,
Warning,
}Expand description
Sets a color that has a consistent meaning across all themes.
Variants
Default
The default text color. Might be known as “foreground” or “primary” in some theme systems.
For less emphasis, consider using Color::Muted or Color::Hidden.
Accent
A text color used for accents, such as links or highlights.
Conflict
A color used to indicate a conflict, such as a version control merge conflict, or a conflict between a file in the editor and the file system.
Created
A color used to indicate a newly created item, such as a new file in version control, or a new file on disk.
Custom(Hsla)
It is highly, HIGHLY recommended not to use this! Using this color means detaching it from any semantic meaning across themes.
A custom color specified by an HSLA value.
Debugger
A color used for all debugger UI elements.
Deleted
A color used to indicate a deleted item, such as a file removed from version control.
Disabled
A color used for disabled UI elements or text, like a disabled button or menu item.
Error
A color used to indicate an error condition, or something the user cannot do. In very rare cases, it might be used to indicate dangerous or destructive action.
Hidden
A color used for elements that represent something that is hidden, like a hidden file, or an element that should be visually de-emphasized.
Hint
A color used for hint or suggestion text, often a blue color. Use this color to represent helpful, or semantically neutral information.
Ignored
A color used for items that are intentionally ignored, such as files ignored by version control.
Info
A color used for informational messages or status indicators, often a blue color.
Modified
A color used to indicate a modified item, such as an edited file, or a modified entry in version control.
Muted
A color used for text or UI elements that should be visually muted or de-emphasized.
For more emphasis, consider using Color::Default.
For less emphasis, consider using Color::Hidden.
Placeholder
A color used for placeholder text in input fields.
Player(u32)
A color associated with a specific player number.
Selected
A color used to indicate selected text or UI elements.
Success
A color used to indicate a successful operation or status.
VersionControlAdded
A version control color used to indicate a newly added file or content in version control.
VersionControlConflict
A version control color used to indicate conflicting changes that need resolution.
VersionControlDeleted
A version control color used to indicate a file or content that has been deleted in version control.
VersionControlIgnored
A version control color used to indicate files or content that is being ignored by version control.
VersionControlModified
A version control color used to indicate modified files or content in version control.
Warning
A color used to indicate a warning condition.
Implementations