pub enum ColumnWidthConfig {
Static {
widths: StaticColumnWidths,
table_width: Option<DefiniteLength>,
},
Redistributable {
columns_state: Entity<RedistributableColumnsState>,
table_width: Option<DefiniteLength>,
},
Resizable(Entity<ResizableColumnsState>),
}Variants
Static
Static column widths (no resize handles).
Fields

widths: StaticColumnWidths
table_width: Option<DefiniteLength>Controls widths of the whole table.
Redistributable
Redistributable columns — dragging redistributes the fixed available space among columns without changing the overall table width.
Resizable(Entity<ResizableColumnsState>)
Independently resizable columns — dragging changes absolute column widths and thus the overall table width. Like spreadsheets.
Implementations
Sourceimpl ColumnWidthConfig
impl ColumnWidthConfig
Sourcepub fn redistributable(
columns_state: Entity<RedistributableColumnsState>,
) -> Self
pub fn redistributable( columns_state: Entity<RedistributableColumnsState>, ) -> Self
Redistributable columns with no fixed table width.
Sourcepub fn auto_with_table_width(width: impl Into<DefiniteLength>) -> Self
pub fn auto_with_table_width(width: impl Into<DefiniteLength>) -> Self
Auto-width columns, fixed table width.
Sourcepub fn explicit<T: Into<DefiniteLength>>(widths: Vec<T>) -> Self
pub fn explicit<T: Into<DefiniteLength>>(widths: Vec<T>) -> Self
Explicit column widths with no fixed table width.
Sourcepub fn widths_to_render(&self, cx: &App) -> Option<TableRow<Length>>
pub fn widths_to_render(&self, cx: &App) -> Option<TableRow<Length>>
Column widths for rendering.
Sourcepub fn list_horizontal_sizing(
&self,
window: &Window,
cx: &App,
) -> ListHorizontalSizingBehavior
pub fn list_horizontal_sizing( &self, window: &Window, cx: &App, ) -> ListHorizontalSizingBehavior
ListHorizontalSizingBehavior for uniform_list.