pub enum DynamicSpacing {
Show 14 variants
Base00,
Base01,
Base02,
Base03,
Base04,
Base06,
Base08,
Base12,
Base16,
Base20,
Base24,
Base32,
Base40,
Base48,
}Expand description
A dynamic spacing system that adjusts spacing based on UiDensity.
The number following “Base” refers to the base pixel size at the default rem size and spacing settings.
When possible, DynamicSpacing should be used over manual or built-in spacing values in places dynamic spacing is needed.
Variants
Base00
0px|0px|0px (@16px/rem) - Scales with the user’s rem size.
Base01
1px|1px|2px (@16px/rem) - Scales with the user’s rem size.
Base02
1px|2px|4px (@16px/rem) - Scales with the user’s rem size.
Base03
2px|3px|4px (@16px/rem) - Scales with the user’s rem size.
Base04
2px|4px|6px (@16px/rem) - Scales with the user’s rem size.
Base06
3px|6px|8px (@16px/rem) - Scales with the user’s rem size.
Base08
4px|8px|10px (@16px/rem) - Scales with the user’s rem size.
Base12
10px|12px|14px (@16px/rem) - Scales with the user’s rem size.
Base16
14px|16px|18px (@16px/rem) - Scales with the user’s rem size.
Base20
18px|20px|22px (@16px/rem) - Scales with the user’s rem size.
Base24
20px|24px|28px (@16px/rem) - Scales with the user’s rem size.
Base32
28px|32px|36px (@16px/rem) - Scales with the user’s rem size.
Base40
36px|40px|44px (@16px/rem) - Scales with the user’s rem size.
Base48
44px|48px|52px (@16px/rem) - Scales with the user’s rem size.
Implementations