ElevationIndex

Enum ElevationIndex 

pub enum ElevationIndex {
    Background,
    Surface,
    EditorSurface,
    ElevatedSurface,
    ModalSurface,
}
Today, elevation is primarily used to add shadows to elements, and set the correct background for elements like buttons.

Elevation can be thought of as the physical closeness of an element to the user. Elements with lower elevations are physically further away on the z-axis and appear to be underneath elements with higher elevations.

In the future, a more complete approach to elevation may be added.

Variants



Background

On the layer of the app background. This is under panels, panes, and other surfaces.



Surface

The primary surface – Contains panels, panes, containers, etc.



EditorSurface

The same elevation as the primary surface, but used for the editable areas, like buffers



ElevatedSurface

A surface that is elevated above the primary surface. but below washes, models, and dragged elements.



ModalSurface

A surface above the ElevationIndex::ElevatedSurface that is used for dialogs, alerts, modals, etc.

Implementations

Source

impl ElevationIndex

pub fn shadow(self, cx: &App) -> Vec<BoxShadow>

Returns an appropriate shadow for the given elevation index.

pub fn bg(&self, cx: &mut App) -> Hsla

Returns the background color for the given elevation index.

pub fn on_elevation_bg(&self, cx: &App) -> Hsla

Returns a color that is appropriate a filled element on this elevation

pub fn darker_bg(&self, cx: &App) -> Hsla

Attempts to return a darker background color than the current elevation index’s background.

If the current background color is already dark, it will return a lighter color instead.