pub enum TextSize {
Default,
Large,
Small,
XSmall,
Ui,
Editor,
}Expand description
A utility for getting the size of various semantic text sizes.
Variants
Default
The default size for UI text.
0.825rem or 14px at the default scale of 1rem = 16px.
Note: The absolute size of this text will change based on a user’s ui_scale setting.
Large
The large size for UI text.
1rem or 16px at the default scale of 1rem = 16px.
Note: The absolute size of this text will change based on a user’s ui_scale setting.
Small
The small size for UI text.
0.75rem or 12px at the default scale of 1rem = 16px.
Note: The absolute size of this text will change based on a user’s ui_scale setting.
XSmall
The extra small size for UI text.
0.625rem or 10px at the default scale of 1rem = 16px.
Note: The absolute size of this text will change based on a user’s ui_scale setting.
Ui
The ui_font_size set by the user.
Editor
The buffer_font_size set by the user.
Implementations