pub enum ToggleStyle {
Ghost,
ElevationBased(ElevationIndex),
Custom(Hsla),
}Expand description
The visual style of a toggle.
Variants
Ghost
Toggle has a transparent background
ElevationBased(ElevationIndex)
Toggle has a filled background based on the elevation index of the parent container
Custom(Hsla)
A custom style using a color to tint the toggle