pub fn level_at(section: &LevelSection, row: u16) -> Option<usize>Expand description
Level index drawn at absolute terminal row, if that row is a list row.
pub fn level_at(section: &LevelSection, row: u16) -> Option<usize>Level index drawn at absolute terminal row, if that row is a list row.