pub fn items_at<'a>(items: &'a [Item], path: &[usize]) -> Option<&'a [Item]>Expand description
The menu path opens into: items itself for an empty path, else the rows
of the submenu each index names. None as soon as one of them does not name
an open-able submenu.