pub fn error_row(theme: &Theme, message: impl Into<SharedString>) -> DivExpand description
Inline error row + Retry affordance (the caller attaches the listener to the returned id).
pub fn error_row(theme: &Theme, message: impl Into<SharedString>) -> DivInline error row + Retry affordance (the caller attaches the listener to the returned id).