pub enum AbsoluteLength {
Pixels(Pixels),
Rems(Rems),
}Expand description
Represents an absolute length in pixels or rems.
AbsoluteLength can be either a fixed number of pixels, which is an absolute measurement not
affected by the current font size, or a number of rems, which is relative to the font size of
the root element. It is used for specifying dimensions that are either independent of or
related to the typographic scale.
Variants
Implementations
Sourceimpl AbsoluteLength
impl AbsoluteLength
Sourcepub fn to_pixels(self, rem_size: Pixels) -> Pixels
pub fn to_pixels(self, rem_size: Pixels) -> Pixels
Converts an AbsoluteLength to Pixels based on a given rem_size.
Arguments
rem_size- The size of one rem in pixels.
Returns
Returns the AbsoluteLength as Pixels.
Examples
let length_in_pixels = AbsoluteLength::Pixels(Pixels::from(42.0));
let length_in_rems = AbsoluteLength::Rems(Rems(2.0));
let rem_size = Pixels::from(16.0);
assert_eq!(length_in_pixels.to_pixels(rem_size), Pixels::from(42.0));
assert_eq!(length_in_rems.to_pixels(rem_size), Pixels::from(32.0));Trait Implementations
Sourceimpl Clone for AbsoluteLength
impl Clone for AbsoluteLength
Sourcefn clone(&self) -> AbsoluteLength
fn clone(&self) -> AbsoluteLength
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AbsoluteLength
Sourceimpl Debug for AbsoluteLength
impl Debug for AbsoluteLength
Sourceimpl Default for AbsoluteLength
impl Default for AbsoluteLength
Sourcefn default() -> AbsoluteLength
fn default() -> AbsoluteLength
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AbsoluteLength
impl<'de> Deserialize<'de> for AbsoluteLength
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<AbsoluteLength, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<AbsoluteLength, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for AbsoluteLength
impl Display for AbsoluteLength
Sourceimpl From<AbsoluteLength> for DefiniteLength
impl From<AbsoluteLength> for DefiniteLength
Sourcefn from(length: AbsoluteLength) -> DefiniteLength
fn from(length: AbsoluteLength) -> DefiniteLength
Converts to this type from the input type.
Sourceimpl From<Pixels> for AbsoluteLength
impl From<Pixels> for AbsoluteLength
Sourcefn from(pixels: Pixels) -> AbsoluteLength
fn from(pixels: Pixels) -> AbsoluteLength
Converts to this type from the input type.
Sourceimpl From<Rems> for AbsoluteLength
impl From<Rems> for AbsoluteLength
Sourcefn from(rems: Rems) -> AbsoluteLength
fn from(rems: Rems) -> AbsoluteLength
Converts to this type from the input type.
Sourceimpl IsZero for AbsoluteLength
impl IsZero for AbsoluteLength
Sourceimpl JsonSchema for AbsoluteLength
impl JsonSchema for AbsoluteLength
Sourcefn json_schema(_generator: &mut SchemaGenerator) -> Schema
fn json_schema(_generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Neg for AbsoluteLength
impl Neg for AbsoluteLength
Sourcetype Output = AbsoluteLength
type Output = AbsoluteLength
The resulting type after applying the
- operator.Sourcefn neg(self) -> AbsoluteLength
fn neg(self) -> AbsoluteLength
Performs the unary
- operation. Read moreSourceimpl PartialEq for AbsoluteLength
impl PartialEq for AbsoluteLength
Sourcefn eq(&self, other: &AbsoluteLength) -> bool
fn eq(&self, other: &AbsoluteLength) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AbsoluteLength
impl Serialize for AbsoluteLength
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AbsoluteLength