pub enum DefiniteLength {
Absolute(AbsoluteLength),
Fraction(f32),
}Expand description
A non-auto length that can be defined in pixels, rems, or percent of parent.
This enum represents lengths that have a specific value, as opposed to lengths that are automatically determined by the context. It includes absolute lengths in pixels or rems, and relative lengths as a fraction of the parent’s size.
Variants
Absolute(AbsoluteLength)
An absolute length specified in pixels or rems.
Fraction(f32)
A relative length specified as a fraction of the parent’s size, between 0 and 1.
Implementations
Sourceimpl DefiniteLength
impl DefiniteLength
Sourcepub fn to_pixels(self, base_size: AbsoluteLength, rem_size: Pixels) -> Pixels
pub fn to_pixels(self, base_size: AbsoluteLength, rem_size: Pixels) -> Pixels
Converts the DefiniteLength to Pixels based on a given base_size and rem_size.
If the DefiniteLength is an absolute length, it will be directly converted to Pixels.
If it is a fraction, the fraction will be multiplied by the base_size to get the length in pixels.
Arguments
base_size- The base size inAbsoluteLengthto which the fraction will be applied.rem_size- The size of one rem in pixels, used to convert rems to pixels.
Returns
Returns the DefiniteLength as Pixels.
Examples
let length_in_pixels = DefiniteLength::Absolute(AbsoluteLength::Pixels(px(42.0)));
let length_in_rems = DefiniteLength::Absolute(AbsoluteLength::Rems(rems(2.0)));
let length_as_fraction = DefiniteLength::Fraction(0.5);
let base_size = AbsoluteLength::Pixels(px(100.0));
let rem_size = px(16.0);
assert_eq!(length_in_pixels.to_pixels(base_size, rem_size), Pixels::from(42.0));
assert_eq!(length_in_rems.to_pixels(base_size, rem_size), Pixels::from(32.0));
assert_eq!(length_as_fraction.to_pixels(base_size, rem_size), Pixels::from(50.0));Trait Implementations
Sourceimpl Clone for DefiniteLength
impl Clone for DefiniteLength
Sourcefn clone(&self) -> DefiniteLength
fn clone(&self) -> DefiniteLength
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DefiniteLength
Sourceimpl Debug for DefiniteLength
impl Debug for DefiniteLength
Sourceimpl Default for DefiniteLength
impl Default for DefiniteLength
Sourcefn default() -> DefiniteLength
fn default() -> DefiniteLength
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DefiniteLength
impl<'de> Deserialize<'de> for DefiniteLength
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<DefiniteLength, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<DefiniteLength, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for DefiniteLength
impl Display for DefiniteLength
Sourceimpl From<AbsoluteLength> for DefiniteLength
impl From<AbsoluteLength> for DefiniteLength
Sourcefn from(length: AbsoluteLength) -> DefiniteLength
fn from(length: AbsoluteLength) -> DefiniteLength
Converts to this type from the input type.
Sourceimpl From<Pixels> for DefiniteLength
impl From<Pixels> for DefiniteLength
Sourcefn from(pixels: Pixels) -> DefiniteLength
fn from(pixels: Pixels) -> DefiniteLength
Converts to this type from the input type.
Sourceimpl From<Rems> for DefiniteLength
impl From<Rems> for DefiniteLength
Sourcefn from(rems: Rems) -> DefiniteLength
fn from(rems: Rems) -> DefiniteLength
Converts to this type from the input type.
Sourceimpl IsZero for DefiniteLength
impl IsZero for DefiniteLength
Sourceimpl JsonSchema for DefiniteLength
impl JsonSchema for DefiniteLength
Sourcefn json_schema(_generator: &mut SchemaGenerator) -> Schema
fn json_schema(_generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Neg for DefiniteLength
impl Neg for DefiniteLength
Sourcetype Output = DefiniteLength
type Output = DefiniteLength
The resulting type after applying the
- operator.Sourcefn neg(self) -> DefiniteLength
fn neg(self) -> DefiniteLength
Performs the unary
- operation. Read moreSourceimpl PartialEq for DefiniteLength
impl PartialEq for DefiniteLength
Sourcefn eq(&self, other: &DefiniteLength) -> bool
fn eq(&self, other: &DefiniteLength) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DefiniteLength
impl Serialize for DefiniteLength
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DefiniteLength