AnyElement

Struct AnyElement 

pub struct AnyElement(/* private fields */);
A dynamically typed element that can be used to store any element type.

Implementations

Source

impl AnyElement

pub fn downcast_mut<T>(&mut self) -> Option<&mut T>
where T: 'static,

Attempt to downcast a reference to the boxed element to a specific type.

pub fn request_layout(&mut self, window: &mut Window, cx: &mut App) -> LayoutId

Request the layout ID of the element stored in this AnyElement. Used for laying out child elements in a parent element.

pub fn prepaint( &mut self, window: &mut Window, cx: &mut App, ) -> Option<FocusHandle>

Prepares the element to be painted by storing its bounds, giving it a chance to draw hitboxes and request autoscroll before the final paint pass is confirmed.

pub fn paint(&mut self, window: &mut Window, cx: &mut App)

Paints the element stored in this AnyElement.

pub fn layout_as_root( &mut self, available_space: Size<AvailableSpace>, window: &mut Window, cx: &mut App, ) -> Size<Pixels>

Performs layout for this element within the given available space and returns its size.

pub fn prepaint_at( &mut self, origin: Point<Pixels>, window: &mut Window, cx: &mut App, ) -> Option<FocusHandle>

Prepaints this element at the given absolute origin. If any element in the subtree beneath this element is focused, its FocusHandle is returned.

pub fn prepaint_as_root( &mut self, origin: Point<Pixels>, available_space: Size<AvailableSpace>, window: &mut Window, cx: &mut App, ) -> Option<FocusHandle>

Performs layout on this element in the available space, then prepaints it at the given absolute origin. If any element in the subtree beneath this element is focused, its FocusHandle is returned.