FixedWidth

Trait FixedWidth 

pub trait FixedWidth {
    // Required methods
    fn width(self, width: impl Into<DefiniteLength>) -> Self;
    fn full_width(self) -> Self;
}
A trait for elements that can have a fixed with. Enables the use of the width and full_width methods.

Required Methods

fn width(self, width: impl Into<DefiniteLength>) -> Self

Sets the width of the element.

fn full_width(self) -> Self

Sets the element’s width to the full width of its container.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors