IntoElement

Trait IntoElement 

pub trait IntoElement: Sized {
    type Element: Element;

    // Required method
    fn into_element(self) -> Self::Element;

    // Provided method
    fn into_any_element(self) -> AnyElement { ... }
}
Implemented by any type that can be converted into an element.

Required Associated Types

type Element: Element

The specific type of element into which the implementing type is converted. Useful for converting other types into elements automatically, like Strings

Required Methods

fn into_element(self) -> Self::Element

Convert self into a type that implements Element.

Provided Methods

fn into_any_element(self) -> AnyElement

Convert self into a dynamically-typed AnyElement.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoElement for &'static str

Source

type Element = &'static str

Source

fn into_element(self) -> <&'static str as IntoElement>::Element

Source

impl IntoElement for Checkbox

Source

impl IntoElement for ComponentExample

Source

impl IntoElement for ComponentExampleGroup

Source

impl IntoElement for CopyButton

Source

impl IntoElement for Cow<'static, str>

Source

impl IntoElement for MarkdownElement

Source

impl IntoElement for String

Implementors

Source

impl IntoElement for ActionPanel

Source

type Element = Component<ActionPanel>

Source

impl IntoElement for AgentMarkdown

Source

type Element = Component<AgentMarkdown>

Source

impl IntoElement for AgentMessageBubble

Source

impl IntoElement for AgentModelSelector

Source

impl IntoElement for AgentSetupButton

Source

impl IntoElement for AgentThreadToolbar

Source

impl IntoElement for AgentThreadView

Source

impl IntoElement for AiSettingItem

Source

type Element = Component<AiSettingItem>

Source

impl IntoElement for Alert

Source

type Element = Component<Alert>

Source

impl IntoElement for AlertDialog

Source

type Element = Component<AlertDialog>

Source

impl IntoElement for AlertModal

Source

type Element = Component<AlertModal>

Source

impl IntoElement for Anchored

Source

impl IntoElement for AnnouncementToast

Source

impl IntoElement for AnyElement

Source

impl IntoElement for AnyIcon

Source

type Element = Component<AnyIcon>

Source

impl IntoElement for AnyView

Source

impl IntoElement for AppShell

Source

type Element = Component<AppShell>

Source

impl IntoElement for AspectRatio

Source

type Element = Component<AspectRatio>

Source

impl IntoElement for Avatar

Source

type Element = Component<Avatar>

Source

impl IntoElement for AvatarAudioStatusIndicator

Source

impl IntoElement for AvatarAvailabilityIndicator

Source

impl IntoElement for Badge

Source

type Element = Component<Badge>

Source

impl IntoElement for Banner

Source

type Element = Component<Banner>

Source

impl IntoElement for Breadcrumb

Source

type Element = Component<Breadcrumb>

Source

impl IntoElement for Button

Source

type Element = Component<Button>

Source

impl IntoElement for ButtonGroup

Source

type Element = Component<ButtonGroup>

Source

impl IntoElement for ButtonLike

Source

type Element = Component<ButtonLike>

Source

type Element = Component<ButtonLink>

Source

impl IntoElement for CalendarPreview

Source

impl IntoElement for Callout

Source

type Element = Component<Callout>

Source

impl IntoElement for Card

Source

type Element = Component<Card>

Source

impl IntoElement for CarouselPreview

Source

impl IntoElement for Chart

Source

type Element = Component<Chart>

Source

impl IntoElement for ui::Checkbox

Source

type Element = Component<Checkbox>

Source

impl IntoElement for Chip

Source

type Element = Component<Chip>

Source

impl IntoElement for CircularProgress

Source

impl IntoElement for CollabNotification

Source

impl IntoElement for ConfiguredApiCard

Source

impl IntoElement for Container

Source

type Element = Component<Container>

Source

impl IntoElement for ui::CopyButton

Source

type Element = Component<CopyButton>

Source

impl IntoElement for CountBadge

Source

type Element = Component<CountBadge>

Source

impl IntoElement for DatePickerPreview

Source

impl IntoElement for DecoratedIcon

Source

type Element = Component<DecoratedIcon>

Source

impl IntoElement for Deferred

Source

impl IntoElement for DescriptionList

Source

impl IntoElement for DiffBlock

Source

type Element = Component<DiffBlock>

Source

impl IntoElement for DiffStat

Source

type Element = Component<DiffStat>

Source

impl IntoElement for Disclosure

Source

type Element = Component<Disclosure>

Source

impl IntoElement for Div

Source

impl IntoElement for Divider

Source

type Element = Component<Divider>

Source

impl IntoElement for Drawer

Source

type Element = Component<Drawer>

Source

impl IntoElement for DropdownMenu

Source

type Element = Component<DropdownMenu>

Source

impl IntoElement for Empty

Source

impl IntoElement for EmptyState

Source

type Element = Component<EmptyState>

Source

impl IntoElement for Facepile

Source

type Element = Component<Facepile>

Source

impl IntoElement for Feed

Source

type Element = Component<Feed>

Source

impl IntoElement for FileInput

Source

type Element = Component<FileInput>

Source

impl IntoElement for Form

Source

type Element = Component<Form>

Source

impl IntoElement for FormField

Source

type Element = Component<FormField>

Source

impl IntoElement for GradientFade

Source

type Element = Component<GradientFade>

Source

impl IntoElement for Headline

Source

type Element = Component<Headline>

Source

impl IntoElement for HighlightedLabel

Source

impl IntoElement for HoverCard

Source

type Element = Component<HoverCard>

Source

impl IntoElement for Icon

Source

type Element = Component<Icon>

Source

impl IntoElement for IconButton

Source

type Element = Component<IconButton>

Source

impl IntoElement for IconDecoration

Source

impl IntoElement for IconWithIndicator

Source

impl IntoElement for ImageCacheElement

Source

impl IntoElement for Img

Source

impl IntoElement for Indicator

Source

type Element = Component<Indicator>

Source

impl IntoElement for InputGroup

Source

type Element = Component<InputGroup>

Source

impl IntoElement for InteractiveText

Source

impl IntoElement for Item

Source

type Element = Component<Item>

Source

impl IntoElement for ItemActions

Source

type Element = Component<ItemActions>

Source

impl IntoElement for ItemContent

Source

type Element = Component<ItemContent>

Source

impl IntoElement for ItemMedia

Source

type Element = Component<ItemMedia>

Source

impl IntoElement for Kbd

Source

type Element = Component<Kbd>

Source

impl IntoElement for KbdGroup

Source

type Element = Component<KbdGroup>

Source

impl IntoElement for Key

Source

type Element = Component<Key>

Source

impl IntoElement for KeyBinding

Source

type Element = Component<KeyBinding>

Source

impl IntoElement for KeyIcon

Source

type Element = Component<KeyIcon>

Source

impl IntoElement for KeybindingHint

Source

impl IntoElement for Label

Source

type Element = Component<Label>

Source

impl IntoElement for LabelLike

Source

type Element = Component<LabelLike>

Source

impl IntoElement for boltz_gpui::elements::list::List

Source

impl IntoElement for ui::List

Source

type Element = Component<List>

Source

impl IntoElement for ListBulletItem

Source

impl IntoElement for ListHeader

Source

type Element = Component<ListHeader>

Source

impl IntoElement for ListItem

Source

type Element = Component<ListItem>

Source

impl IntoElement for ListSeparator

Source

type Element = Component<ListSeparator>

Source

impl IntoElement for ListSubHeader

Source

type Element = Component<ListSubHeader>

Source

impl IntoElement for LoadingLabel

Source

type Element = Component<LoadingLabel>

Source

impl IntoElement for MediaObject

Source

type Element = Component<MediaObject>

Source

impl IntoElement for Modal

Source

type Element = Component<Modal>

Source

impl IntoElement for ModalFooter

Source

type Element = Component<ModalFooter>

Source

impl IntoElement for ModalHeader

Source

type Element = Component<ModalHeader>

Source

impl IntoElement for ModalRow

Source

type Element = Component<ModalRow>

Source

impl IntoElement for ModeSelector

Source

type Element = Component<ModeSelector>

Source

impl IntoElement for Navbar

Source

type Element = Component<Navbar>

Source

impl IntoElement for Navigable

Source

type Element = Component<Navigable>

Source

impl IntoElement for NavigationMenuContent

Source

impl IntoElement for NavigationMenuList

Source

impl IntoElement for NavigationMenuPreview

Source

impl IntoElement for NavigationMenuTrigger

Source

impl IntoElement for NavigationMenuViewport

Source

impl IntoElement for PageHeading

Source

type Element = Component<PageHeading>

Source

impl IntoElement for Pagination

Source

type Element = Component<Pagination>

Source

impl IntoElement for PaneGroupPreview

Source

impl IntoElement for ParallelAgentsIllustration

Source

impl IntoElement for Popover

Source

type Element = Component<Popover>

Source

impl IntoElement for ProfileSelector

Source

impl IntoElement for ProgressBar

Source

type Element = Component<ProgressBar>

Source

impl IntoElement for RadioButton

Source

type Element = Component<RadioButton>

Source

impl IntoElement for ResizableHandle

Source

impl IntoElement for ResizablePanel

Source

impl IntoElement for ResizablePreview

Source

impl IntoElement for Section

Source

type Element = Component<Section>

Source

impl IntoElement for SectionHeader

Source

type Element = Component<SectionHeader>

Source

impl IntoElement for SectionHeading

Source

impl IntoElement for SegmentedControl

Source

impl IntoElement for SharedString

Source

impl IntoElement for Sidebar

Source

type Element = Component<Sidebar>

Source

impl IntoElement for SidebarItem

Source

type Element = Component<SidebarItem>

Source

impl IntoElement for Skeleton

Source

type Element = Component<Skeleton>

Source

impl IntoElement for SonnerStackPreview

Source

impl IntoElement for SonnerToast

Source

type Element = Component<SonnerToast>

Source

impl IntoElement for Spinner

Source

type Element = Component<Spinner>

Source

impl IntoElement for SpinnerLabel

Source

type Element = Component<SpinnerLabel>

Source

impl IntoElement for SplitButton

Source

type Element = Component<SplitButton>

Source

impl IntoElement for StatsCard

Source

type Element = Component<StatsCard>

Source

impl IntoElement for Stepper

Source

type Element = Component<Stepper>

Source

impl IntoElement for StyledText

Source

impl IntoElement for Surface

Source

impl IntoElement for Svg

Source

impl IntoElement for Switch

Source

type Element = Component<Switch>

Source

impl IntoElement for SwitchField

Source

type Element = Component<SwitchField>

Source

impl IntoElement for Tab

Source

type Element = Component<Tab>

Source

impl IntoElement for TabBar

Source

type Element = Component<TabBar>

Source

impl IntoElement for ui::Table

Source

type Element = Component<Table>

Source

impl IntoElement for ui::LayoutTable

Source

type Element = Component<Table>

Source

impl IntoElement for TableBody

Source

type Element = Component<TableBody>

Source

impl IntoElement for TableCaption

Source

type Element = Component<TableCaption>

Source

impl IntoElement for TableCell

Source

type Element = Component<TableCell>

Source

impl IntoElement for TableFooter

Source

type Element = Component<TableFooter>

Source

impl IntoElement for TableHead

Source

type Element = Component<TableHead>

Source

impl IntoElement for TableHeader

Source

type Element = Component<TableHeader>

Source

impl IntoElement for TableRow

Source

type Element = Component<TableRow>

Source

impl IntoElement for TerminalOutputBlock

Source

impl IntoElement for ThinkingBlock

Source

type Element = Component<ThinkingBlock>

Source

impl IntoElement for ThreadItem

Source

type Element = Component<ThreadItem>

Source

impl IntoElement for TitleBar

Source

type Element = Component<TitleBar>

Source

impl IntoElement for ToastStack

Source

type Element = Component<ToastStack>

Source

impl IntoElement for ToggleGroup

Source

type Element = Component<ToggleGroup>

Source

impl IntoElement for TreeViewItem

Source

type Element = Component<TreeViewItem>

Source

impl IntoElement for UniformList

Source

impl IntoElement for UpdateButton

Source

type Element = Component<UpdateButton>

Source

impl IntoElement for Vector

Source

type Element = Component<Vector>

Source

impl IntoElement for VerticalNav

Source

type Element = Component<VerticalNav>

Source

impl IntoElement for VerticalNavItem

Source

impl IntoElement for WithRemSize

Source

impl<E> IntoElement for AnimationElement<E>
where E: IntoElement + 'static,

Source

impl<E> IntoElement for Stateful<E>
where E: Element,

Source

impl<M: ManagedView> IntoElement for PopoverMenu<M>

Source

impl<M: ManagedView> IntoElement for RightClickMenu<M>

Source

impl<T, const COLS: usize, const ROWS: usize> IntoElement for ToggleButtonGroup<T, COLS, ROWS>
where T: ButtonBuilder,

Source

type Element = Component<ToggleButtonGroup<T, COLS, ROWS>>

Source

impl<T> IntoElement for Canvas<T>
where T: 'static,

Source

impl<V> IntoElement for Entity<V>
where V: 'static + Render,