pub struct AlertModal { /* private fields */ }Implementations
Sourceimpl AlertModal
impl AlertModal
pub fn new(id: impl Into<ElementId>) -> Self
pub fn title(self, title: impl Into<SharedString>) -> Self
pub fn header(self, header: impl IntoElement) -> Self
pub fn primary_action(self, primary_action: impl Into<SharedString>) -> Self
pub fn dismiss_label(self, dismiss_label: impl Into<SharedString>) -> Self
pub fn width(self, width: impl Into<DefiniteLength>) -> Self
pub fn key_context(self, key_context: impl Into<String>) -> Self
pub fn on_action<A: Action>( self, listener: impl Fn(&A, &mut Window, &mut App) + 'static, ) -> Self
pub fn track_focus(self, focus_handle: &FocusHandle) -> Self
Sourcepub fn destructive(self, destructive: bool) -> Self
pub fn destructive(self, destructive: bool) -> Self
Marks the primary action as destructive, rendering it with the danger button style instead of the default primary style.