ButtonLike

Struct ButtonLike 

pub struct ButtonLike { /* private fields */ }
A button-like element that can be used to create a custom button when prebuilt buttons are not sufficient. Use this sparingly, as it is unconstrained and may make the UI feel less consistent.

This is also used to build the prebuilt buttons.

Implementations

Source

impl ButtonLike

pub fn new(id: impl Into<ElementId>) -> Self

pub fn new_rounded_left(id: impl Into<ElementId>) -> Self

pub fn new_rounded_right(id: impl Into<ElementId>) -> Self

pub fn new_rounded_all(id: impl Into<ElementId>) -> Self

pub fn opacity(self, opacity: f32) -> Self

pub fn height(self, height: DefiniteLength) -> Self

pub fn on_right_click( self, handler: impl Fn(&ClickEvent, &mut Window, &mut App) + 'static, ) -> Self

pub fn hoverable_tooltip( self, tooltip: impl Fn(&mut Window, &mut App) -> AnyView + 'static, ) -> Self