pub struct Callout { /* private fields */ }Expand description
A callout component for displaying important information that requires user attention.
Usage Example
use ui::prelude::*;
use ui::{Button, Callout, IconName, Label, Severity};
let callout = Callout::new()
.severity(Severity::Warning)
.icon(IconName::Warning)
.title("Be aware of your subscription!")
.description("Your subscription is about to expire. Renew now!")
.actions_slot(Button::new("renew", "Renew Now"));Implementations
Sourceimpl Callout
impl Callout
Sourcepub fn title(self, title: impl Into<SharedString>) -> Self
pub fn title(self, title: impl Into<SharedString>) -> Self
Sets the title of the callout.
Sourcepub fn description(self, description: impl Into<SharedString>) -> Self
pub fn description(self, description: impl Into<SharedString>) -> Self
Sets the description of the callout. The description can be single or multi-line text.
Sourcepub fn description_slot(self, description: impl IntoElement) -> Self
pub fn description_slot(self, description: impl IntoElement) -> Self
Allows for any element—like markdown elements—to fill the description slot of the callout.
This method wins over description if both happen to be set.
Sourcepub fn actions_slot(self, action: impl IntoElement) -> Self
pub fn actions_slot(self, action: impl IntoElement) -> Self
Sets the primary call-to-action button.
Sourcepub fn dismiss_action(self, action: impl IntoElement) -> Self
pub fn dismiss_action(self, action: impl IntoElement) -> Self
Sets an optional dismiss button, which is usually an icon button with a close icon. This button is always rendered as the last one to the far right.
Sourcepub fn line_height(self, line_height: Pixels) -> Self
pub fn line_height(self, line_height: Pixels) -> Self
Sets a custom line height for the callout content.
Sourcepub fn border_position(self, border_position: BorderPosition) -> Self
pub fn border_position(self, border_position: BorderPosition) -> Self
Sets the border position in the callout.