pub struct Checkbox { /* private fields */ }Expand description
Checkbox
Checkboxes are used for multiple choices, not for mutually exclusive choices. Each checkbox works independently from other checkboxes in the list, therefore checking an additional box does not affect any other selections.
Implementations
Sourceimpl Checkbox
impl Checkbox
Sourcepub fn tab_index(self, tab_index: isize) -> Self
pub fn tab_index(self, tab_index: isize) -> Self
Enables keyboard focus (tab stop) and shows a primary-color focus ring
on keyboard focus, using the same native focus_visible mechanism as
Switch::tab_index.
Sourcepub fn placeholder(self, placeholder: bool) -> Self
pub fn placeholder(self, placeholder: bool) -> Self
Sets the disabled state of the Checkbox.
Sourcepub fn on_click(
self,
handler: impl Fn(&ToggleState, &mut Window, &mut App) + 'static,
) -> Self
pub fn on_click( self, handler: impl Fn(&ToggleState, &mut Window, &mut App) + 'static, ) -> Self
Binds a handler to the Checkbox that will be called when clicked.
pub fn on_click_ext( self, handler: impl Fn(&ToggleState, &ClickEvent, &mut Window, &mut App) + 'static, ) -> Self
Sourcepub fn fill(self) -> Self
pub fn fill(self) -> Self
Sets the fill setting of the checkbox, indicating whether it should be filled.
Sourcepub fn visualization_only(self, visualization: bool) -> Self
pub fn visualization_only(self, visualization: bool) -> Self
Makes the checkbox look enabled but without pointer cursor and hover styles. Primarily used for uninteractive markdown previews.
Sourcepub fn style(self, style: ToggleStyle) -> Self
pub fn style(self, style: ToggleStyle) -> Self
Sets the style of the checkbox using the specified ToggleStyle.
Sourcepub fn elevation(self, elevation: ElevationIndex) -> Self
pub fn elevation(self, elevation: ElevationIndex) -> Self
Match the style of the checkbox to the current elevation using ToggleStyle::ElevationBased.
Sourcepub fn tooltip(
self,
tooltip: impl Fn(&mut Window, &mut App) -> AnyView + 'static,
) -> Self
pub fn tooltip( self, tooltip: impl Fn(&mut Window, &mut App) -> AnyView + 'static, ) -> Self
Sets the tooltip for the checkbox.
Sourcepub fn label(self, label: impl Into<SharedString>) -> Self
pub fn label(self, label: impl Into<SharedString>) -> Self
Set the label for the checkbox.
pub fn label_size(self, size: LabelSize) -> Self
pub fn label_color(self, color: Color) -> Self