pub struct ContextMenu { /* private fields */ }Implementations
Sourceimpl ContextMenu
impl ContextMenu
pub fn new( window: &mut Window, cx: &mut Context<'_, Self>, f: impl FnOnce(Self, &mut Window, &mut Context<'_, Self>) -> Self, ) -> Self
pub fn build( window: &mut Window, cx: &mut App, f: impl FnOnce(Self, &mut Window, &mut Context<'_, Self>) -> Self, ) -> Entity<Self>
Sourcepub fn build_persistent(
window: &mut Window,
cx: &mut App,
builder: impl Fn(Self, &mut Window, &mut Context<'_, Self>) -> Self + 'static,
) -> Entity<Self>
pub fn build_persistent( window: &mut Window, cx: &mut App, builder: impl Fn(Self, &mut Window, &mut Context<'_, Self>) -> Self + 'static, ) -> Entity<Self>
Builds a ContextMenu that will stay open when making changes instead of closing after each confirmation.
The main difference from ContextMenu::build is the type of the builder, as we need to be able to hold onto
it to call it again.
Sourcepub fn rebuild(&mut self, window: &mut Window, cx: &mut Context<'_, Self>)
pub fn rebuild(&mut self, window: &mut Window, cx: &mut Context<'_, Self>)
Rebuilds the menu.
This is used to refresh the menu entries when entries are toggled when the menu is configured with
keep_open_on_confirm = true.
This only works if the ContextMenu was constructed using ContextMenu::build_persistent. Otherwise it is
a no-op.
pub fn context(self, focus: FocusHandle) -> Self
pub fn header(self, title: impl Into<SharedString>) -> Self
pub fn header_with_link( self, title: impl Into<SharedString>, link_label: impl Into<SharedString>, link_url: impl Into<SharedString>, ) -> Self
pub fn separator(self) -> Self
pub fn extend<I: Into<ContextMenuItem>>( self, items: impl IntoIterator<Item = I>, ) -> Self
pub fn item(self, item: impl Into<ContextMenuItem>) -> Self
pub fn push_item(&mut self, item: impl Into<ContextMenuItem>)
pub fn entry( self, label: impl Into<SharedString>, action: Option<Box<dyn Action>>, handler: impl Fn(&mut Window, &mut App) + 'static, ) -> Self
pub fn entry_with_end_slot( self, label: impl Into<SharedString>, action: Option<Box<dyn Action>>, handler: impl Fn(&mut Window, &mut App) + 'static, end_slot_icon: IconName, end_slot_title: SharedString, end_slot_handler: impl Fn(&mut Window, &mut App) + 'static, ) -> Self
pub fn entry_with_end_slot_on_hover( self, label: impl Into<SharedString>, action: Option<Box<dyn Action>>, handler: impl Fn(&mut Window, &mut App) + 'static, end_slot_icon: IconName, end_slot_title: SharedString, end_slot_handler: impl Fn(&mut Window, &mut App) + 'static, ) -> Self
pub fn toggleable_entry( self, label: impl Into<SharedString>, toggled: bool, position: IconPosition, action: Option<Box<dyn Action>>, handler: impl Fn(&mut Window, &mut App) + 'static, ) -> Self
pub fn custom_row( self, entry_render: impl Fn(&mut Window, &mut App) -> AnyElement + 'static, ) -> Self
pub fn custom_entry( self, entry_render: impl Fn(&mut Window, &mut App) -> AnyElement + 'static, handler: impl Fn(&mut Window, &mut App) + 'static, ) -> Self
pub fn custom_entry_with_docs( self, entry_render: impl Fn(&mut Window, &mut App) -> AnyElement + 'static, handler: impl Fn(&mut Window, &mut App) + 'static, documentation_aside: Option<DocumentationAside>, ) -> Self
pub fn selectable(self, selectable: bool) -> Self
pub fn label(self, label: impl Into<SharedString>) -> Self
pub fn action( self, label: impl Into<SharedString>, action: Box<dyn Action>, ) -> Self
pub fn action_checked( self, label: impl Into<SharedString>, action: Box<dyn Action>, checked: bool, ) -> Self
pub fn action_checked_with_disabled( self, label: impl Into<SharedString>, action: Box<dyn Action>, checked: bool, disabled: bool, ) -> Self
pub fn action_disabled_when( self, disabled: bool, label: impl Into<SharedString>, action: Box<dyn Action>, ) -> Self
pub fn link( self, label: impl Into<SharedString>, action: Box<dyn Action>, ) -> Self
pub fn link_with_handler( self, label: impl Into<SharedString>, action: Box<dyn Action>, handler: impl Fn(&mut Window, &mut App) + 'static, ) -> Self
pub fn keep_open_on_confirm(self, keep_open: bool) -> Self
pub fn trigger_end_slot_handler( &mut self, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn fixed_width(self, width: DefiniteLength) -> Self
pub fn end_slot_action(self, action: Box<dyn Action>) -> Self
pub fn key_context(self, context: impl Into<SharedString>) -> Self
pub fn selected_index(&self) -> Option<usize>
pub fn confirm( &mut self, _: &Confirm, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn secondary_confirm( &mut self, _: &SecondaryConfirm, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn cancel( &mut self, _: &Cancel, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn end_slot( &mut self, _: &dyn Action, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn clear_selected(&mut self)
pub fn select_first( &mut self, _: &SelectFirst, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn select_last( &mut self, window: &mut Window, cx: &mut Context<'_, Self>, ) -> Option<usize>
pub fn select_next( &mut self, _: &SelectNext, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn select_previous( &mut self, _: &SelectPrevious, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn on_action_dispatch( &mut self, dispatched: &dyn Action, window: &mut Window, cx: &mut Context<'_, Self>, )
pub fn on_blur_subscription(self, new_subscription: Subscription) -> Self