Facepile

Struct Facepile 

pub struct Facepile { /* private fields */ }
An element that displays a collection of (usually) faces stacked horizontally, with the left-most face on top, visually descending from left to right.

Facepiles are used to display a group of people or things, such as a list of participants in a collaboration session.

Examples

Default

A default, horizontal facepile.

use gpui::IntoElement;
use ui::{Avatar, Facepile, EXAMPLE_FACES};

let facepile = Facepile::new(
    EXAMPLE_FACES.iter().take(3).map(|&url|
        Avatar::new(url).into_any_element()).collect()
);

Implementations

Source

impl Facepile

pub fn empty() -> Self

Creates a new empty facepile.

pub fn new(faces: SmallVec<[AnyElement; 2]>) -> Self

Creates a new facepile with the given faces.

pub fn max_visible(self, max: usize) -> Self

Caps the number of visible faces, replacing the rest with a +N overflow indicator.

Source

impl Facepile

pub fn p(self, length: impl Clone + Into<DefiniteLength>) -> Self

Sets the padding of the element. Docs

pub fn p_0(self) -> Self

Sets the padding of the element. Docs

0px

pub fn p_neg_0(self) -> Self

Sets the padding of the element. Docs

0px

pub fn p_0p5(self) -> Self

Sets the padding of the element. Docs

2px (0.125rem)

pub fn p_neg_0p5(self) -> Self

Sets the padding of the element. Docs

2px (0.125rem)

pub fn p_1(self) -> Self

Sets the padding of the element. Docs

4px (0.25rem)

pub fn p_neg_1(self) -> Self

Sets the padding of the element. Docs

4px (0.25rem)

pub fn p_1p5(self) -> Self

Sets the padding of the element. Docs

6px (0.375rem)

pub fn p_neg_1p5(self) -> Self

Sets the padding of the element. Docs

6px (0.375rem)

pub fn p_2(self) -> Self

Sets the padding of the element. Docs

8px (0.5rem)

pub fn p_neg_2(self) -> Self

Sets the padding of the element. Docs

8px (0.5rem)

pub fn p_2p5(self) -> Self

Sets the padding of the element. Docs

10px (0.625rem)

pub fn p_neg_2p5(self) -> Self

Sets the padding of the element. Docs

10px (0.625rem)

pub fn p_3(self) -> Self

Sets the padding of the element. Docs

12px (0.75rem)

pub fn p_neg_3(self) -> Self

Sets the padding of the element. Docs

12px (0.75rem)

pub fn p_3p5(self) -> Self

Sets the padding of the element. Docs

14px (0.875rem)

pub fn p_neg_3p5(self) -> Self

Sets the padding of the element. Docs

14px (0.875rem)

pub fn p_4(self) -> Self

Sets the padding of the element. Docs

16px (1rem)

pub fn p_neg_4(self) -> Self

Sets the padding of the element. Docs

16px (1rem)

pub fn p_5(self) -> Self

Sets the padding of the element. Docs

20px (1.25rem)

pub fn p_neg_5(self) -> Self

Sets the padding of the element. Docs

20px (1.25rem)

pub fn p_6(self) -> Self

Sets the padding of the element. Docs

24px (1.5rem)

pub fn p_neg_6(self) -> Self

Sets the padding of the element. Docs

24px (1.5rem)

pub fn p_7(self) -> Self

Sets the padding of the element. Docs

28px (1.75rem)

pub fn p_neg_7(self) -> Self

Sets the padding of the element. Docs

28px (1.75rem)

pub fn p_8(self) -> Self

Sets the padding of the element. Docs

32px (2rem)

pub fn p_neg_8(self) -> Self

Sets the padding of the element. Docs

32px (2rem)

pub fn p_9(self) -> Self

Sets the padding of the element. Docs

36px (2.25rem)

pub fn p_neg_9(self) -> Self

Sets the padding of the element. Docs

36px (2.25rem)

pub fn p_10(self) -> Self

Sets the padding of the element. Docs

40px (2.5rem)

pub fn p_neg_10(self) -> Self

Sets the padding of the element. Docs

40px (2.5rem)

pub fn p_11(self) -> Self

Sets the padding of the element. Docs

44px (2.75rem)

pub fn p_neg_11(self) -> Self

Sets the padding of the element. Docs

44px (2.75rem)

pub fn p_12(self) -> Self

Sets the padding of the element. Docs

48px (3rem)

pub fn p_neg_12(self) -> Self

Sets the padding of the element. Docs

48px (3rem)

pub fn p_16(self) -> Self

Sets the padding of the element. Docs

64px (4rem)

pub fn p_neg_16(self) -> Self

Sets the padding of the element. Docs

64px (4rem)

pub fn p_20(self) -> Self

Sets the padding of the element. Docs

80px (5rem)

pub fn p_neg_20(self) -> Self

Sets the padding of the element. Docs

80px (5rem)

pub fn p_24(self) -> Self

Sets the padding of the element. Docs

96px (6rem)

pub fn p_neg_24(self) -> Self

Sets the padding of the element. Docs

96px (6rem)

pub fn p_32(self) -> Self

Sets the padding of the element. Docs

128px (8rem)

pub fn p_neg_32(self) -> Self

Sets the padding of the element. Docs

128px (8rem)

pub fn p_40(self) -> Self

Sets the padding of the element. Docs

160px (10rem)

pub fn p_neg_40(self) -> Self

Sets the padding of the element. Docs

160px (10rem)

pub fn p_48(self) -> Self

Sets the padding of the element. Docs

192px (12rem)

pub fn p_neg_48(self) -> Self

Sets the padding of the element. Docs

192px (12rem)

pub fn p_56(self) -> Self

Sets the padding of the element. Docs

224px (14rem)

pub fn p_neg_56(self) -> Self

Sets the padding of the element. Docs

224px (14rem)

pub fn p_64(self) -> Self

Sets the padding of the element. Docs

256px (16rem)

pub fn p_neg_64(self) -> Self

Sets the padding of the element. Docs

256px (16rem)

pub fn p_72(self) -> Self

Sets the padding of the element. Docs

288px (18rem)

pub fn p_neg_72(self) -> Self

Sets the padding of the element. Docs

288px (18rem)

pub fn p_80(self) -> Self

Sets the padding of the element. Docs

320px (20rem)

pub fn p_neg_80(self) -> Self

Sets the padding of the element. Docs

320px (20rem)

pub fn p_96(self) -> Self

Sets the padding of the element. Docs

384px (24rem)

pub fn p_neg_96(self) -> Self

Sets the padding of the element. Docs

384px (24rem)

pub fn p_112(self) -> Self

Sets the padding of the element. Docs

448px (28rem)

pub fn p_neg_112(self) -> Self

Sets the padding of the element. Docs

448px (28rem)

pub fn p_128(self) -> Self

Sets the padding of the element. Docs

512px (32rem)

pub fn p_neg_128(self) -> Self

Sets the padding of the element. Docs

512px (32rem)

pub fn p_px(self) -> Self

Sets the padding of the element. Docs

1px

pub fn p_neg_px(self) -> Self

Sets the padding of the element. Docs

1px

pub fn p_full(self) -> Self

Sets the padding of the element. Docs

100%

pub fn p_neg_full(self) -> Self

Sets the padding of the element. Docs

100%

pub fn p_1_2(self) -> Self

Sets the padding of the element. Docs

50% (1/2)

pub fn p_neg_1_2(self) -> Self

Sets the padding of the element. Docs

50% (1/2)

pub fn p_1_3(self) -> Self

Sets the padding of the element. Docs

33% (1/3)

pub fn p_neg_1_3(self) -> Self

Sets the padding of the element. Docs

33% (1/3)

pub fn p_2_3(self) -> Self

Sets the padding of the element. Docs

66% (2/3)

pub fn p_neg_2_3(self) -> Self

Sets the padding of the element. Docs

66% (2/3)

pub fn p_1_4(self) -> Self

Sets the padding of the element. Docs

25% (1/4)

pub fn p_neg_1_4(self) -> Self

Sets the padding of the element. Docs

25% (1/4)

pub fn p_2_4(self) -> Self

Sets the padding of the element. Docs

50% (2/4)

pub fn p_neg_2_4(self) -> Self

Sets the padding of the element. Docs

50% (2/4)

pub fn p_3_4(self) -> Self

Sets the padding of the element. Docs

75% (3/4)

pub fn p_neg_3_4(self) -> Self

Sets the padding of the element. Docs

75% (3/4)

pub fn p_1_5(self) -> Self

Sets the padding of the element. Docs

20% (1/5)

pub fn p_neg_1_5(self) -> Self

Sets the padding of the element. Docs

20% (1/5)

pub fn p_2_5(self) -> Self

Sets the padding of the element. Docs

40% (2/5)

pub fn p_neg_2_5(self) -> Self

Sets the padding of the element. Docs

40% (2/5)

pub fn p_3_5(self) -> Self

Sets the padding of the element. Docs

60% (3/5)

pub fn p_neg_3_5(self) -> Self

Sets the padding of the element. Docs

60% (3/5)

pub fn p_4_5(self) -> Self

Sets the padding of the element. Docs

80% (4/5)

pub fn p_neg_4_5(self) -> Self

Sets the padding of the element. Docs

80% (4/5)

pub fn p_1_6(self) -> Self

Sets the padding of the element. Docs

16% (1/6)

pub fn p_neg_1_6(self) -> Self

Sets the padding of the element. Docs

16% (1/6)

pub fn p_5_6(self) -> Self

Sets the padding of the element. Docs

80% (5/6)

pub fn p_neg_5_6(self) -> Self

Sets the padding of the element. Docs

80% (5/6)

pub fn p_1_12(self) -> Self

Sets the padding of the element. Docs

8% (1/12)

pub fn p_neg_1_12(self) -> Self

Sets the padding of the element. Docs

8% (1/12)

pub fn pt(self, length: impl Clone + Into<DefiniteLength>) -> Self

Sets the top padding of the element. Docs

pub fn pt_0(self) -> Self

Sets the top padding of the element. Docs

0px

pub fn pt_neg_0(self) -> Self

Sets the top padding of the element. Docs

0px

pub fn pt_0p5(self) -> Self

Sets the top padding of the element. Docs

2px (0.125rem)

pub fn pt_neg_0p5(self) -> Self

Sets the top padding of the element. Docs

2px (0.125rem)

pub fn pt_1(self) -> Self

Sets the top padding of the element. Docs

4px (0.25rem)

pub fn pt_neg_1(self) -> Self

Sets the top padding of the element. Docs

4px (0.25rem)

pub fn pt_1p5(self) -> Self

Sets the top padding of the element. Docs

6px (0.375rem)

pub fn pt_neg_1p5(self) -> Self

Sets the top padding of the element. Docs

6px (0.375rem)

pub fn pt_2(self) -> Self

Sets the top padding of the element. Docs

8px (0.5rem)

pub fn pt_neg_2(self) -> Self

Sets the top padding of the element. Docs

8px (0.5rem)

pub fn pt_2p5(self) -> Self

Sets the top padding of the element. Docs

10px (0.625rem)

pub fn pt_neg_2p5(self) -> Self

Sets the top padding of the element. Docs

10px (0.625rem)

pub fn pt_3(self) -> Self

Sets the top padding of the element. Docs

12px (0.75rem)

pub fn pt_neg_3(self) -> Self

Sets the top padding of the element. Docs

12px (0.75rem)

pub fn pt_3p5(self) -> Self

Sets the top padding of the element. Docs

14px (0.875rem)

pub fn pt_neg_3p5(self) -> Self

Sets the top padding of the element. Docs

14px (0.875rem)

pub fn pt_4(self) -> Self

Sets the top padding of the element. Docs

16px (1rem)

pub fn pt_neg_4(self) -> Self

Sets the top padding of the element. Docs

16px (1rem)

pub fn pt_5(self) -> Self

Sets the top padding of the element. Docs

20px (1.25rem)

pub fn pt_neg_5(self) -> Self

Sets the top padding of the element. Docs

20px (1.25rem)

pub fn pt_6(self) -> Self

Sets the top padding of the element. Docs

24px (1.5rem)

pub fn pt_neg_6(self) -> Self

Sets the top padding of the element. Docs

24px (1.5rem)

pub fn pt_7(self) -> Self

Sets the top padding of the element. Docs

28px (1.75rem)

pub fn pt_neg_7(self) -> Self

Sets the top padding of the element. Docs

28px (1.75rem)

pub fn pt_8(self) -> Self

Sets the top padding of the element. Docs

32px (2rem)

pub fn pt_neg_8(self) -> Self

Sets the top padding of the element. Docs

32px (2rem)

pub fn pt_9(self) -> Self

Sets the top padding of the element. Docs

36px (2.25rem)

pub fn pt_neg_9(self) -> Self

Sets the top padding of the element. Docs

36px (2.25rem)

pub fn pt_10(self) -> Self

Sets the top padding of the element. Docs

40px (2.5rem)

pub fn pt_neg_10(self) -> Self

Sets the top padding of the element. Docs

40px (2.5rem)

pub fn pt_11(self) -> Self

Sets the top padding of the element. Docs

44px (2.75rem)

pub fn pt_neg_11(self) -> Self

Sets the top padding of the element. Docs

44px (2.75rem)

pub fn pt_12(self) -> Self

Sets the top padding of the element. Docs

48px (3rem)

pub fn pt_neg_12(self) -> Self

Sets the top padding of the element. Docs

48px (3rem)

pub fn pt_16(self) -> Self

Sets the top padding of the element. Docs

64px (4rem)

pub fn pt_neg_16(self) -> Self

Sets the top padding of the element. Docs

64px (4rem)

pub fn pt_20(self) -> Self

Sets the top padding of the element. Docs

80px (5rem)

pub fn pt_neg_20(self) -> Self

Sets the top padding of the element. Docs

80px (5rem)

pub fn pt_24(self) -> Self

Sets the top padding of the element. Docs

96px (6rem)

pub fn pt_neg_24(self) -> Self

Sets the top padding of the element. Docs

96px (6rem)

pub fn pt_32(self) -> Self

Sets the top padding of the element. Docs

128px (8rem)

pub fn pt_neg_32(self) -> Self

Sets the top padding of the element. Docs

128px (8rem)

pub fn pt_40(self) -> Self

Sets the top padding of the element. Docs

160px (10rem)

pub fn pt_neg_40(self) -> Self

Sets the top padding of the element. Docs

160px (10rem)

pub fn pt_48(self) -> Self

Sets the top padding of the element. Docs

192px (12rem)

pub fn pt_neg_48(self) -> Self

Sets the top padding of the element. Docs

192px (12rem)

pub fn pt_56(self) -> Self

Sets the top padding of the element. Docs

224px (14rem)

pub fn pt_neg_56(self) -> Self

Sets the top padding of the element. Docs

224px (14rem)

pub fn pt_64(self) -> Self

Sets the top padding of the element. Docs

256px (16rem)

pub fn pt_neg_64(self) -> Self

Sets the top padding of the element. Docs

256px (16rem)

pub fn pt_72(self) -> Self

Sets the top padding of the element. Docs

288px (18rem)

pub fn pt_neg_72(self) -> Self

Sets the top padding of the element. Docs

288px (18rem)

pub fn pt_80(self) -> Self

Sets the top padding of the element. Docs

320px (20rem)

pub fn pt_neg_80(self) -> Self

Sets the top padding of the element. Docs

320px (20rem)

pub fn pt_96(self) -> Self

Sets the top padding of the element. Docs

384px (24rem)

pub fn pt_neg_96(self) -> Self

Sets the top padding of the element. Docs

384px (24rem)

pub fn pt_112(self) -> Self

Sets the top padding of the element. Docs

448px (28rem)

pub fn pt_neg_112(self) -> Self

Sets the top padding of the element. Docs

448px (28rem)

pub fn pt_128(self) -> Self

Sets the top padding of the element. Docs

512px (32rem)

pub fn pt_neg_128(self) -> Self

Sets the top padding of the element. Docs

512px (32rem)

pub fn pt_px(self) -> Self

Sets the top padding of the element. Docs

1px

pub fn pt_neg_px(self) -> Self

Sets the top padding of the element. Docs

1px

pub fn pt_full(self) -> Self

Sets the top padding of the element. Docs

100%

pub fn pt_neg_full(self) -> Self

Sets the top padding of the element. Docs

100%

pub fn pt_1_2(self) -> Self

Sets the top padding of the element. Docs

50% (1/2)

pub fn pt_neg_1_2(self) -> Self

Sets the top padding of the element. Docs

50% (1/2)

pub fn pt_1_3(self) -> Self

Sets the top padding of the element. Docs

33% (1/3)

pub fn pt_neg_1_3(self) -> Self

Sets the top padding of the element. Docs

33% (1/3)

pub fn pt_2_3(self) -> Self

Sets the top padding of the element. Docs

66% (2/3)

pub fn pt_neg_2_3(self) -> Self

Sets the top padding of the element. Docs

66% (2/3)

pub fn pt_1_4(self) -> Self

Sets the top padding of the element. Docs

25% (1/4)

pub fn pt_neg_1_4(self) -> Self

Sets the top padding of the element. Docs

25% (1/4)

pub fn pt_2_4(self) -> Self

Sets the top padding of the element. Docs

50% (2/4)

pub fn pt_neg_2_4(self) -> Self

Sets the top padding of the element. Docs

50% (2/4)

pub fn pt_3_4(self) -> Self

Sets the top padding of the element. Docs

75% (3/4)

pub fn pt_neg_3_4(self) -> Self

Sets the top padding of the element. Docs

75% (3/4)

pub fn pt_1_5(self) -> Self

Sets the top padding of the element. Docs

20% (1/5)

pub fn pt_neg_1_5(self) -> Self

Sets the top padding of the element. Docs

20% (1/5)

pub fn pt_2_5(self) -> Self

Sets the top padding of the element. Docs

40% (2/5)

pub fn pt_neg_2_5(self) -> Self

Sets the top padding of the element. Docs

40% (2/5)

pub fn pt_3_5(self) -> Self

Sets the top padding of the element. Docs

60% (3/5)

pub fn pt_neg_3_5(self) -> Self

Sets the top padding of the element. Docs

60% (3/5)

pub fn pt_4_5(self) -> Self

Sets the top padding of the element. Docs

80% (4/5)

pub fn pt_neg_4_5(self) -> Self

Sets the top padding of the element. Docs

80% (4/5)

pub fn pt_1_6(self) -> Self

Sets the top padding of the element. Docs

16% (1/6)

pub fn pt_neg_1_6(self) -> Self

Sets the top padding of the element. Docs

16% (1/6)

pub fn pt_5_6(self) -> Self

Sets the top padding of the element. Docs

80% (5/6)

pub fn pt_neg_5_6(self) -> Self

Sets the top padding of the element. Docs

80% (5/6)

pub fn pt_1_12(self) -> Self

Sets the top padding of the element. Docs

8% (1/12)

pub fn pt_neg_1_12(self) -> Self

Sets the top padding of the element. Docs

8% (1/12)

pub fn pb(self, length: impl Clone + Into<DefiniteLength>) -> Self

Sets the bottom padding of the element. Docs

pub fn pb_0(self) -> Self

Sets the bottom padding of the element. Docs

0px

pub fn pb_neg_0(self) -> Self

Sets the bottom padding of the element. Docs

0px

pub fn pb_0p5(self) -> Self

Sets the bottom padding of the element. Docs

2px (0.125rem)

pub fn pb_neg_0p5(self) -> Self

Sets the bottom padding of the element. Docs

2px (0.125rem)

pub fn pb_1(self) -> Self

Sets the bottom padding of the element. Docs

4px (0.25rem)

pub fn pb_neg_1(self) -> Self

Sets the bottom padding of the element. Docs

4px (0.25rem)

pub fn pb_1p5(self) -> Self

Sets the bottom padding of the element. Docs

6px (0.375rem)

pub fn pb_neg_1p5(self) -> Self

Sets the bottom padding of the element. Docs

6px (0.375rem)

pub fn pb_2(self) -> Self

Sets the bottom padding of the element. Docs

8px (0.5rem)

pub fn pb_neg_2(self) -> Self

Sets the bottom padding of the element. Docs

8px (0.5rem)

pub fn pb_2p5(self) -> Self

Sets the bottom padding of the element. Docs

10px (0.625rem)

pub fn pb_neg_2p5(self) -> Self

Sets the bottom padding of the element. Docs

10px (0.625rem)

pub fn pb_3(self) -> Self

Sets the bottom padding of the element. Docs

12px (0.75rem)

pub fn pb_neg_3(self) -> Self

Sets the bottom padding of the element. Docs

12px (0.75rem)

pub fn pb_3p5(self) -> Self

Sets the bottom padding of the element. Docs

14px (0.875rem)

pub fn pb_neg_3p5(self) -> Self

Sets the bottom padding of the element. Docs

14px (0.875rem)

pub fn pb_4(self) -> Self

Sets the bottom padding of the element. Docs

16px (1rem)

pub fn pb_neg_4(self) -> Self

Sets the bottom padding of the element. Docs

16px (1rem)

pub fn pb_5(self) -> Self

Sets the bottom padding of the element. Docs

20px (1.25rem)

pub fn pb_neg_5(self) -> Self

Sets the bottom padding of the element. Docs

20px (1.25rem)

pub fn pb_6(self) -> Self

Sets the bottom padding of the element. Docs

24px (1.5rem)

pub fn pb_neg_6(self) -> Self

Sets the bottom padding of the element. Docs

24px (1.5rem)

pub fn pb_7(self) -> Self

Sets the bottom padding of the element. Docs

28px (1.75rem)

pub fn pb_neg_7(self) -> Self

Sets the bottom padding of the element. Docs

28px (1.75rem)

pub fn pb_8(self) -> Self

Sets the bottom padding of the element. Docs

32px (2rem)

pub fn pb_neg_8(self) -> Self

Sets the bottom padding of the element. Docs

32px (2rem)

pub fn pb_9(self) -> Self

Sets the bottom padding of the element. Docs

36px (2.25rem)

pub fn pb_neg_9(self) -> Self

Sets the bottom padding of the element. Docs

36px (2.25rem)

pub fn pb_10(self) -> Self

Sets the bottom padding of the element. Docs

40px (2.5rem)

pub fn pb_neg_10(self) -> Self

Sets the bottom padding of the element. Docs

40px (2.5rem)

pub fn pb_11(self) -> Self

Sets the bottom padding of the element. Docs

44px (2.75rem)

pub fn pb_neg_11(self) -> Self

Sets the bottom padding of the element. Docs

44px (2.75rem)

pub fn pb_12(self) -> Self

Sets the bottom padding of the element. Docs

48px (3rem)

pub fn pb_neg_12(self) -> Self

Sets the bottom padding of the element. Docs

48px (3rem)

pub fn pb_16(self) -> Self

Sets the bottom padding of the element. Docs

64px (4rem)

pub fn pb_neg_16(self) -> Self

Sets the bottom padding of the element. Docs

64px (4rem)

pub fn pb_20(self) -> Self

Sets the bottom padding of the element. Docs

80px (5rem)

pub fn pb_neg_20(self) -> Self

Sets the bottom padding of the element. Docs

80px (5rem)

pub fn pb_24(self) -> Self

Sets the bottom padding of the element. Docs

96px (6rem)

pub fn pb_neg_24(self) -> Self

Sets the bottom padding of the element. Docs

96px (6rem)

pub fn pb_32(self) -> Self

Sets the bottom padding of the element. Docs

128px (8rem)

pub fn pb_neg_32(self) -> Self

Sets the bottom padding of the element. Docs

128px (8rem)

pub fn pb_40(self) -> Self

Sets the bottom padding of the element. Docs

160px (10rem)

pub fn pb_neg_40(self) -> Self

Sets the bottom padding of the element. Docs

160px (10rem)

pub fn pb_48(self) -> Self

Sets the bottom padding of the element. Docs

192px (12rem)

pub fn pb_neg_48(self) -> Self

Sets the bottom padding of the element. Docs

192px (12rem)

pub fn pb_56(self) -> Self

Sets the bottom padding of the element. Docs

224px (14rem)

pub fn pb_neg_56(self) -> Self

Sets the bottom padding of the element. Docs

224px (14rem)

pub fn pb_64(self) -> Self

Sets the bottom padding of the element. Docs

256px (16rem)

pub fn pb_neg_64(self) -> Self

Sets the bottom padding of the element. Docs

256px (16rem)

pub fn pb_72(self) -> Self

Sets the bottom padding of the element. Docs

288px (18rem)

pub fn pb_neg_72(self) -> Self

Sets the bottom padding of the element. Docs

288px (18rem)

pub fn pb_80(self) -> Self

Sets the bottom padding of the element. Docs

320px (20rem)

pub fn pb_neg_80(self) -> Self

Sets the bottom padding of the element. Docs

320px (20rem)

pub fn pb_96(self) -> Self

Sets the bottom padding of the element. Docs

384px (24rem)

pub fn pb_neg_96(self) -> Self

Sets the bottom padding of the element. Docs

384px (24rem)

pub fn pb_112(self) -> Self

Sets the bottom padding of the element. Docs

448px (28rem)

pub fn pb_neg_112(self) -> Self

Sets the bottom padding of the element. Docs

448px (28rem)

pub fn pb_128(self) -> Self

Sets the bottom padding of the element. Docs

512px (32rem)

pub fn pb_neg_128(self) -> Self

Sets the bottom padding of the element. Docs

512px (32rem)

pub fn pb_px(self) -> Self

Sets the bottom padding of the element. Docs

1px

pub fn pb_neg_px(self) -> Self

Sets the bottom padding of the element. Docs

1px

pub fn pb_full(self) -> Self

Sets the bottom padding of the element. Docs

100%

pub fn pb_neg_full(self) -> Self

Sets the bottom padding of the element. Docs

100%

pub fn pb_1_2(self) -> Self

Sets the bottom padding of the element. Docs

50% (1/2)

pub fn pb_neg_1_2(self) -> Self

Sets the bottom padding of the element. Docs

50% (1/2)

pub fn pb_1_3(self) -> Self

Sets the bottom padding of the element. Docs

33% (1/3)

pub fn pb_neg_1_3(self) -> Self

Sets the bottom padding of the element. Docs

33% (1/3)

pub fn pb_2_3(self) -> Self

Sets the bottom padding of the element. Docs

66% (2/3)

pub fn pb_neg_2_3(self) -> Self

Sets the bottom padding of the element. Docs

66% (2/3)

pub fn pb_1_4(self) -> Self

Sets the bottom padding of the element. Docs

25% (1/4)

pub fn pb_neg_1_4(self) -> Self

Sets the bottom padding of the element. Docs

25% (1/4)

pub fn pb_2_4(self) -> Self

Sets the bottom padding of the element. Docs

50% (2/4)

pub fn pb_neg_2_4(self) -> Self

Sets the bottom padding of the element. Docs

50% (2/4)

pub fn pb_3_4(self) -> Self

Sets the bottom padding of the element. Docs

75% (3/4)

pub fn pb_neg_3_4(self) -> Self

Sets the bottom padding of the element. Docs

75% (3/4)

pub fn pb_1_5(self) -> Self

Sets the bottom padding of the element. Docs

20% (1/5)

pub fn pb_neg_1_5(self) -> Self

Sets the bottom padding of the element. Docs

20% (1/5)

pub fn pb_2_5(self) -> Self

Sets the bottom padding of the element. Docs

40% (2/5)

pub fn pb_neg_2_5(self) -> Self

Sets the bottom padding of the element. Docs

40% (2/5)

pub fn pb_3_5(self) -> Self

Sets the bottom padding of the element. Docs

60% (3/5)

pub fn pb_neg_3_5(self) -> Self

Sets the bottom padding of the element. Docs

60% (3/5)

pub fn pb_4_5(self) -> Self

Sets the bottom padding of the element. Docs

80% (4/5)

pub fn pb_neg_4_5(self) -> Self

Sets the bottom padding of the element. Docs

80% (4/5)

pub fn pb_1_6(self) -> Self

Sets the bottom padding of the element. Docs

16% (1/6)

pub fn pb_neg_1_6(self) -> Self

Sets the bottom padding of the element. Docs

16% (1/6)

pub fn pb_5_6(self) -> Self

Sets the bottom padding of the element. Docs

80% (5/6)

pub fn pb_neg_5_6(self) -> Self

Sets the bottom padding of the element. Docs

80% (5/6)

pub fn pb_1_12(self) -> Self

Sets the bottom padding of the element. Docs

8% (1/12)

pub fn pb_neg_1_12(self) -> Self

Sets the bottom padding of the element. Docs

8% (1/12)

pub fn px(self, length: impl Clone + Into<DefiniteLength>) -> Self

Sets the horizontal padding of the element. Docs

pub fn px_0(self) -> Self

Sets the horizontal padding of the element. Docs

0px

pub fn px_neg_0(self) -> Self

Sets the horizontal padding of the element. Docs

0px

pub fn px_0p5(self) -> Self

Sets the horizontal padding of the element. Docs

2px (0.125rem)

pub fn px_neg_0p5(self) -> Self

Sets the horizontal padding of the element. Docs

2px (0.125rem)

pub fn px_1(self) -> Self

Sets the horizontal padding of the element. Docs

4px (0.25rem)

pub fn px_neg_1(self) -> Self

Sets the horizontal padding of the element. Docs

4px (0.25rem)

pub fn px_1p5(self) -> Self

Sets the horizontal padding of the element. Docs

6px (0.375rem)

pub fn px_neg_1p5(self) -> Self

Sets the horizontal padding of the element. Docs

6px (0.375rem)

pub fn px_2(self) -> Self

Sets the horizontal padding of the element. Docs

8px (0.5rem)

pub fn px_neg_2(self) -> Self

Sets the horizontal padding of the element. Docs

8px (0.5rem)

pub fn px_2p5(self) -> Self

Sets the horizontal padding of the element. Docs

10px (0.625rem)

pub fn px_neg_2p5(self) -> Self

Sets the horizontal padding of the element. Docs

10px (0.625rem)

pub fn px_3(self) -> Self

Sets the horizontal padding of the element. Docs

12px (0.75rem)

pub fn px_neg_3(self) -> Self

Sets the horizontal padding of the element. Docs

12px (0.75rem)

pub fn px_3p5(self) -> Self

Sets the horizontal padding of the element. Docs

14px (0.875rem)

pub fn px_neg_3p5(self) -> Self

Sets the horizontal padding of the element. Docs

14px (0.875rem)

pub fn px_4(self) -> Self

Sets the horizontal padding of the element. Docs

16px (1rem)

pub fn px_neg_4(self) -> Self

Sets the horizontal padding of the element. Docs

16px (1rem)

pub fn px_5(self) -> Self

Sets the horizontal padding of the element. Docs

20px (1.25rem)

pub fn px_neg_5(self) -> Self

Sets the horizontal padding of the element. Docs

20px (1.25rem)

pub fn px_6(self) -> Self

Sets the horizontal padding of the element. Docs

24px (1.5rem)

pub fn px_neg_6(self) -> Self

Sets the horizontal padding of the element. Docs

24px (1.5rem)

pub fn px_7(self) -> Self

Sets the horizontal padding of the element. Docs

28px (1.75rem)

pub fn px_neg_7(self) -> Self

Sets the horizontal padding of the element. Docs

28px (1.75rem)

pub fn px_8(self) -> Self

Sets the horizontal padding of the element. Docs

32px (2rem)

pub fn px_neg_8(self) -> Self

Sets the horizontal padding of the element. Docs

32px (2rem)

pub fn px_9(self) -> Self

Sets the horizontal padding of the element. Docs

36px (2.25rem)

pub fn px_neg_9(self) -> Self

Sets the horizontal padding of the element. Docs

36px (2.25rem)

pub fn px_10(self) -> Self

Sets the horizontal padding of the element. Docs

40px (2.5rem)

pub fn px_neg_10(self) -> Self

Sets the horizontal padding of the element. Docs

40px (2.5rem)

pub fn px_11(self) -> Self

Sets the horizontal padding of the element. Docs

44px (2.75rem)

pub fn px_neg_11(self) -> Self

Sets the horizontal padding of the element. Docs

44px (2.75rem)

pub fn px_12(self) -> Self

Sets the horizontal padding of the element. Docs

48px (3rem)

pub fn px_neg_12(self) -> Self

Sets the horizontal padding of the element. Docs

48px (3rem)

pub fn px_16(self) -> Self

Sets the horizontal padding of the element. Docs

64px (4rem)

pub fn px_neg_16(self) -> Self

Sets the horizontal padding of the element. Docs

64px (4rem)

pub fn px_20(self) -> Self

Sets the horizontal padding of the element. Docs

80px (5rem)

pub fn px_neg_20(self) -> Self

Sets the horizontal padding of the element. Docs

80px (5rem)

pub fn px_24(self) -> Self

Sets the horizontal padding of the element. Docs

96px (6rem)

pub fn px_neg_24(self) -> Self

Sets the horizontal padding of the element. Docs

96px (6rem)

pub fn px_32(self) -> Self

Sets the horizontal padding of the element. Docs

128px (8rem)

pub fn px_neg_32(self) -> Self

Sets the horizontal padding of the element. Docs

128px (8rem)

pub fn px_40(self) -> Self

Sets the horizontal padding of the element. Docs

160px (10rem)

pub fn px_neg_40(self) -> Self

Sets the horizontal padding of the element. Docs

160px (10rem)

pub fn px_48(self) -> Self

Sets the horizontal padding of the element. Docs

192px (12rem)

pub fn px_neg_48(self) -> Self

Sets the horizontal padding of the element. Docs

192px (12rem)

pub fn px_56(self) -> Self

Sets the horizontal padding of the element. Docs

224px (14rem)

pub fn px_neg_56(self) -> Self

Sets the horizontal padding of the element. Docs

224px (14rem)

pub fn px_64(self) -> Self

Sets the horizontal padding of the element. Docs

256px (16rem)

pub fn px_neg_64(self) -> Self

Sets the horizontal padding of the element. Docs

256px (16rem)

pub fn px_72(self) -> Self

Sets the horizontal padding of the element. Docs

288px (18rem)

pub fn px_neg_72(self) -> Self

Sets the horizontal padding of the element. Docs

288px (18rem)

pub fn px_80(self) -> Self

Sets the horizontal padding of the element. Docs

320px (20rem)

pub fn px_neg_80(self) -> Self

Sets the horizontal padding of the element. Docs

320px (20rem)

pub fn px_96(self) -> Self

Sets the horizontal padding of the element. Docs

384px (24rem)

pub fn px_neg_96(self) -> Self

Sets the horizontal padding of the element. Docs

384px (24rem)

pub fn px_112(self) -> Self

Sets the horizontal padding of the element. Docs

448px (28rem)

pub fn px_neg_112(self) -> Self

Sets the horizontal padding of the element. Docs

448px (28rem)

pub fn px_128(self) -> Self

Sets the horizontal padding of the element. Docs

512px (32rem)

pub fn px_neg_128(self) -> Self

Sets the horizontal padding of the element. Docs

512px (32rem)

pub fn px_px(self) -> Self

Sets the horizontal padding of the element. Docs

1px

pub fn px_neg_px(self) -> Self

Sets the horizontal padding of the element. Docs

1px

pub fn px_full(self) -> Self

Sets the horizontal padding of the element. Docs

100%

pub fn px_neg_full(self) -> Self

Sets the horizontal padding of the element. Docs

100%

pub fn px_1_2(self) -> Self

Sets the horizontal padding of the element. Docs

50% (1/2)

pub fn px_neg_1_2(self) -> Self

Sets the horizontal padding of the element. Docs

50% (1/2)

pub fn px_1_3(self) -> Self

Sets the horizontal padding of the element. Docs

33% (1/3)

pub fn px_neg_1_3(self) -> Self

Sets the horizontal padding of the element. Docs

33% (1/3)

pub fn px_2_3(self) -> Self

Sets the horizontal padding of the element. Docs

66% (2/3)

pub fn px_neg_2_3(self) -> Self

Sets the horizontal padding of the element. Docs

66% (2/3)

pub fn px_1_4(self) -> Self

Sets the horizontal padding of the element. Docs

25% (1/4)

pub fn px_neg_1_4(self) -> Self

Sets the horizontal padding of the element. Docs

25% (1/4)

pub fn px_2_4(self) -> Self

Sets the horizontal padding of the element. Docs

50% (2/4)

pub fn px_neg_2_4(self) -> Self

Sets the horizontal padding of the element. Docs

50% (2/4)

pub fn px_3_4(self) -> Self

Sets the horizontal padding of the element. Docs

75% (3/4)

pub fn px_neg_3_4(self) -> Self

Sets the horizontal padding of the element. Docs

75% (3/4)

pub fn px_1_5(self) -> Self

Sets the horizontal padding of the element. Docs

20% (1/5)

pub fn px_neg_1_5(self) -> Self

Sets the horizontal padding of the element. Docs

20% (1/5)

pub fn px_2_5(self) -> Self

Sets the horizontal padding of the element. Docs

40% (2/5)

pub fn px_neg_2_5(self) -> Self

Sets the horizontal padding of the element. Docs

40% (2/5)

pub fn px_3_5(self) -> Self

Sets the horizontal padding of the element. Docs

60% (3/5)

pub fn px_neg_3_5(self) -> Self

Sets the horizontal padding of the element. Docs

60% (3/5)

pub fn px_4_5(self) -> Self

Sets the horizontal padding of the element. Docs

80% (4/5)

pub fn px_neg_4_5(self) -> Self

Sets the horizontal padding of the element. Docs

80% (4/5)

pub fn px_1_6(self) -> Self

Sets the horizontal padding of the element. Docs

16% (1/6)

pub fn px_neg_1_6(self) -> Self

Sets the horizontal padding of the element. Docs

16% (1/6)

pub fn px_5_6(self) -> Self

Sets the horizontal padding of the element. Docs

80% (5/6)

pub fn px_neg_5_6(self) -> Self

Sets the horizontal padding of the element. Docs

80% (5/6)

pub fn px_1_12(self) -> Self

Sets the horizontal padding of the element. Docs

8% (1/12)

pub fn px_neg_1_12(self) -> Self

Sets the horizontal padding of the element. Docs

8% (1/12)

pub fn py(self, length: impl Clone + Into<DefiniteLength>) -> Self

Sets the vertical padding of the element. Docs

pub fn py_0(self) -> Self

Sets the vertical padding of the element. Docs

0px

pub fn py_neg_0(self) -> Self

Sets the vertical padding of the element. Docs

0px

pub fn py_0p5(self) -> Self

Sets the vertical padding of the element. Docs

2px (0.125rem)

pub fn py_neg_0p5(self) -> Self

Sets the vertical padding of the element. Docs

2px (0.125rem)

pub fn py_1(self) -> Self

Sets the vertical padding of the element. Docs

4px (0.25rem)

pub fn py_neg_1(self) -> Self

Sets the vertical padding of the element. Docs

4px (0.25rem)

pub fn py_1p5(self) -> Self

Sets the vertical padding of the element. Docs

6px (0.375rem)

pub fn py_neg_1p5(self) -> Self

Sets the vertical padding of the element. Docs

6px (0.375rem)

pub fn py_2(self) -> Self

Sets the vertical padding of the element. Docs

8px (0.5rem)

pub fn py_neg_2(self) -> Self

Sets the vertical padding of the element. Docs

8px (0.5rem)

pub fn py_2p5(self) -> Self

Sets the vertical padding of the element. Docs

10px (0.625rem)

pub fn py_neg_2p5(self) -> Self

Sets the vertical padding of the element. Docs

10px (0.625rem)

pub fn py_3(self) -> Self

Sets the vertical padding of the element. Docs

12px (0.75rem)

pub fn py_neg_3(self) -> Self

Sets the vertical padding of the element. Docs

12px (0.75rem)

pub fn py_3p5(self) -> Self

Sets the vertical padding of the element. Docs

14px (0.875rem)

pub fn py_neg_3p5(self) -> Self

Sets the vertical padding of the element. Docs

14px (0.875rem)

pub fn py_4(self) -> Self

Sets the vertical padding of the element. Docs

16px (1rem)

pub fn py_neg_4(self) -> Self

Sets the vertical padding of the element. Docs

16px (1rem)

pub fn py_5(self) -> Self

Sets the vertical padding of the element. Docs

20px (1.25rem)

pub fn py_neg_5(self) -> Self

Sets the vertical padding of the element. Docs

20px (1.25rem)

pub fn py_6(self) -> Self

Sets the vertical padding of the element. Docs

24px (1.5rem)

pub fn py_neg_6(self) -> Self

Sets the vertical padding of the element. Docs

24px (1.5rem)

pub fn py_7(self) -> Self

Sets the vertical padding of the element. Docs

28px (1.75rem)

pub fn py_neg_7(self) -> Self

Sets the vertical padding of the element. Docs

28px (1.75rem)

pub fn py_8(self) -> Self

Sets the vertical padding of the element. Docs

32px (2rem)

pub fn py_neg_8(self) -> Self

Sets the vertical padding of the element. Docs

32px (2rem)

pub fn py_9(self) -> Self

Sets the vertical padding of the element. Docs

36px (2.25rem)

pub fn py_neg_9(self) -> Self

Sets the vertical padding of the element. Docs

36px (2.25rem)

pub fn py_10(self) -> Self

Sets the vertical padding of the element. Docs

40px (2.5rem)

pub fn py_neg_10(self) -> Self

Sets the vertical padding of the element. Docs

40px (2.5rem)

pub fn py_11(self) -> Self

Sets the vertical padding of the element. Docs

44px (2.75rem)

pub fn py_neg_11(self) -> Self

Sets the vertical padding of the element. Docs

44px (2.75rem)

pub fn py_12(self) -> Self

Sets the vertical padding of the element. Docs

48px (3rem)

pub fn py_neg_12(self) -> Self

Sets the vertical padding of the element. Docs

48px (3rem)

pub fn py_16(self) -> Self

Sets the vertical padding of the element. Docs

64px (4rem)

pub fn py_neg_16(self) -> Self

Sets the vertical padding of the element. Docs

64px (4rem)

pub fn py_20(self) -> Self

Sets the vertical padding of the element. Docs

80px (5rem)

pub fn py_neg_20(self) -> Self

Sets the vertical padding of the element. Docs

80px (5rem)

pub fn py_24(self) -> Self

Sets the vertical padding of the element. Docs

96px (6rem)

pub fn py_neg_24(self) -> Self

Sets the vertical padding of the element. Docs

96px (6rem)

pub fn py_32(self) -> Self

Sets the vertical padding of the element. Docs

128px (8rem)

pub fn py_neg_32(self) -> Self

Sets the vertical padding of the element. Docs

128px (8rem)

pub fn py_40(self) -> Self

Sets the vertical padding of the element. Docs

160px (10rem)

pub fn py_neg_40(self) -> Self

Sets the vertical padding of the element. Docs

160px (10rem)

pub fn py_48(self) -> Self

Sets the vertical padding of the element. Docs

192px (12rem)

pub fn py_neg_48(self) -> Self

Sets the vertical padding of the element. Docs

192px (12rem)

pub fn py_56(self) -> Self

Sets the vertical padding of the element. Docs

224px (14rem)

pub fn py_neg_56(self) -> Self

Sets the vertical padding of the element. Docs

224px (14rem)

pub fn py_64(self) -> Self

Sets the vertical padding of the element. Docs

256px (16rem)

pub fn py_neg_64(self) -> Self

Sets the vertical padding of the element. Docs

256px (16rem)

pub fn py_72(self) -> Self

Sets the vertical padding of the element. Docs

288px (18rem)

pub fn py_neg_72(self) -> Self

Sets the vertical padding of the element. Docs

288px (18rem)

pub fn py_80(self) -> Self

Sets the vertical padding of the element. Docs

320px (20rem)

pub fn py_neg_80(self) -> Self

Sets the vertical padding of the element. Docs

320px (20rem)

pub fn py_96(self) -> Self

Sets the vertical padding of the element. Docs

384px (24rem)

pub fn py_neg_96(self) -> Self

Sets the vertical padding of the element. Docs

384px (24rem)

pub fn py_112(self) -> Self

Sets the vertical padding of the element. Docs

448px (28rem)

pub fn py_neg_112(self) -> Self

Sets the vertical padding of the element. Docs

448px (28rem)

pub fn py_128(self) -> Self

Sets the vertical padding of the element. Docs

512px (32rem)

pub fn py_neg_128(self) -> Self

Sets the vertical padding of the element. Docs

512px (32rem)

pub fn py_px(self) -> Self

Sets the vertical padding of the element. Docs

1px

pub fn py_neg_px(self) -> Self

Sets the vertical padding of the element. Docs

1px

pub fn py_full(self) -> Self

Sets the vertical padding of the element. Docs

100%

pub fn py_neg_full(self) -> Self

Sets the vertical padding of the element. Docs

100%

pub fn py_1_2(self) -> Self

Sets the vertical padding of the element. Docs

50% (1/2)

pub fn py_neg_1_2(self) -> Self

Sets the vertical padding of the element. Docs

50% (1/2)

pub fn py_1_3(self) -> Self

Sets the vertical padding of the element. Docs

33% (1/3)

pub fn py_neg_1_3(self) -> Self

Sets the vertical padding of the element. Docs

33% (1/3)

pub fn py_2_3(self) -> Self

Sets the vertical padding of the element. Docs

66% (2/3)

pub fn py_neg_2_3(self) -> Self

Sets the vertical padding of the element. Docs

66% (2/3)

pub fn py_1_4(self) -> Self

Sets the vertical padding of the element. Docs

25% (1/4)

pub fn py_neg_1_4(self) -> Self

Sets the vertical padding of the element. Docs

25% (1/4)

pub fn py_2_4(self) -> Self

Sets the vertical padding of the element. Docs

50% (2/4)

pub fn py_neg_2_4(self) -> Self

Sets the vertical padding of the element. Docs

50% (2/4)

pub fn py_3_4(self) -> Self

Sets the vertical padding of the element. Docs

75% (3/4)

pub fn py_neg_3_4(self) -> Self

Sets the vertical padding of the element. Docs

75% (3/4)

pub fn py_1_5(self) -> Self

Sets the vertical padding of the element. Docs

20% (1/5)

pub fn py_neg_1_5(self) -> Self

Sets the vertical padding of the element. Docs

20% (1/5)

pub fn py_2_5(self) -> Self

Sets the vertical padding of the element. Docs

40% (2/5)

pub fn py_neg_2_5(self) -> Self

Sets the vertical padding of the element. Docs

40% (2/5)

pub fn py_3_5(self) -> Self

Sets the vertical padding of the element. Docs

60% (3/5)

pub fn py_neg_3_5(self) -> Self

Sets the vertical padding of the element. Docs

60% (3/5)

pub fn py_4_5(self) -> Self

Sets the vertical padding of the element. Docs

80% (4/5)

pub fn py_neg_4_5(self) -> Self

Sets the vertical padding of the element. Docs

80% (4/5)

pub fn py_1_6(self) -> Self

Sets the vertical padding of the element. Docs

16% (1/6)

pub fn py_neg_1_6(self) -> Self

Sets the vertical padding of the element. Docs

16% (1/6)

pub fn py_5_6(self) -> Self

Sets the vertical padding of the element. Docs

80% (5/6)

pub fn py_neg_5_6(self) -> Self

Sets the vertical padding of the element. Docs

80% (5/6)

pub fn py_1_12(self) -> Self

Sets the vertical padding of the element. Docs

8% (1/12)

pub fn py_neg_1_12(self) -> Self

Sets the vertical padding of the element. Docs

8% (1/12)

pub fn pl(self, length: impl Clone + Into<DefiniteLength>) -> Self

Sets the left padding of the element. Docs

pub fn pl_0(self) -> Self

Sets the left padding of the element. Docs

0px

pub fn pl_neg_0(self) -> Self

Sets the left padding of the element. Docs

0px

pub fn pl_0p5(self) -> Self

Sets the left padding of the element. Docs

2px (0.125rem)

pub fn pl_neg_0p5(self) -> Self

Sets the left padding of the element. Docs

2px (0.125rem)

pub fn pl_1(self) -> Self

Sets the left padding of the element. Docs

4px (0.25rem)

pub fn pl_neg_1(self) -> Self

Sets the left padding of the element. Docs

4px (0.25rem)

pub fn pl_1p5(self) -> Self

Sets the left padding of the element. Docs

6px (0.375rem)

pub fn pl_neg_1p5(self) -> Self

Sets the left padding of the element. Docs

6px (0.375rem)

pub fn pl_2(self) -> Self

Sets the left padding of the element. Docs

8px (0.5rem)

pub fn pl_neg_2(self) -> Self

Sets the left padding of the element. Docs

8px (0.5rem)

pub fn pl_2p5(self) -> Self

Sets the left padding of the element. Docs

10px (0.625rem)

pub fn pl_neg_2p5(self) -> Self

Sets the left padding of the element. Docs

10px (0.625rem)

pub fn pl_3(self) -> Self

Sets the left padding of the element. Docs

12px (0.75rem)

pub fn pl_neg_3(self) -> Self

Sets the left padding of the element. Docs

12px (0.75rem)

pub fn pl_3p5(self) -> Self

Sets the left padding of the element. Docs

14px (0.875rem)

pub fn pl_neg_3p5(self) -> Self

Sets the left padding of the element. Docs

14px (0.875rem)

pub fn pl_4(self) -> Self

Sets the left padding of the element. Docs

16px (1rem)

pub fn pl_neg_4(self) -> Self

Sets the left padding of the element. Docs

16px (1rem)

pub fn pl_5(self) -> Self

Sets the left padding of the element. Docs

20px (1.25rem)

pub fn pl_neg_5(self) -> Self

Sets the left padding of the element. Docs

20px (1.25rem)

pub fn pl_6(self) -> Self

Sets the left padding of the element. Docs

24px (1.5rem)

pub fn pl_neg_6(self) -> Self

Sets the left padding of the element. Docs

24px (1.5rem)

pub fn pl_7(self) -> Self

Sets the left padding of the element. Docs

28px (1.75rem)

pub fn pl_neg_7(self) -> Self

Sets the left padding of the element. Docs

28px (1.75rem)

pub fn pl_8(self) -> Self

Sets the left padding of the element. Docs

32px (2rem)

pub fn pl_neg_8(self) -> Self

Sets the left padding of the element. Docs

32px (2rem)

pub fn pl_9(self) -> Self

Sets the left padding of the element. Docs

36px (2.25rem)

pub fn pl_neg_9(self) -> Self

Sets the left padding of the element. Docs

36px (2.25rem)

pub fn pl_10(self) -> Self

Sets the left padding of the element. Docs

40px (2.5rem)

pub fn pl_neg_10(self) -> Self

Sets the left padding of the element. Docs

40px (2.5rem)

pub fn pl_11(self) -> Self

Sets the left padding of the element. Docs

44px (2.75rem)

pub fn pl_neg_11(self) -> Self

Sets the left padding of the element. Docs

44px (2.75rem)

pub fn pl_12(self) -> Self

Sets the left padding of the element. Docs

48px (3rem)

pub fn pl_neg_12(self) -> Self

Sets the left padding of the element. Docs

48px (3rem)

pub fn pl_16(self) -> Self

Sets the left padding of the element. Docs

64px (4rem)

pub fn pl_neg_16(self) -> Self

Sets the left padding of the element. Docs

64px (4rem)

pub fn pl_20(self) -> Self

Sets the left padding of the element. Docs

80px (5rem)

pub fn pl_neg_20(self) -> Self

Sets the left padding of the element. Docs

80px (5rem)

pub fn pl_24(self) -> Self

Sets the left padding of the element. Docs

96px (6rem)

pub fn pl_neg_24(self) -> Self

Sets the left padding of the element. Docs

96px (6rem)

pub fn pl_32(self) -> Self

Sets the left padding of the element. Docs

128px (8rem)

pub fn pl_neg_32(self) -> Self

Sets the left padding of the element. Docs

128px (8rem)

pub fn pl_40(self) -> Self

Sets the left padding of the element. Docs

160px (10rem)

pub fn pl_neg_40(self) -> Self

Sets the left padding of the element. Docs

160px (10rem)

pub fn pl_48(self) -> Self

Sets the left padding of the element. Docs

192px (12rem)

pub fn pl_neg_48(self) -> Self

Sets the left padding of the element. Docs

192px (12rem)

pub fn pl_56(self) -> Self

Sets the left padding of the element. Docs

224px (14rem)

pub fn pl_neg_56(self) -> Self

Sets the left padding of the element. Docs

224px (14rem)

pub fn pl_64(self) -> Self

Sets the left padding of the element. Docs

256px (16rem)

pub fn pl_neg_64(self) -> Self

Sets the left padding of the element. Docs

256px (16rem)

pub fn pl_72(self) -> Self

Sets the left padding of the element. Docs

288px (18rem)

pub fn pl_neg_72(self) -> Self

Sets the left padding of the element. Docs

288px (18rem)

pub fn pl_80(self) -> Self

Sets the left padding of the element. Docs

320px (20rem)

pub fn pl_neg_80(self) -> Self

Sets the left padding of the element. Docs

320px (20rem)

pub fn pl_96(self) -> Self

Sets the left padding of the element. Docs

384px (24rem)

pub fn pl_neg_96(self) -> Self

Sets the left padding of the element. Docs

384px (24rem)

pub fn pl_112(self) -> Self

Sets the left padding of the element. Docs

448px (28rem)

pub fn pl_neg_112(self) -> Self

Sets the left padding of the element. Docs

448px (28rem)

pub fn pl_128(self) -> Self

Sets the left padding of the element. Docs

512px (32rem)

pub fn pl_neg_128(self) -> Self

Sets the left padding of the element. Docs

512px (32rem)

pub fn pl_px(self) -> Self

Sets the left padding of the element. Docs

1px

pub fn pl_neg_px(self) -> Self

Sets the left padding of the element. Docs

1px

pub fn pl_full(self) -> Self

Sets the left padding of the element. Docs

100%

pub fn pl_neg_full(self) -> Self

Sets the left padding of the element. Docs

100%

pub fn pl_1_2(self) -> Self

Sets the left padding of the element. Docs

50% (1/2)

pub fn pl_neg_1_2(self) -> Self

Sets the left padding of the element. Docs

50% (1/2)

pub fn pl_1_3(self) -> Self

Sets the left padding of the element. Docs

33% (1/3)

pub fn pl_neg_1_3(self) -> Self

Sets the left padding of the element. Docs

33% (1/3)

pub fn pl_2_3(self) -> Self

Sets the left padding of the element. Docs

66% (2/3)

pub fn pl_neg_2_3(self) -> Self

Sets the left padding of the element. Docs

66% (2/3)

pub fn pl_1_4(self) -> Self

Sets the left padding of the element. Docs

25% (1/4)

pub fn pl_neg_1_4(self) -> Self

Sets the left padding of the element. Docs

25% (1/4)

pub fn pl_2_4(self) -> Self

Sets the left padding of the element. Docs

50% (2/4)

pub fn pl_neg_2_4(self) -> Self

Sets the left padding of the element. Docs

50% (2/4)

pub fn pl_3_4(self) -> Self

Sets the left padding of the element. Docs

75% (3/4)

pub fn pl_neg_3_4(self) -> Self

Sets the left padding of the element. Docs

75% (3/4)

pub fn pl_1_5(self) -> Self

Sets the left padding of the element. Docs

20% (1/5)

pub fn pl_neg_1_5(self) -> Self

Sets the left padding of the element. Docs

20% (1/5)

pub fn pl_2_5(self) -> Self

Sets the left padding of the element. Docs

40% (2/5)

pub fn pl_neg_2_5(self) -> Self

Sets the left padding of the element. Docs

40% (2/5)

pub fn pl_3_5(self) -> Self

Sets the left padding of the element. Docs

60% (3/5)

pub fn pl_neg_3_5(self) -> Self

Sets the left padding of the element. Docs

60% (3/5)

pub fn pl_4_5(self) -> Self

Sets the left padding of the element. Docs

80% (4/5)

pub fn pl_neg_4_5(self) -> Self

Sets the left padding of the element. Docs

80% (4/5)

pub fn pl_1_6(self) -> Self

Sets the left padding of the element. Docs

16% (1/6)

pub fn pl_neg_1_6(self) -> Self

Sets the left padding of the element. Docs

16% (1/6)

pub fn pl_5_6(self) -> Self

Sets the left padding of the element. Docs

80% (5/6)

pub fn pl_neg_5_6(self) -> Self

Sets the left padding of the element. Docs

80% (5/6)

pub fn pl_1_12(self) -> Self

Sets the left padding of the element. Docs

8% (1/12)

pub fn pl_neg_1_12(self) -> Self

Sets the left padding of the element. Docs

8% (1/12)

pub fn pr(self, length: impl Clone + Into<DefiniteLength>) -> Self

Sets the right padding of the element. Docs

pub fn pr_0(self) -> Self

Sets the right padding of the element. Docs

0px

pub fn pr_neg_0(self) -> Self

Sets the right padding of the element. Docs

0px

pub fn pr_0p5(self) -> Self

Sets the right padding of the element. Docs

2px (0.125rem)

pub fn pr_neg_0p5(self) -> Self

Sets the right padding of the element. Docs

2px (0.125rem)

pub fn pr_1(self) -> Self

Sets the right padding of the element. Docs

4px (0.25rem)

pub fn pr_neg_1(self) -> Self

Sets the right padding of the element. Docs

4px (0.25rem)

pub fn pr_1p5(self) -> Self

Sets the right padding of the element. Docs

6px (0.375rem)

pub fn pr_neg_1p5(self) -> Self

Sets the right padding of the element. Docs

6px (0.375rem)

pub fn pr_2(self) -> Self

Sets the right padding of the element. Docs

8px (0.5rem)

pub fn pr_neg_2(self) -> Self

Sets the right padding of the element. Docs

8px (0.5rem)

pub fn pr_2p5(self) -> Self

Sets the right padding of the element. Docs

10px (0.625rem)

pub fn pr_neg_2p5(self) -> Self

Sets the right padding of the element. Docs

10px (0.625rem)

pub fn pr_3(self) -> Self

Sets the right padding of the element. Docs

12px (0.75rem)

pub fn pr_neg_3(self) -> Self

Sets the right padding of the element. Docs

12px (0.75rem)

pub fn pr_3p5(self) -> Self

Sets the right padding of the element. Docs

14px (0.875rem)

pub fn pr_neg_3p5(self) -> Self

Sets the right padding of the element. Docs

14px (0.875rem)

pub fn pr_4(self) -> Self

Sets the right padding of the element. Docs

16px (1rem)

pub fn pr_neg_4(self) -> Self

Sets the right padding of the element. Docs

16px (1rem)

pub fn pr_5(self) -> Self

Sets the right padding of the element. Docs

20px (1.25rem)

pub fn pr_neg_5(self) -> Self

Sets the right padding of the element. Docs

20px (1.25rem)

pub fn pr_6(self) -> Self

Sets the right padding of the element. Docs

24px (1.5rem)

pub fn pr_neg_6(self) -> Self

Sets the right padding of the element. Docs

24px (1.5rem)

pub fn pr_7(self) -> Self

Sets the right padding of the element. Docs

28px (1.75rem)

pub fn pr_neg_7(self) -> Self

Sets the right padding of the element. Docs

28px (1.75rem)

pub fn pr_8(self) -> Self

Sets the right padding of the element. Docs

32px (2rem)

pub fn pr_neg_8(self) -> Self

Sets the right padding of the element. Docs

32px (2rem)

pub fn pr_9(self) -> Self

Sets the right padding of the element. Docs

36px (2.25rem)

pub fn pr_neg_9(self) -> Self

Sets the right padding of the element. Docs

36px (2.25rem)

pub fn pr_10(self) -> Self

Sets the right padding of the element. Docs

40px (2.5rem)

pub fn pr_neg_10(self) -> Self

Sets the right padding of the element. Docs

40px (2.5rem)

pub fn pr_11(self) -> Self

Sets the right padding of the element. Docs

44px (2.75rem)

pub fn pr_neg_11(self) -> Self

Sets the right padding of the element. Docs

44px (2.75rem)

pub fn pr_12(self) -> Self

Sets the right padding of the element. Docs

48px (3rem)

pub fn pr_neg_12(self) -> Self

Sets the right padding of the element. Docs

48px (3rem)

pub fn pr_16(self) -> Self

Sets the right padding of the element. Docs

64px (4rem)

pub fn pr_neg_16(self) -> Self

Sets the right padding of the element. Docs

64px (4rem)

pub fn pr_20(self) -> Self

Sets the right padding of the element. Docs

80px (5rem)

pub fn pr_neg_20(self) -> Self

Sets the right padding of the element. Docs

80px (5rem)

pub fn pr_24(self) -> Self

Sets the right padding of the element. Docs

96px (6rem)

pub fn pr_neg_24(self) -> Self

Sets the right padding of the element. Docs

96px (6rem)

pub fn pr_32(self) -> Self

Sets the right padding of the element. Docs

128px (8rem)

pub fn pr_neg_32(self) -> Self

Sets the right padding of the element. Docs

128px (8rem)

pub fn pr_40(self) -> Self

Sets the right padding of the element. Docs

160px (10rem)

pub fn pr_neg_40(self) -> Self

Sets the right padding of the element. Docs

160px (10rem)

pub fn pr_48(self) -> Self

Sets the right padding of the element. Docs

192px (12rem)

pub fn pr_neg_48(self) -> Self

Sets the right padding of the element. Docs

192px (12rem)

pub fn pr_56(self) -> Self

Sets the right padding of the element. Docs

224px (14rem)

pub fn pr_neg_56(self) -> Self

Sets the right padding of the element. Docs

224px (14rem)

pub fn pr_64(self) -> Self

Sets the right padding of the element. Docs

256px (16rem)

pub fn pr_neg_64(self) -> Self

Sets the right padding of the element. Docs

256px (16rem)

pub fn pr_72(self) -> Self

Sets the right padding of the element. Docs

288px (18rem)

pub fn pr_neg_72(self) -> Self

Sets the right padding of the element. Docs

288px (18rem)

pub fn pr_80(self) -> Self

Sets the right padding of the element. Docs

320px (20rem)

pub fn pr_neg_80(self) -> Self

Sets the right padding of the element. Docs

320px (20rem)

pub fn pr_96(self) -> Self

Sets the right padding of the element. Docs

384px (24rem)

pub fn pr_neg_96(self) -> Self

Sets the right padding of the element. Docs

384px (24rem)

pub fn pr_112(self) -> Self

Sets the right padding of the element. Docs

448px (28rem)

pub fn pr_neg_112(self) -> Self

Sets the right padding of the element. Docs

448px (28rem)

pub fn pr_128(self) -> Self

Sets the right padding of the element. Docs

512px (32rem)

pub fn pr_neg_128(self) -> Self

Sets the right padding of the element. Docs

512px (32rem)

pub fn pr_px(self) -> Self

Sets the right padding of the element. Docs

1px

pub fn pr_neg_px(self) -> Self

Sets the right padding of the element. Docs

1px

pub fn pr_full(self) -> Self

Sets the right padding of the element. Docs

100%

pub fn pr_neg_full(self) -> Self

Sets the right padding of the element. Docs

100%

pub fn pr_1_2(self) -> Self

Sets the right padding of the element. Docs

50% (1/2)

pub fn pr_neg_1_2(self) -> Self

Sets the right padding of the element. Docs

50% (1/2)

pub fn pr_1_3(self) -> Self

Sets the right padding of the element. Docs

33% (1/3)

pub fn pr_neg_1_3(self) -> Self

Sets the right padding of the element. Docs

33% (1/3)

pub fn pr_2_3(self) -> Self

Sets the right padding of the element. Docs

66% (2/3)

pub fn pr_neg_2_3(self) -> Self

Sets the right padding of the element. Docs

66% (2/3)

pub fn pr_1_4(self) -> Self

Sets the right padding of the element. Docs

25% (1/4)

pub fn pr_neg_1_4(self) -> Self

Sets the right padding of the element. Docs

25% (1/4)

pub fn pr_2_4(self) -> Self

Sets the right padding of the element. Docs

50% (2/4)

pub fn pr_neg_2_4(self) -> Self

Sets the right padding of the element. Docs

50% (2/4)

pub fn pr_3_4(self) -> Self

Sets the right padding of the element. Docs

75% (3/4)

pub fn pr_neg_3_4(self) -> Self

Sets the right padding of the element. Docs

75% (3/4)

pub fn pr_1_5(self) -> Self

Sets the right padding of the element. Docs

20% (1/5)

pub fn pr_neg_1_5(self) -> Self

Sets the right padding of the element. Docs

20% (1/5)

pub fn pr_2_5(self) -> Self

Sets the right padding of the element. Docs

40% (2/5)

pub fn pr_neg_2_5(self) -> Self

Sets the right padding of the element. Docs

40% (2/5)

pub fn pr_3_5(self) -> Self

Sets the right padding of the element. Docs

60% (3/5)

pub fn pr_neg_3_5(self) -> Self

Sets the right padding of the element. Docs

60% (3/5)

pub fn pr_4_5(self) -> Self

Sets the right padding of the element. Docs

80% (4/5)

pub fn pr_neg_4_5(self) -> Self

Sets the right padding of the element. Docs

80% (4/5)

pub fn pr_1_6(self) -> Self

Sets the right padding of the element. Docs

16% (1/6)

pub fn pr_neg_1_6(self) -> Self

Sets the right padding of the element. Docs

16% (1/6)

pub fn pr_5_6(self) -> Self

Sets the right padding of the element. Docs

80% (5/6)

pub fn pr_neg_5_6(self) -> Self

Sets the right padding of the element. Docs

80% (5/6)

pub fn pr_1_12(self) -> Self

Sets the right padding of the element. Docs

8% (1/12)

pub fn pr_neg_1_12(self) -> Self

Sets the right padding of the element. Docs

8% (1/12)