pub struct IconDecoration { /* private fields */ }Expand description
The decoration for an icon.
For example, this can show an indicator, an “x”, or a diagonal strikethrough to indicate something is disabled.
Implementations
Sourceimpl IconDecoration
impl IconDecoration
Sourcepub fn new(kind: IconDecorationKind, knockout_color: Hsla, cx: &App) -> Self
pub fn new(kind: IconDecorationKind, knockout_color: Hsla, cx: &App) -> Self
Creates a new IconDecoration.
Sourcepub fn kind(self, kind: IconDecorationKind) -> Self
pub fn kind(self, kind: IconDecorationKind) -> Self
Sets the kind of decoration.
Sourcepub fn knockout_color(self, color: Hsla) -> Self
pub fn knockout_color(self, color: Hsla) -> Self
Sets the color of the decoration’s knockout
Match this to the background of the element the icon will be rendered on.
Sourcepub fn knockout_hover_color(self, color: Hsla) -> Self
pub fn knockout_hover_color(self, color: Hsla) -> Self
Sets the color of the decoration that is used on hover.
Sourcepub fn group_name(self, name: Option<SharedString>) -> Self
pub fn group_name(self, name: Option<SharedString>) -> Self
Sets the name of the group the decoration belongs to