pub struct KeyBinding { /* private fields */ }Implementations
Sourceimpl KeyBinding
impl KeyBinding
Sourcepub fn for_action(action: &dyn Action, cx: &App) -> Self
pub fn for_action(action: &dyn Action, cx: &App) -> Self
Returns the highest precedence keybinding for an action. This is the last binding added to the keymap. User bindings are added after built-in bindings so that they take precedence.
Sourcepub fn for_action_in(action: &dyn Action, focus: &FocusHandle, cx: &App) -> Self
pub fn for_action_in(action: &dyn Action, focus: &FocusHandle, cx: &App) -> Self
Like for_action, but lets you specify the context from which keybindings are matched.
pub fn has_binding(&self, window: &Window) -> bool
pub fn set_vim_mode(cx: &mut App, enabled: bool)
pub fn new( action: &dyn Action, focus_handle: Option<FocusHandle>, cx: &App, ) -> Self
pub fn from_keystrokes( keystrokes: Rc<[KeybindingKeystroke]>, vim_mode: bool, ) -> Self
Sourcepub fn platform_style(self, platform_style: PlatformStyle) -> Self
pub fn platform_style(self, platform_style: PlatformStyle) -> Self
Sets the PlatformStyle for this KeyBinding.
Sourcepub fn size(self, size: impl Into<AbsoluteLength>) -> Self
pub fn size(self, size: impl Into<AbsoluteLength>) -> Self
Sets the size for this KeyBinding.