Label

Struct Label 

pub struct Label { /* private fields */ }
A struct representing a label element in the UI.

The Label struct stores the label text and common properties for a label element. It provides methods for modifying these properties.

Examples

use ui::prelude::*;

Label::new("Hello, World!");

A colored label, for example labeling a dangerous action:

use ui::prelude::*;

let my_label = Label::new("Delete").color(Color::Error);

A label with a strikethrough, for example labeling something that has been deleted:

use ui::prelude::*;

let my_label = Label::new("Deleted").strikethrough();

Implementations

Source

impl Label

pub fn new(label: impl Into<SharedString>) -> Self

Creates a new Label with the given text.

Examples
use ui::prelude::*;

let my_label = Label::new("Hello, World!");
pub fn render_code_spans(self) -> Self

When enabled, text wrapped in backticks (e.g. `code`) will be rendered in the buffer (monospace) font.

pub fn set_text(&mut self, text: impl Into<SharedString>)

Sets the text of the Label.

pub fn truncate_start(self) -> Self

Truncates the label from the start, keeping the end visible.

Source

impl Label

pub fn m(self, length: impl Clone + Into<Length>) -> Self

Sets the margin of the element. Docs

pub fn m_0(self) -> Self

Sets the margin of the element. Docs

0px

pub fn m_neg_0(self) -> Self

Sets the margin of the element. Docs

0px

pub fn m_0p5(self) -> Self

Sets the margin of the element. Docs

2px (0.125rem)

pub fn m_neg_0p5(self) -> Self

Sets the margin of the element. Docs

2px (0.125rem)

pub fn m_1(self) -> Self

Sets the margin of the element. Docs

4px (0.25rem)

pub fn m_neg_1(self) -> Self

Sets the margin of the element. Docs

4px (0.25rem)

pub fn m_1p5(self) -> Self

Sets the margin of the element. Docs

6px (0.375rem)

pub fn m_neg_1p5(self) -> Self

Sets the margin of the element. Docs

6px (0.375rem)

pub fn m_2(self) -> Self

Sets the margin of the element. Docs

8px (0.5rem)

pub fn m_neg_2(self) -> Self

Sets the margin of the element. Docs

8px (0.5rem)

pub fn m_2p5(self) -> Self

Sets the margin of the element. Docs

10px (0.625rem)

pub fn m_neg_2p5(self) -> Self

Sets the margin of the element. Docs

10px (0.625rem)

pub fn m_3(self) -> Self

Sets the margin of the element. Docs

12px (0.75rem)

pub fn m_neg_3(self) -> Self

Sets the margin of the element. Docs

12px (0.75rem)

pub fn m_3p5(self) -> Self

Sets the margin of the element. Docs

14px (0.875rem)

pub fn m_neg_3p5(self) -> Self

Sets the margin of the element. Docs

14px (0.875rem)

pub fn m_4(self) -> Self

Sets the margin of the element. Docs

16px (1rem)

pub fn m_neg_4(self) -> Self

Sets the margin of the element. Docs

16px (1rem)

pub fn m_5(self) -> Self

Sets the margin of the element. Docs

20px (1.25rem)

pub fn m_neg_5(self) -> Self

Sets the margin of the element. Docs

20px (1.25rem)

pub fn m_6(self) -> Self

Sets the margin of the element. Docs

24px (1.5rem)

pub fn m_neg_6(self) -> Self

Sets the margin of the element. Docs

24px (1.5rem)

pub fn m_7(self) -> Self

Sets the margin of the element. Docs

28px (1.75rem)

pub fn m_neg_7(self) -> Self

Sets the margin of the element. Docs

28px (1.75rem)

pub fn m_8(self) -> Self

Sets the margin of the element. Docs

32px (2rem)

pub fn m_neg_8(self) -> Self

Sets the margin of the element. Docs

32px (2rem)

pub fn m_9(self) -> Self

Sets the margin of the element. Docs

36px (2.25rem)

pub fn m_neg_9(self) -> Self

Sets the margin of the element. Docs

36px (2.25rem)

pub fn m_10(self) -> Self

Sets the margin of the element. Docs

40px (2.5rem)

pub fn m_neg_10(self) -> Self

Sets the margin of the element. Docs

40px (2.5rem)

pub fn m_11(self) -> Self

Sets the margin of the element. Docs

44px (2.75rem)

pub fn m_neg_11(self) -> Self

Sets the margin of the element. Docs

44px (2.75rem)

pub fn m_12(self) -> Self

Sets the margin of the element. Docs

48px (3rem)

pub fn m_neg_12(self) -> Self

Sets the margin of the element. Docs

48px (3rem)

pub fn m_16(self) -> Self

Sets the margin of the element. Docs

64px (4rem)

pub fn m_neg_16(self) -> Self

Sets the margin of the element. Docs

64px (4rem)

pub fn m_20(self) -> Self

Sets the margin of the element. Docs

80px (5rem)

pub fn m_neg_20(self) -> Self

Sets the margin of the element. Docs

80px (5rem)

pub fn m_24(self) -> Self

Sets the margin of the element. Docs

96px (6rem)

pub fn m_neg_24(self) -> Self

Sets the margin of the element. Docs

96px (6rem)

pub fn m_32(self) -> Self

Sets the margin of the element. Docs

128px (8rem)

pub fn m_neg_32(self) -> Self

Sets the margin of the element. Docs

128px (8rem)

pub fn m_40(self) -> Self

Sets the margin of the element. Docs

160px (10rem)

pub fn m_neg_40(self) -> Self

Sets the margin of the element. Docs

160px (10rem)

pub fn m_48(self) -> Self

Sets the margin of the element. Docs

192px (12rem)

pub fn m_neg_48(self) -> Self

Sets the margin of the element. Docs

192px (12rem)

pub fn m_56(self) -> Self

Sets the margin of the element. Docs

224px (14rem)

pub fn m_neg_56(self) -> Self

Sets the margin of the element. Docs

224px (14rem)

pub fn m_64(self) -> Self

Sets the margin of the element. Docs

256px (16rem)

pub fn m_neg_64(self) -> Self

Sets the margin of the element. Docs

256px (16rem)

pub fn m_72(self) -> Self

Sets the margin of the element. Docs

288px (18rem)

pub fn m_neg_72(self) -> Self

Sets the margin of the element. Docs

288px (18rem)

pub fn m_80(self) -> Self

Sets the margin of the element. Docs

320px (20rem)

pub fn m_neg_80(self) -> Self

Sets the margin of the element. Docs

320px (20rem)

pub fn m_96(self) -> Self

Sets the margin of the element. Docs

384px (24rem)

pub fn m_neg_96(self) -> Self

Sets the margin of the element. Docs

384px (24rem)

pub fn m_112(self) -> Self

Sets the margin of the element. Docs

448px (28rem)

pub fn m_neg_112(self) -> Self

Sets the margin of the element. Docs

448px (28rem)

pub fn m_128(self) -> Self

Sets the margin of the element. Docs

512px (32rem)

pub fn m_neg_128(self) -> Self

Sets the margin of the element. Docs

512px (32rem)

pub fn m_auto(self) -> Self

Sets the margin of the element. Docs

Auto

pub fn m_px(self) -> Self

Sets the margin of the element. Docs

1px

pub fn m_neg_px(self) -> Self

Sets the margin of the element. Docs

1px

pub fn m_full(self) -> Self

Sets the margin of the element. Docs

100%

pub fn m_neg_full(self) -> Self

Sets the margin of the element. Docs

100%

pub fn m_1_2(self) -> Self

Sets the margin of the element. Docs

50% (1/2)

pub fn m_neg_1_2(self) -> Self

Sets the margin of the element. Docs

50% (1/2)

pub fn m_1_3(self) -> Self

Sets the margin of the element. Docs

33% (1/3)

pub fn m_neg_1_3(self) -> Self

Sets the margin of the element. Docs

33% (1/3)

pub fn m_2_3(self) -> Self

Sets the margin of the element. Docs

66% (2/3)

pub fn m_neg_2_3(self) -> Self

Sets the margin of the element. Docs

66% (2/3)

pub fn m_1_4(self) -> Self

Sets the margin of the element. Docs

25% (1/4)

pub fn m_neg_1_4(self) -> Self

Sets the margin of the element. Docs

25% (1/4)

pub fn m_2_4(self) -> Self

Sets the margin of the element. Docs

50% (2/4)

pub fn m_neg_2_4(self) -> Self

Sets the margin of the element. Docs

50% (2/4)

pub fn m_3_4(self) -> Self

Sets the margin of the element. Docs

75% (3/4)

pub fn m_neg_3_4(self) -> Self

Sets the margin of the element. Docs

75% (3/4)

pub fn m_1_5(self) -> Self

Sets the margin of the element. Docs

20% (1/5)

pub fn m_neg_1_5(self) -> Self

Sets the margin of the element. Docs

20% (1/5)

pub fn m_2_5(self) -> Self

Sets the margin of the element. Docs

40% (2/5)

pub fn m_neg_2_5(self) -> Self

Sets the margin of the element. Docs

40% (2/5)

pub fn m_3_5(self) -> Self

Sets the margin of the element. Docs

60% (3/5)

pub fn m_neg_3_5(self) -> Self

Sets the margin of the element. Docs

60% (3/5)

pub fn m_4_5(self) -> Self

Sets the margin of the element. Docs

80% (4/5)

pub fn m_neg_4_5(self) -> Self

Sets the margin of the element. Docs

80% (4/5)

pub fn m_1_6(self) -> Self

Sets the margin of the element. Docs

16% (1/6)

pub fn m_neg_1_6(self) -> Self

Sets the margin of the element. Docs

16% (1/6)

pub fn m_5_6(self) -> Self

Sets the margin of the element. Docs

80% (5/6)

pub fn m_neg_5_6(self) -> Self

Sets the margin of the element. Docs

80% (5/6)

pub fn m_1_12(self) -> Self

Sets the margin of the element. Docs

8% (1/12)

pub fn m_neg_1_12(self) -> Self

Sets the margin of the element. Docs

8% (1/12)

pub fn mt(self, length: impl Clone + Into<Length>) -> Self

Sets the top margin of the element. Docs

pub fn mt_0(self) -> Self

Sets the top margin of the element. Docs

0px

pub fn mt_neg_0(self) -> Self

Sets the top margin of the element. Docs

0px

pub fn mt_0p5(self) -> Self

Sets the top margin of the element. Docs

2px (0.125rem)

pub fn mt_neg_0p5(self) -> Self

Sets the top margin of the element. Docs

2px (0.125rem)

pub fn mt_1(self) -> Self

Sets the top margin of the element. Docs

4px (0.25rem)

pub fn mt_neg_1(self) -> Self

Sets the top margin of the element. Docs

4px (0.25rem)

pub fn mt_1p5(self) -> Self

Sets the top margin of the element. Docs

6px (0.375rem)

pub fn mt_neg_1p5(self) -> Self

Sets the top margin of the element. Docs

6px (0.375rem)

pub fn mt_2(self) -> Self

Sets the top margin of the element. Docs

8px (0.5rem)

pub fn mt_neg_2(self) -> Self

Sets the top margin of the element. Docs

8px (0.5rem)

pub fn mt_2p5(self) -> Self

Sets the top margin of the element. Docs

10px (0.625rem)

pub fn mt_neg_2p5(self) -> Self

Sets the top margin of the element. Docs

10px (0.625rem)

pub fn mt_3(self) -> Self

Sets the top margin of the element. Docs

12px (0.75rem)

pub fn mt_neg_3(self) -> Self

Sets the top margin of the element. Docs

12px (0.75rem)

pub fn mt_3p5(self) -> Self

Sets the top margin of the element. Docs

14px (0.875rem)

pub fn mt_neg_3p5(self) -> Self

Sets the top margin of the element. Docs

14px (0.875rem)

pub fn mt_4(self) -> Self

Sets the top margin of the element. Docs

16px (1rem)

pub fn mt_neg_4(self) -> Self

Sets the top margin of the element. Docs

16px (1rem)

pub fn mt_5(self) -> Self

Sets the top margin of the element. Docs

20px (1.25rem)

pub fn mt_neg_5(self) -> Self

Sets the top margin of the element. Docs

20px (1.25rem)

pub fn mt_6(self) -> Self

Sets the top margin of the element. Docs

24px (1.5rem)

pub fn mt_neg_6(self) -> Self

Sets the top margin of the element. Docs

24px (1.5rem)

pub fn mt_7(self) -> Self

Sets the top margin of the element. Docs

28px (1.75rem)

pub fn mt_neg_7(self) -> Self

Sets the top margin of the element. Docs

28px (1.75rem)

pub fn mt_8(self) -> Self

Sets the top margin of the element. Docs

32px (2rem)

pub fn mt_neg_8(self) -> Self

Sets the top margin of the element. Docs

32px (2rem)

pub fn mt_9(self) -> Self

Sets the top margin of the element. Docs

36px (2.25rem)

pub fn mt_neg_9(self) -> Self

Sets the top margin of the element. Docs

36px (2.25rem)

pub fn mt_10(self) -> Self

Sets the top margin of the element. Docs

40px (2.5rem)

pub fn mt_neg_10(self) -> Self

Sets the top margin of the element. Docs

40px (2.5rem)

pub fn mt_11(self) -> Self

Sets the top margin of the element. Docs

44px (2.75rem)

pub fn mt_neg_11(self) -> Self

Sets the top margin of the element. Docs

44px (2.75rem)

pub fn mt_12(self) -> Self

Sets the top margin of the element. Docs

48px (3rem)

pub fn mt_neg_12(self) -> Self

Sets the top margin of the element. Docs

48px (3rem)

pub fn mt_16(self) -> Self

Sets the top margin of the element. Docs

64px (4rem)

pub fn mt_neg_16(self) -> Self

Sets the top margin of the element. Docs

64px (4rem)

pub fn mt_20(self) -> Self

Sets the top margin of the element. Docs

80px (5rem)

pub fn mt_neg_20(self) -> Self

Sets the top margin of the element. Docs

80px (5rem)

pub fn mt_24(self) -> Self

Sets the top margin of the element. Docs

96px (6rem)

pub fn mt_neg_24(self) -> Self

Sets the top margin of the element. Docs

96px (6rem)

pub fn mt_32(self) -> Self

Sets the top margin of the element. Docs

128px (8rem)

pub fn mt_neg_32(self) -> Self

Sets the top margin of the element. Docs

128px (8rem)

pub fn mt_40(self) -> Self

Sets the top margin of the element. Docs

160px (10rem)

pub fn mt_neg_40(self) -> Self

Sets the top margin of the element. Docs

160px (10rem)

pub fn mt_48(self) -> Self

Sets the top margin of the element. Docs

192px (12rem)

pub fn mt_neg_48(self) -> Self

Sets the top margin of the element. Docs

192px (12rem)

pub fn mt_56(self) -> Self

Sets the top margin of the element. Docs

224px (14rem)

pub fn mt_neg_56(self) -> Self

Sets the top margin of the element. Docs

224px (14rem)

pub fn mt_64(self) -> Self

Sets the top margin of the element. Docs

256px (16rem)

pub fn mt_neg_64(self) -> Self

Sets the top margin of the element. Docs

256px (16rem)

pub fn mt_72(self) -> Self

Sets the top margin of the element. Docs

288px (18rem)

pub fn mt_neg_72(self) -> Self

Sets the top margin of the element. Docs

288px (18rem)

pub fn mt_80(self) -> Self

Sets the top margin of the element. Docs

320px (20rem)

pub fn mt_neg_80(self) -> Self

Sets the top margin of the element. Docs

320px (20rem)

pub fn mt_96(self) -> Self

Sets the top margin of the element. Docs

384px (24rem)

pub fn mt_neg_96(self) -> Self

Sets the top margin of the element. Docs

384px (24rem)

pub fn mt_112(self) -> Self

Sets the top margin of the element. Docs

448px (28rem)

pub fn mt_neg_112(self) -> Self

Sets the top margin of the element. Docs

448px (28rem)

pub fn mt_128(self) -> Self

Sets the top margin of the element. Docs

512px (32rem)

pub fn mt_neg_128(self) -> Self

Sets the top margin of the element. Docs

512px (32rem)

pub fn mt_auto(self) -> Self

Sets the top margin of the element. Docs

Auto

pub fn mt_px(self) -> Self

Sets the top margin of the element. Docs

1px

pub fn mt_neg_px(self) -> Self

Sets the top margin of the element. Docs

1px

pub fn mt_full(self) -> Self

Sets the top margin of the element. Docs

100%

pub fn mt_neg_full(self) -> Self

Sets the top margin of the element. Docs

100%

pub fn mt_1_2(self) -> Self

Sets the top margin of the element. Docs

50% (1/2)

pub fn mt_neg_1_2(self) -> Self

Sets the top margin of the element. Docs

50% (1/2)

pub fn mt_1_3(self) -> Self

Sets the top margin of the element. Docs

33% (1/3)

pub fn mt_neg_1_3(self) -> Self

Sets the top margin of the element. Docs

33% (1/3)

pub fn mt_2_3(self) -> Self

Sets the top margin of the element. Docs

66% (2/3)

pub fn mt_neg_2_3(self) -> Self

Sets the top margin of the element. Docs

66% (2/3)

pub fn mt_1_4(self) -> Self

Sets the top margin of the element. Docs

25% (1/4)

pub fn mt_neg_1_4(self) -> Self

Sets the top margin of the element. Docs

25% (1/4)

pub fn mt_2_4(self) -> Self

Sets the top margin of the element. Docs

50% (2/4)

pub fn mt_neg_2_4(self) -> Self

Sets the top margin of the element. Docs

50% (2/4)

pub fn mt_3_4(self) -> Self

Sets the top margin of the element. Docs

75% (3/4)

pub fn mt_neg_3_4(self) -> Self

Sets the top margin of the element. Docs

75% (3/4)

pub fn mt_1_5(self) -> Self

Sets the top margin of the element. Docs

20% (1/5)

pub fn mt_neg_1_5(self) -> Self

Sets the top margin of the element. Docs

20% (1/5)

pub fn mt_2_5(self) -> Self

Sets the top margin of the element. Docs

40% (2/5)

pub fn mt_neg_2_5(self) -> Self

Sets the top margin of the element. Docs

40% (2/5)

pub fn mt_3_5(self) -> Self

Sets the top margin of the element. Docs

60% (3/5)

pub fn mt_neg_3_5(self) -> Self

Sets the top margin of the element. Docs

60% (3/5)

pub fn mt_4_5(self) -> Self

Sets the top margin of the element. Docs

80% (4/5)

pub fn mt_neg_4_5(self) -> Self

Sets the top margin of the element. Docs

80% (4/5)

pub fn mt_1_6(self) -> Self

Sets the top margin of the element. Docs

16% (1/6)

pub fn mt_neg_1_6(self) -> Self

Sets the top margin of the element. Docs

16% (1/6)

pub fn mt_5_6(self) -> Self

Sets the top margin of the element. Docs

80% (5/6)

pub fn mt_neg_5_6(self) -> Self

Sets the top margin of the element. Docs

80% (5/6)

pub fn mt_1_12(self) -> Self

Sets the top margin of the element. Docs

8% (1/12)

pub fn mt_neg_1_12(self) -> Self

Sets the top margin of the element. Docs

8% (1/12)

pub fn mb(self, length: impl Clone + Into<Length>) -> Self

Sets the bottom margin of the element. Docs

pub fn mb_0(self) -> Self

Sets the bottom margin of the element. Docs

0px

pub fn mb_neg_0(self) -> Self

Sets the bottom margin of the element. Docs

0px

pub fn mb_0p5(self) -> Self

Sets the bottom margin of the element. Docs

2px (0.125rem)

pub fn mb_neg_0p5(self) -> Self

Sets the bottom margin of the element. Docs

2px (0.125rem)

pub fn mb_1(self) -> Self

Sets the bottom margin of the element. Docs

4px (0.25rem)

pub fn mb_neg_1(self) -> Self

Sets the bottom margin of the element. Docs

4px (0.25rem)

pub fn mb_1p5(self) -> Self

Sets the bottom margin of the element. Docs

6px (0.375rem)

pub fn mb_neg_1p5(self) -> Self

Sets the bottom margin of the element. Docs

6px (0.375rem)

pub fn mb_2(self) -> Self

Sets the bottom margin of the element. Docs

8px (0.5rem)

pub fn mb_neg_2(self) -> Self

Sets the bottom margin of the element. Docs

8px (0.5rem)

pub fn mb_2p5(self) -> Self

Sets the bottom margin of the element. Docs

10px (0.625rem)

pub fn mb_neg_2p5(self) -> Self

Sets the bottom margin of the element. Docs

10px (0.625rem)

pub fn mb_3(self) -> Self

Sets the bottom margin of the element. Docs

12px (0.75rem)

pub fn mb_neg_3(self) -> Self

Sets the bottom margin of the element. Docs

12px (0.75rem)

pub fn mb_3p5(self) -> Self

Sets the bottom margin of the element. Docs

14px (0.875rem)

pub fn mb_neg_3p5(self) -> Self

Sets the bottom margin of the element. Docs

14px (0.875rem)

pub fn mb_4(self) -> Self

Sets the bottom margin of the element. Docs

16px (1rem)

pub fn mb_neg_4(self) -> Self

Sets the bottom margin of the element. Docs

16px (1rem)

pub fn mb_5(self) -> Self

Sets the bottom margin of the element. Docs

20px (1.25rem)

pub fn mb_neg_5(self) -> Self

Sets the bottom margin of the element. Docs

20px (1.25rem)

pub fn mb_6(self) -> Self

Sets the bottom margin of the element. Docs

24px (1.5rem)

pub fn mb_neg_6(self) -> Self

Sets the bottom margin of the element. Docs

24px (1.5rem)

pub fn mb_7(self) -> Self

Sets the bottom margin of the element. Docs

28px (1.75rem)

pub fn mb_neg_7(self) -> Self

Sets the bottom margin of the element. Docs

28px (1.75rem)

pub fn mb_8(self) -> Self

Sets the bottom margin of the element. Docs

32px (2rem)

pub fn mb_neg_8(self) -> Self

Sets the bottom margin of the element. Docs

32px (2rem)

pub fn mb_9(self) -> Self

Sets the bottom margin of the element. Docs

36px (2.25rem)

pub fn mb_neg_9(self) -> Self

Sets the bottom margin of the element. Docs

36px (2.25rem)

pub fn mb_10(self) -> Self

Sets the bottom margin of the element. Docs

40px (2.5rem)

pub fn mb_neg_10(self) -> Self

Sets the bottom margin of the element. Docs

40px (2.5rem)

pub fn mb_11(self) -> Self

Sets the bottom margin of the element. Docs

44px (2.75rem)

pub fn mb_neg_11(self) -> Self

Sets the bottom margin of the element. Docs

44px (2.75rem)

pub fn mb_12(self) -> Self

Sets the bottom margin of the element. Docs

48px (3rem)

pub fn mb_neg_12(self) -> Self

Sets the bottom margin of the element. Docs

48px (3rem)

pub fn mb_16(self) -> Self

Sets the bottom margin of the element. Docs

64px (4rem)

pub fn mb_neg_16(self) -> Self

Sets the bottom margin of the element. Docs

64px (4rem)

pub fn mb_20(self) -> Self

Sets the bottom margin of the element. Docs

80px (5rem)

pub fn mb_neg_20(self) -> Self

Sets the bottom margin of the element. Docs

80px (5rem)

pub fn mb_24(self) -> Self

Sets the bottom margin of the element. Docs

96px (6rem)

pub fn mb_neg_24(self) -> Self

Sets the bottom margin of the element. Docs

96px (6rem)

pub fn mb_32(self) -> Self

Sets the bottom margin of the element. Docs

128px (8rem)

pub fn mb_neg_32(self) -> Self

Sets the bottom margin of the element. Docs

128px (8rem)

pub fn mb_40(self) -> Self

Sets the bottom margin of the element. Docs

160px (10rem)

pub fn mb_neg_40(self) -> Self

Sets the bottom margin of the element. Docs

160px (10rem)

pub fn mb_48(self) -> Self

Sets the bottom margin of the element. Docs

192px (12rem)

pub fn mb_neg_48(self) -> Self

Sets the bottom margin of the element. Docs

192px (12rem)

pub fn mb_56(self) -> Self

Sets the bottom margin of the element. Docs

224px (14rem)

pub fn mb_neg_56(self) -> Self

Sets the bottom margin of the element. Docs

224px (14rem)

pub fn mb_64(self) -> Self

Sets the bottom margin of the element. Docs

256px (16rem)

pub fn mb_neg_64(self) -> Self

Sets the bottom margin of the element. Docs

256px (16rem)

pub fn mb_72(self) -> Self

Sets the bottom margin of the element. Docs

288px (18rem)

pub fn mb_neg_72(self) -> Self

Sets the bottom margin of the element. Docs

288px (18rem)

pub fn mb_80(self) -> Self

Sets the bottom margin of the element. Docs

320px (20rem)

pub fn mb_neg_80(self) -> Self

Sets the bottom margin of the element. Docs

320px (20rem)

pub fn mb_96(self) -> Self

Sets the bottom margin of the element. Docs

384px (24rem)

pub fn mb_neg_96(self) -> Self

Sets the bottom margin of the element. Docs

384px (24rem)

pub fn mb_112(self) -> Self

Sets the bottom margin of the element. Docs

448px (28rem)

pub fn mb_neg_112(self) -> Self

Sets the bottom margin of the element. Docs

448px (28rem)

pub fn mb_128(self) -> Self

Sets the bottom margin of the element. Docs

512px (32rem)

pub fn mb_neg_128(self) -> Self

Sets the bottom margin of the element. Docs

512px (32rem)

pub fn mb_auto(self) -> Self

Sets the bottom margin of the element. Docs

Auto

pub fn mb_px(self) -> Self

Sets the bottom margin of the element. Docs

1px

pub fn mb_neg_px(self) -> Self

Sets the bottom margin of the element. Docs

1px

pub fn mb_full(self) -> Self

Sets the bottom margin of the element. Docs

100%

pub fn mb_neg_full(self) -> Self

Sets the bottom margin of the element. Docs

100%

pub fn mb_1_2(self) -> Self

Sets the bottom margin of the element. Docs

50% (1/2)

pub fn mb_neg_1_2(self) -> Self

Sets the bottom margin of the element. Docs

50% (1/2)

pub fn mb_1_3(self) -> Self

Sets the bottom margin of the element. Docs

33% (1/3)

pub fn mb_neg_1_3(self) -> Self

Sets the bottom margin of the element. Docs

33% (1/3)

pub fn mb_2_3(self) -> Self

Sets the bottom margin of the element. Docs

66% (2/3)

pub fn mb_neg_2_3(self) -> Self

Sets the bottom margin of the element. Docs

66% (2/3)

pub fn mb_1_4(self) -> Self

Sets the bottom margin of the element. Docs

25% (1/4)

pub fn mb_neg_1_4(self) -> Self

Sets the bottom margin of the element. Docs

25% (1/4)

pub fn mb_2_4(self) -> Self

Sets the bottom margin of the element. Docs

50% (2/4)

pub fn mb_neg_2_4(self) -> Self

Sets the bottom margin of the element. Docs

50% (2/4)

pub fn mb_3_4(self) -> Self

Sets the bottom margin of the element. Docs

75% (3/4)

pub fn mb_neg_3_4(self) -> Self

Sets the bottom margin of the element. Docs

75% (3/4)

pub fn mb_1_5(self) -> Self

Sets the bottom margin of the element. Docs

20% (1/5)

pub fn mb_neg_1_5(self) -> Self

Sets the bottom margin of the element. Docs

20% (1/5)

pub fn mb_2_5(self) -> Self

Sets the bottom margin of the element. Docs

40% (2/5)

pub fn mb_neg_2_5(self) -> Self

Sets the bottom margin of the element. Docs

40% (2/5)

pub fn mb_3_5(self) -> Self

Sets the bottom margin of the element. Docs

60% (3/5)

pub fn mb_neg_3_5(self) -> Self

Sets the bottom margin of the element. Docs

60% (3/5)

pub fn mb_4_5(self) -> Self

Sets the bottom margin of the element. Docs

80% (4/5)

pub fn mb_neg_4_5(self) -> Self

Sets the bottom margin of the element. Docs

80% (4/5)

pub fn mb_1_6(self) -> Self

Sets the bottom margin of the element. Docs

16% (1/6)

pub fn mb_neg_1_6(self) -> Self

Sets the bottom margin of the element. Docs

16% (1/6)

pub fn mb_5_6(self) -> Self

Sets the bottom margin of the element. Docs

80% (5/6)

pub fn mb_neg_5_6(self) -> Self

Sets the bottom margin of the element. Docs

80% (5/6)

pub fn mb_1_12(self) -> Self

Sets the bottom margin of the element. Docs

8% (1/12)

pub fn mb_neg_1_12(self) -> Self

Sets the bottom margin of the element. Docs

8% (1/12)

pub fn my(self, length: impl Clone + Into<Length>) -> Self

Sets the vertical margin of the element. Docs

pub fn my_0(self) -> Self

Sets the vertical margin of the element. Docs

0px

pub fn my_neg_0(self) -> Self

Sets the vertical margin of the element. Docs

0px

pub fn my_0p5(self) -> Self

Sets the vertical margin of the element. Docs

2px (0.125rem)

pub fn my_neg_0p5(self) -> Self

Sets the vertical margin of the element. Docs

2px (0.125rem)

pub fn my_1(self) -> Self

Sets the vertical margin of the element. Docs

4px (0.25rem)

pub fn my_neg_1(self) -> Self

Sets the vertical margin of the element. Docs

4px (0.25rem)

pub fn my_1p5(self) -> Self

Sets the vertical margin of the element. Docs

6px (0.375rem)

pub fn my_neg_1p5(self) -> Self

Sets the vertical margin of the element. Docs

6px (0.375rem)

pub fn my_2(self) -> Self

Sets the vertical margin of the element. Docs

8px (0.5rem)

pub fn my_neg_2(self) -> Self

Sets the vertical margin of the element. Docs

8px (0.5rem)

pub fn my_2p5(self) -> Self

Sets the vertical margin of the element. Docs

10px (0.625rem)

pub fn my_neg_2p5(self) -> Self

Sets the vertical margin of the element. Docs

10px (0.625rem)

pub fn my_3(self) -> Self

Sets the vertical margin of the element. Docs

12px (0.75rem)

pub fn my_neg_3(self) -> Self

Sets the vertical margin of the element. Docs

12px (0.75rem)

pub fn my_3p5(self) -> Self

Sets the vertical margin of the element. Docs

14px (0.875rem)

pub fn my_neg_3p5(self) -> Self

Sets the vertical margin of the element. Docs

14px (0.875rem)

pub fn my_4(self) -> Self

Sets the vertical margin of the element. Docs

16px (1rem)

pub fn my_neg_4(self) -> Self

Sets the vertical margin of the element. Docs

16px (1rem)

pub fn my_5(self) -> Self

Sets the vertical margin of the element. Docs

20px (1.25rem)

pub fn my_neg_5(self) -> Self

Sets the vertical margin of the element. Docs

20px (1.25rem)

pub fn my_6(self) -> Self

Sets the vertical margin of the element. Docs

24px (1.5rem)

pub fn my_neg_6(self) -> Self

Sets the vertical margin of the element. Docs

24px (1.5rem)

pub fn my_7(self) -> Self

Sets the vertical margin of the element. Docs

28px (1.75rem)

pub fn my_neg_7(self) -> Self

Sets the vertical margin of the element. Docs

28px (1.75rem)

pub fn my_8(self) -> Self

Sets the vertical margin of the element. Docs

32px (2rem)

pub fn my_neg_8(self) -> Self

Sets the vertical margin of the element. Docs

32px (2rem)

pub fn my_9(self) -> Self

Sets the vertical margin of the element. Docs

36px (2.25rem)

pub fn my_neg_9(self) -> Self

Sets the vertical margin of the element. Docs

36px (2.25rem)

pub fn my_10(self) -> Self

Sets the vertical margin of the element. Docs

40px (2.5rem)

pub fn my_neg_10(self) -> Self

Sets the vertical margin of the element. Docs

40px (2.5rem)

pub fn my_11(self) -> Self

Sets the vertical margin of the element. Docs

44px (2.75rem)

pub fn my_neg_11(self) -> Self

Sets the vertical margin of the element. Docs

44px (2.75rem)

pub fn my_12(self) -> Self

Sets the vertical margin of the element. Docs

48px (3rem)

pub fn my_neg_12(self) -> Self

Sets the vertical margin of the element. Docs

48px (3rem)

pub fn my_16(self) -> Self

Sets the vertical margin of the element. Docs

64px (4rem)

pub fn my_neg_16(self) -> Self

Sets the vertical margin of the element. Docs

64px (4rem)

pub fn my_20(self) -> Self

Sets the vertical margin of the element. Docs

80px (5rem)

pub fn my_neg_20(self) -> Self

Sets the vertical margin of the element. Docs

80px (5rem)

pub fn my_24(self) -> Self

Sets the vertical margin of the element. Docs

96px (6rem)

pub fn my_neg_24(self) -> Self

Sets the vertical margin of the element. Docs

96px (6rem)

pub fn my_32(self) -> Self

Sets the vertical margin of the element. Docs

128px (8rem)

pub fn my_neg_32(self) -> Self

Sets the vertical margin of the element. Docs

128px (8rem)

pub fn my_40(self) -> Self

Sets the vertical margin of the element. Docs

160px (10rem)

pub fn my_neg_40(self) -> Self

Sets the vertical margin of the element. Docs

160px (10rem)

pub fn my_48(self) -> Self

Sets the vertical margin of the element. Docs

192px (12rem)

pub fn my_neg_48(self) -> Self

Sets the vertical margin of the element. Docs

192px (12rem)

pub fn my_56(self) -> Self

Sets the vertical margin of the element. Docs

224px (14rem)

pub fn my_neg_56(self) -> Self

Sets the vertical margin of the element. Docs

224px (14rem)

pub fn my_64(self) -> Self

Sets the vertical margin of the element. Docs

256px (16rem)

pub fn my_neg_64(self) -> Self

Sets the vertical margin of the element. Docs

256px (16rem)

pub fn my_72(self) -> Self

Sets the vertical margin of the element. Docs

288px (18rem)

pub fn my_neg_72(self) -> Self

Sets the vertical margin of the element. Docs

288px (18rem)

pub fn my_80(self) -> Self

Sets the vertical margin of the element. Docs

320px (20rem)

pub fn my_neg_80(self) -> Self

Sets the vertical margin of the element. Docs

320px (20rem)

pub fn my_96(self) -> Self

Sets the vertical margin of the element. Docs

384px (24rem)

pub fn my_neg_96(self) -> Self

Sets the vertical margin of the element. Docs

384px (24rem)

pub fn my_112(self) -> Self

Sets the vertical margin of the element. Docs

448px (28rem)

pub fn my_neg_112(self) -> Self

Sets the vertical margin of the element. Docs

448px (28rem)

pub fn my_128(self) -> Self

Sets the vertical margin of the element. Docs

512px (32rem)

pub fn my_neg_128(self) -> Self

Sets the vertical margin of the element. Docs

512px (32rem)

pub fn my_auto(self) -> Self

Sets the vertical margin of the element. Docs

Auto

pub fn my_px(self) -> Self

Sets the vertical margin of the element. Docs

1px

pub fn my_neg_px(self) -> Self

Sets the vertical margin of the element. Docs

1px

pub fn my_full(self) -> Self

Sets the vertical margin of the element. Docs

100%

pub fn my_neg_full(self) -> Self

Sets the vertical margin of the element. Docs

100%

pub fn my_1_2(self) -> Self

Sets the vertical margin of the element. Docs

50% (1/2)

pub fn my_neg_1_2(self) -> Self

Sets the vertical margin of the element. Docs

50% (1/2)

pub fn my_1_3(self) -> Self

Sets the vertical margin of the element. Docs

33% (1/3)

pub fn my_neg_1_3(self) -> Self

Sets the vertical margin of the element. Docs

33% (1/3)

pub fn my_2_3(self) -> Self

Sets the vertical margin of the element. Docs

66% (2/3)

pub fn my_neg_2_3(self) -> Self

Sets the vertical margin of the element. Docs

66% (2/3)

pub fn my_1_4(self) -> Self

Sets the vertical margin of the element. Docs

25% (1/4)

pub fn my_neg_1_4(self) -> Self

Sets the vertical margin of the element. Docs

25% (1/4)

pub fn my_2_4(self) -> Self

Sets the vertical margin of the element. Docs

50% (2/4)

pub fn my_neg_2_4(self) -> Self

Sets the vertical margin of the element. Docs

50% (2/4)

pub fn my_3_4(self) -> Self

Sets the vertical margin of the element. Docs

75% (3/4)

pub fn my_neg_3_4(self) -> Self

Sets the vertical margin of the element. Docs

75% (3/4)

pub fn my_1_5(self) -> Self

Sets the vertical margin of the element. Docs

20% (1/5)

pub fn my_neg_1_5(self) -> Self

Sets the vertical margin of the element. Docs

20% (1/5)

pub fn my_2_5(self) -> Self

Sets the vertical margin of the element. Docs

40% (2/5)

pub fn my_neg_2_5(self) -> Self

Sets the vertical margin of the element. Docs

40% (2/5)

pub fn my_3_5(self) -> Self

Sets the vertical margin of the element. Docs

60% (3/5)

pub fn my_neg_3_5(self) -> Self

Sets the vertical margin of the element. Docs

60% (3/5)

pub fn my_4_5(self) -> Self

Sets the vertical margin of the element. Docs

80% (4/5)

pub fn my_neg_4_5(self) -> Self

Sets the vertical margin of the element. Docs

80% (4/5)

pub fn my_1_6(self) -> Self

Sets the vertical margin of the element. Docs

16% (1/6)

pub fn my_neg_1_6(self) -> Self

Sets the vertical margin of the element. Docs

16% (1/6)

pub fn my_5_6(self) -> Self

Sets the vertical margin of the element. Docs

80% (5/6)

pub fn my_neg_5_6(self) -> Self

Sets the vertical margin of the element. Docs

80% (5/6)

pub fn my_1_12(self) -> Self

Sets the vertical margin of the element. Docs

8% (1/12)

pub fn my_neg_1_12(self) -> Self

Sets the vertical margin of the element. Docs

8% (1/12)

pub fn mx(self, length: impl Clone + Into<Length>) -> Self

Sets the horizontal margin of the element. Docs

pub fn mx_0(self) -> Self

Sets the horizontal margin of the element. Docs

0px

pub fn mx_neg_0(self) -> Self

Sets the horizontal margin of the element. Docs

0px

pub fn mx_0p5(self) -> Self

Sets the horizontal margin of the element. Docs

2px (0.125rem)

pub fn mx_neg_0p5(self) -> Self

Sets the horizontal margin of the element. Docs

2px (0.125rem)

pub fn mx_1(self) -> Self

Sets the horizontal margin of the element. Docs

4px (0.25rem)

pub fn mx_neg_1(self) -> Self

Sets the horizontal margin of the element. Docs

4px (0.25rem)

pub fn mx_1p5(self) -> Self

Sets the horizontal margin of the element. Docs

6px (0.375rem)

pub fn mx_neg_1p5(self) -> Self

Sets the horizontal margin of the element. Docs

6px (0.375rem)

pub fn mx_2(self) -> Self

Sets the horizontal margin of the element. Docs

8px (0.5rem)

pub fn mx_neg_2(self) -> Self

Sets the horizontal margin of the element. Docs

8px (0.5rem)

pub fn mx_2p5(self) -> Self

Sets the horizontal margin of the element. Docs

10px (0.625rem)

pub fn mx_neg_2p5(self) -> Self

Sets the horizontal margin of the element. Docs

10px (0.625rem)

pub fn mx_3(self) -> Self

Sets the horizontal margin of the element. Docs

12px (0.75rem)

pub fn mx_neg_3(self) -> Self

Sets the horizontal margin of the element. Docs

12px (0.75rem)

pub fn mx_3p5(self) -> Self

Sets the horizontal margin of the element. Docs

14px (0.875rem)

pub fn mx_neg_3p5(self) -> Self

Sets the horizontal margin of the element. Docs

14px (0.875rem)

pub fn mx_4(self) -> Self

Sets the horizontal margin of the element. Docs

16px (1rem)

pub fn mx_neg_4(self) -> Self

Sets the horizontal margin of the element. Docs

16px (1rem)

pub fn mx_5(self) -> Self

Sets the horizontal margin of the element. Docs

20px (1.25rem)

pub fn mx_neg_5(self) -> Self

Sets the horizontal margin of the element. Docs

20px (1.25rem)

pub fn mx_6(self) -> Self

Sets the horizontal margin of the element. Docs

24px (1.5rem)

pub fn mx_neg_6(self) -> Self

Sets the horizontal margin of the element. Docs

24px (1.5rem)

pub fn mx_7(self) -> Self

Sets the horizontal margin of the element. Docs

28px (1.75rem)

pub fn mx_neg_7(self) -> Self

Sets the horizontal margin of the element. Docs

28px (1.75rem)

pub fn mx_8(self) -> Self

Sets the horizontal margin of the element. Docs

32px (2rem)

pub fn mx_neg_8(self) -> Self

Sets the horizontal margin of the element. Docs

32px (2rem)

pub fn mx_9(self) -> Self

Sets the horizontal margin of the element. Docs

36px (2.25rem)

pub fn mx_neg_9(self) -> Self

Sets the horizontal margin of the element. Docs

36px (2.25rem)

pub fn mx_10(self) -> Self

Sets the horizontal margin of the element. Docs

40px (2.5rem)

pub fn mx_neg_10(self) -> Self

Sets the horizontal margin of the element. Docs

40px (2.5rem)

pub fn mx_11(self) -> Self

Sets the horizontal margin of the element. Docs

44px (2.75rem)

pub fn mx_neg_11(self) -> Self

Sets the horizontal margin of the element. Docs

44px (2.75rem)

pub fn mx_12(self) -> Self

Sets the horizontal margin of the element. Docs

48px (3rem)

pub fn mx_neg_12(self) -> Self

Sets the horizontal margin of the element. Docs

48px (3rem)

pub fn mx_16(self) -> Self

Sets the horizontal margin of the element. Docs

64px (4rem)

pub fn mx_neg_16(self) -> Self

Sets the horizontal margin of the element. Docs

64px (4rem)

pub fn mx_20(self) -> Self

Sets the horizontal margin of the element. Docs

80px (5rem)

pub fn mx_neg_20(self) -> Self

Sets the horizontal margin of the element. Docs

80px (5rem)

pub fn mx_24(self) -> Self

Sets the horizontal margin of the element. Docs

96px (6rem)

pub fn mx_neg_24(self) -> Self

Sets the horizontal margin of the element. Docs

96px (6rem)

pub fn mx_32(self) -> Self

Sets the horizontal margin of the element. Docs

128px (8rem)

pub fn mx_neg_32(self) -> Self

Sets the horizontal margin of the element. Docs

128px (8rem)

pub fn mx_40(self) -> Self

Sets the horizontal margin of the element. Docs

160px (10rem)

pub fn mx_neg_40(self) -> Self

Sets the horizontal margin of the element. Docs

160px (10rem)

pub fn mx_48(self) -> Self

Sets the horizontal margin of the element. Docs

192px (12rem)

pub fn mx_neg_48(self) -> Self

Sets the horizontal margin of the element. Docs

192px (12rem)

pub fn mx_56(self) -> Self

Sets the horizontal margin of the element. Docs

224px (14rem)

pub fn mx_neg_56(self) -> Self

Sets the horizontal margin of the element. Docs

224px (14rem)

pub fn mx_64(self) -> Self

Sets the horizontal margin of the element. Docs

256px (16rem)

pub fn mx_neg_64(self) -> Self

Sets the horizontal margin of the element. Docs

256px (16rem)

pub fn mx_72(self) -> Self

Sets the horizontal margin of the element. Docs

288px (18rem)

pub fn mx_neg_72(self) -> Self

Sets the horizontal margin of the element. Docs

288px (18rem)

pub fn mx_80(self) -> Self

Sets the horizontal margin of the element. Docs

320px (20rem)

pub fn mx_neg_80(self) -> Self

Sets the horizontal margin of the element. Docs

320px (20rem)

pub fn mx_96(self) -> Self

Sets the horizontal margin of the element. Docs

384px (24rem)

pub fn mx_neg_96(self) -> Self

Sets the horizontal margin of the element. Docs

384px (24rem)

pub fn mx_112(self) -> Self

Sets the horizontal margin of the element. Docs

448px (28rem)

pub fn mx_neg_112(self) -> Self

Sets the horizontal margin of the element. Docs

448px (28rem)

pub fn mx_128(self) -> Self

Sets the horizontal margin of the element. Docs

512px (32rem)

pub fn mx_neg_128(self) -> Self

Sets the horizontal margin of the element. Docs

512px (32rem)

pub fn mx_auto(self) -> Self

Sets the horizontal margin of the element. Docs

Auto

pub fn mx_px(self) -> Self

Sets the horizontal margin of the element. Docs

1px

pub fn mx_neg_px(self) -> Self

Sets the horizontal margin of the element. Docs

1px

pub fn mx_full(self) -> Self

Sets the horizontal margin of the element. Docs

100%

pub fn mx_neg_full(self) -> Self

Sets the horizontal margin of the element. Docs

100%

pub fn mx_1_2(self) -> Self

Sets the horizontal margin of the element. Docs

50% (1/2)

pub fn mx_neg_1_2(self) -> Self

Sets the horizontal margin of the element. Docs

50% (1/2)

pub fn mx_1_3(self) -> Self

Sets the horizontal margin of the element. Docs

33% (1/3)

pub fn mx_neg_1_3(self) -> Self

Sets the horizontal margin of the element. Docs

33% (1/3)

pub fn mx_2_3(self) -> Self

Sets the horizontal margin of the element. Docs

66% (2/3)

pub fn mx_neg_2_3(self) -> Self

Sets the horizontal margin of the element. Docs

66% (2/3)

pub fn mx_1_4(self) -> Self

Sets the horizontal margin of the element. Docs

25% (1/4)

pub fn mx_neg_1_4(self) -> Self

Sets the horizontal margin of the element. Docs

25% (1/4)

pub fn mx_2_4(self) -> Self

Sets the horizontal margin of the element. Docs

50% (2/4)

pub fn mx_neg_2_4(self) -> Self

Sets the horizontal margin of the element. Docs

50% (2/4)

pub fn mx_3_4(self) -> Self

Sets the horizontal margin of the element. Docs

75% (3/4)

pub fn mx_neg_3_4(self) -> Self

Sets the horizontal margin of the element. Docs

75% (3/4)

pub fn mx_1_5(self) -> Self

Sets the horizontal margin of the element. Docs

20% (1/5)

pub fn mx_neg_1_5(self) -> Self

Sets the horizontal margin of the element. Docs

20% (1/5)

pub fn mx_2_5(self) -> Self

Sets the horizontal margin of the element. Docs

40% (2/5)

pub fn mx_neg_2_5(self) -> Self

Sets the horizontal margin of the element. Docs

40% (2/5)

pub fn mx_3_5(self) -> Self

Sets the horizontal margin of the element. Docs

60% (3/5)

pub fn mx_neg_3_5(self) -> Self

Sets the horizontal margin of the element. Docs

60% (3/5)

pub fn mx_4_5(self) -> Self

Sets the horizontal margin of the element. Docs

80% (4/5)

pub fn mx_neg_4_5(self) -> Self

Sets the horizontal margin of the element. Docs

80% (4/5)

pub fn mx_1_6(self) -> Self

Sets the horizontal margin of the element. Docs

16% (1/6)

pub fn mx_neg_1_6(self) -> Self

Sets the horizontal margin of the element. Docs

16% (1/6)

pub fn mx_5_6(self) -> Self

Sets the horizontal margin of the element. Docs

80% (5/6)

pub fn mx_neg_5_6(self) -> Self

Sets the horizontal margin of the element. Docs

80% (5/6)

pub fn mx_1_12(self) -> Self

Sets the horizontal margin of the element. Docs

8% (1/12)

pub fn mx_neg_1_12(self) -> Self

Sets the horizontal margin of the element. Docs

8% (1/12)

pub fn ml(self, length: impl Clone + Into<Length>) -> Self

Sets the left margin of the element. Docs

pub fn ml_0(self) -> Self

Sets the left margin of the element. Docs

0px

pub fn ml_neg_0(self) -> Self

Sets the left margin of the element. Docs

0px

pub fn ml_0p5(self) -> Self

Sets the left margin of the element. Docs

2px (0.125rem)

pub fn ml_neg_0p5(self) -> Self

Sets the left margin of the element. Docs

2px (0.125rem)

pub fn ml_1(self) -> Self

Sets the left margin of the element. Docs

4px (0.25rem)

pub fn ml_neg_1(self) -> Self

Sets the left margin of the element. Docs

4px (0.25rem)

pub fn ml_1p5(self) -> Self

Sets the left margin of the element. Docs

6px (0.375rem)

pub fn ml_neg_1p5(self) -> Self

Sets the left margin of the element. Docs

6px (0.375rem)

pub fn ml_2(self) -> Self

Sets the left margin of the element. Docs

8px (0.5rem)

pub fn ml_neg_2(self) -> Self

Sets the left margin of the element. Docs

8px (0.5rem)

pub fn ml_2p5(self) -> Self

Sets the left margin of the element. Docs

10px (0.625rem)

pub fn ml_neg_2p5(self) -> Self

Sets the left margin of the element. Docs

10px (0.625rem)

pub fn ml_3(self) -> Self

Sets the left margin of the element. Docs

12px (0.75rem)

pub fn ml_neg_3(self) -> Self

Sets the left margin of the element. Docs

12px (0.75rem)

pub fn ml_3p5(self) -> Self

Sets the left margin of the element. Docs

14px (0.875rem)

pub fn ml_neg_3p5(self) -> Self

Sets the left margin of the element. Docs

14px (0.875rem)

pub fn ml_4(self) -> Self

Sets the left margin of the element. Docs

16px (1rem)

pub fn ml_neg_4(self) -> Self

Sets the left margin of the element. Docs

16px (1rem)

pub fn ml_5(self) -> Self

Sets the left margin of the element. Docs

20px (1.25rem)

pub fn ml_neg_5(self) -> Self

Sets the left margin of the element. Docs

20px (1.25rem)

pub fn ml_6(self) -> Self

Sets the left margin of the element. Docs

24px (1.5rem)

pub fn ml_neg_6(self) -> Self

Sets the left margin of the element. Docs

24px (1.5rem)

pub fn ml_7(self) -> Self

Sets the left margin of the element. Docs

28px (1.75rem)

pub fn ml_neg_7(self) -> Self

Sets the left margin of the element. Docs

28px (1.75rem)

pub fn ml_8(self) -> Self

Sets the left margin of the element. Docs

32px (2rem)

pub fn ml_neg_8(self) -> Self

Sets the left margin of the element. Docs

32px (2rem)

pub fn ml_9(self) -> Self

Sets the left margin of the element. Docs

36px (2.25rem)

pub fn ml_neg_9(self) -> Self

Sets the left margin of the element. Docs

36px (2.25rem)

pub fn ml_10(self) -> Self

Sets the left margin of the element. Docs

40px (2.5rem)

pub fn ml_neg_10(self) -> Self

Sets the left margin of the element. Docs

40px (2.5rem)

pub fn ml_11(self) -> Self

Sets the left margin of the element. Docs

44px (2.75rem)

pub fn ml_neg_11(self) -> Self

Sets the left margin of the element. Docs

44px (2.75rem)

pub fn ml_12(self) -> Self

Sets the left margin of the element. Docs

48px (3rem)

pub fn ml_neg_12(self) -> Self

Sets the left margin of the element. Docs

48px (3rem)

pub fn ml_16(self) -> Self

Sets the left margin of the element. Docs

64px (4rem)

pub fn ml_neg_16(self) -> Self

Sets the left margin of the element. Docs

64px (4rem)

pub fn ml_20(self) -> Self

Sets the left margin of the element. Docs

80px (5rem)

pub fn ml_neg_20(self) -> Self

Sets the left margin of the element. Docs

80px (5rem)

pub fn ml_24(self) -> Self

Sets the left margin of the element. Docs

96px (6rem)

pub fn ml_neg_24(self) -> Self

Sets the left margin of the element. Docs

96px (6rem)

pub fn ml_32(self) -> Self

Sets the left margin of the element. Docs

128px (8rem)

pub fn ml_neg_32(self) -> Self

Sets the left margin of the element. Docs

128px (8rem)

pub fn ml_40(self) -> Self

Sets the left margin of the element. Docs

160px (10rem)

pub fn ml_neg_40(self) -> Self

Sets the left margin of the element. Docs

160px (10rem)

pub fn ml_48(self) -> Self

Sets the left margin of the element. Docs

192px (12rem)

pub fn ml_neg_48(self) -> Self

Sets the left margin of the element. Docs

192px (12rem)

pub fn ml_56(self) -> Self

Sets the left margin of the element. Docs

224px (14rem)

pub fn ml_neg_56(self) -> Self

Sets the left margin of the element. Docs

224px (14rem)

pub fn ml_64(self) -> Self

Sets the left margin of the element. Docs

256px (16rem)

pub fn ml_neg_64(self) -> Self

Sets the left margin of the element. Docs

256px (16rem)

pub fn ml_72(self) -> Self

Sets the left margin of the element. Docs

288px (18rem)

pub fn ml_neg_72(self) -> Self

Sets the left margin of the element. Docs

288px (18rem)

pub fn ml_80(self) -> Self

Sets the left margin of the element. Docs

320px (20rem)

pub fn ml_neg_80(self) -> Self

Sets the left margin of the element. Docs

320px (20rem)

pub fn ml_96(self) -> Self

Sets the left margin of the element. Docs

384px (24rem)

pub fn ml_neg_96(self) -> Self

Sets the left margin of the element. Docs

384px (24rem)

pub fn ml_112(self) -> Self

Sets the left margin of the element. Docs

448px (28rem)

pub fn ml_neg_112(self) -> Self

Sets the left margin of the element. Docs

448px (28rem)

pub fn ml_128(self) -> Self

Sets the left margin of the element. Docs

512px (32rem)

pub fn ml_neg_128(self) -> Self

Sets the left margin of the element. Docs

512px (32rem)

pub fn ml_auto(self) -> Self

Sets the left margin of the element. Docs

Auto

pub fn ml_px(self) -> Self

Sets the left margin of the element. Docs

1px

pub fn ml_neg_px(self) -> Self

Sets the left margin of the element. Docs

1px

pub fn ml_full(self) -> Self

Sets the left margin of the element. Docs

100%

pub fn ml_neg_full(self) -> Self

Sets the left margin of the element. Docs

100%

pub fn ml_1_2(self) -> Self

Sets the left margin of the element. Docs

50% (1/2)

pub fn ml_neg_1_2(self) -> Self

Sets the left margin of the element. Docs

50% (1/2)

pub fn ml_1_3(self) -> Self

Sets the left margin of the element. Docs

33% (1/3)

pub fn ml_neg_1_3(self) -> Self

Sets the left margin of the element. Docs

33% (1/3)

pub fn ml_2_3(self) -> Self

Sets the left margin of the element. Docs

66% (2/3)

pub fn ml_neg_2_3(self) -> Self

Sets the left margin of the element. Docs

66% (2/3)

pub fn ml_1_4(self) -> Self

Sets the left margin of the element. Docs

25% (1/4)

pub fn ml_neg_1_4(self) -> Self

Sets the left margin of the element. Docs

25% (1/4)

pub fn ml_2_4(self) -> Self

Sets the left margin of the element. Docs

50% (2/4)

pub fn ml_neg_2_4(self) -> Self

Sets the left margin of the element. Docs

50% (2/4)

pub fn ml_3_4(self) -> Self

Sets the left margin of the element. Docs

75% (3/4)

pub fn ml_neg_3_4(self) -> Self

Sets the left margin of the element. Docs

75% (3/4)

pub fn ml_1_5(self) -> Self

Sets the left margin of the element. Docs

20% (1/5)

pub fn ml_neg_1_5(self) -> Self

Sets the left margin of the element. Docs

20% (1/5)

pub fn ml_2_5(self) -> Self

Sets the left margin of the element. Docs

40% (2/5)

pub fn ml_neg_2_5(self) -> Self

Sets the left margin of the element. Docs

40% (2/5)

pub fn ml_3_5(self) -> Self

Sets the left margin of the element. Docs

60% (3/5)

pub fn ml_neg_3_5(self) -> Self

Sets the left margin of the element. Docs

60% (3/5)

pub fn ml_4_5(self) -> Self

Sets the left margin of the element. Docs

80% (4/5)

pub fn ml_neg_4_5(self) -> Self

Sets the left margin of the element. Docs

80% (4/5)

pub fn ml_1_6(self) -> Self

Sets the left margin of the element. Docs

16% (1/6)

pub fn ml_neg_1_6(self) -> Self

Sets the left margin of the element. Docs

16% (1/6)

pub fn ml_5_6(self) -> Self

Sets the left margin of the element. Docs

80% (5/6)

pub fn ml_neg_5_6(self) -> Self

Sets the left margin of the element. Docs

80% (5/6)

pub fn ml_1_12(self) -> Self

Sets the left margin of the element. Docs

8% (1/12)

pub fn ml_neg_1_12(self) -> Self

Sets the left margin of the element. Docs

8% (1/12)

pub fn mr(self, length: impl Clone + Into<Length>) -> Self

Sets the right margin of the element. Docs

pub fn mr_0(self) -> Self

Sets the right margin of the element. Docs

0px

pub fn mr_neg_0(self) -> Self

Sets the right margin of the element. Docs

0px

pub fn mr_0p5(self) -> Self

Sets the right margin of the element. Docs

2px (0.125rem)

pub fn mr_neg_0p5(self) -> Self

Sets the right margin of the element. Docs

2px (0.125rem)

pub fn mr_1(self) -> Self

Sets the right margin of the element. Docs

4px (0.25rem)

pub fn mr_neg_1(self) -> Self

Sets the right margin of the element. Docs

4px (0.25rem)

pub fn mr_1p5(self) -> Self

Sets the right margin of the element. Docs

6px (0.375rem)

pub fn mr_neg_1p5(self) -> Self

Sets the right margin of the element. Docs

6px (0.375rem)

pub fn mr_2(self) -> Self

Sets the right margin of the element. Docs

8px (0.5rem)

pub fn mr_neg_2(self) -> Self

Sets the right margin of the element. Docs

8px (0.5rem)

pub fn mr_2p5(self) -> Self

Sets the right margin of the element. Docs

10px (0.625rem)

pub fn mr_neg_2p5(self) -> Self

Sets the right margin of the element. Docs

10px (0.625rem)

pub fn mr_3(self) -> Self

Sets the right margin of the element. Docs

12px (0.75rem)

pub fn mr_neg_3(self) -> Self

Sets the right margin of the element. Docs

12px (0.75rem)

pub fn mr_3p5(self) -> Self

Sets the right margin of the element. Docs

14px (0.875rem)

pub fn mr_neg_3p5(self) -> Self

Sets the right margin of the element. Docs

14px (0.875rem)

pub fn mr_4(self) -> Self

Sets the right margin of the element. Docs

16px (1rem)

pub fn mr_neg_4(self) -> Self

Sets the right margin of the element. Docs

16px (1rem)

pub fn mr_5(self) -> Self

Sets the right margin of the element. Docs

20px (1.25rem)

pub fn mr_neg_5(self) -> Self

Sets the right margin of the element. Docs

20px (1.25rem)

pub fn mr_6(self) -> Self

Sets the right margin of the element. Docs

24px (1.5rem)

pub fn mr_neg_6(self) -> Self

Sets the right margin of the element. Docs

24px (1.5rem)

pub fn mr_7(self) -> Self

Sets the right margin of the element. Docs

28px (1.75rem)

pub fn mr_neg_7(self) -> Self

Sets the right margin of the element. Docs

28px (1.75rem)

pub fn mr_8(self) -> Self

Sets the right margin of the element. Docs

32px (2rem)

pub fn mr_neg_8(self) -> Self

Sets the right margin of the element. Docs

32px (2rem)

pub fn mr_9(self) -> Self

Sets the right margin of the element. Docs

36px (2.25rem)

pub fn mr_neg_9(self) -> Self

Sets the right margin of the element. Docs

36px (2.25rem)

pub fn mr_10(self) -> Self

Sets the right margin of the element. Docs

40px (2.5rem)

pub fn mr_neg_10(self) -> Self

Sets the right margin of the element. Docs

40px (2.5rem)

pub fn mr_11(self) -> Self

Sets the right margin of the element. Docs

44px (2.75rem)

pub fn mr_neg_11(self) -> Self

Sets the right margin of the element. Docs

44px (2.75rem)

pub fn mr_12(self) -> Self

Sets the right margin of the element. Docs

48px (3rem)

pub fn mr_neg_12(self) -> Self

Sets the right margin of the element. Docs

48px (3rem)

pub fn mr_16(self) -> Self

Sets the right margin of the element. Docs

64px (4rem)

pub fn mr_neg_16(self) -> Self

Sets the right margin of the element. Docs

64px (4rem)

pub fn mr_20(self) -> Self

Sets the right margin of the element. Docs

80px (5rem)

pub fn mr_neg_20(self) -> Self

Sets the right margin of the element. Docs

80px (5rem)

pub fn mr_24(self) -> Self

Sets the right margin of the element. Docs

96px (6rem)

pub fn mr_neg_24(self) -> Self

Sets the right margin of the element. Docs

96px (6rem)

pub fn mr_32(self) -> Self

Sets the right margin of the element. Docs

128px (8rem)

pub fn mr_neg_32(self) -> Self

Sets the right margin of the element. Docs

128px (8rem)

pub fn mr_40(self) -> Self

Sets the right margin of the element. Docs

160px (10rem)

pub fn mr_neg_40(self) -> Self

Sets the right margin of the element. Docs

160px (10rem)

pub fn mr_48(self) -> Self

Sets the right margin of the element. Docs

192px (12rem)

pub fn mr_neg_48(self) -> Self

Sets the right margin of the element. Docs

192px (12rem)

pub fn mr_56(self) -> Self

Sets the right margin of the element. Docs

224px (14rem)

pub fn mr_neg_56(self) -> Self

Sets the right margin of the element. Docs

224px (14rem)

pub fn mr_64(self) -> Self

Sets the right margin of the element. Docs

256px (16rem)

pub fn mr_neg_64(self) -> Self

Sets the right margin of the element. Docs

256px (16rem)

pub fn mr_72(self) -> Self

Sets the right margin of the element. Docs

288px (18rem)

pub fn mr_neg_72(self) -> Self

Sets the right margin of the element. Docs

288px (18rem)

pub fn mr_80(self) -> Self

Sets the right margin of the element. Docs

320px (20rem)

pub fn mr_neg_80(self) -> Self

Sets the right margin of the element. Docs

320px (20rem)

pub fn mr_96(self) -> Self

Sets the right margin of the element. Docs

384px (24rem)

pub fn mr_neg_96(self) -> Self

Sets the right margin of the element. Docs

384px (24rem)

pub fn mr_112(self) -> Self

Sets the right margin of the element. Docs

448px (28rem)

pub fn mr_neg_112(self) -> Self

Sets the right margin of the element. Docs

448px (28rem)

pub fn mr_128(self) -> Self

Sets the right margin of the element. Docs

512px (32rem)

pub fn mr_neg_128(self) -> Self

Sets the right margin of the element. Docs

512px (32rem)

pub fn mr_auto(self) -> Self

Sets the right margin of the element. Docs

Auto

pub fn mr_px(self) -> Self

Sets the right margin of the element. Docs

1px

pub fn mr_neg_px(self) -> Self

Sets the right margin of the element. Docs

1px

pub fn mr_full(self) -> Self

Sets the right margin of the element. Docs

100%

pub fn mr_neg_full(self) -> Self

Sets the right margin of the element. Docs

100%

pub fn mr_1_2(self) -> Self

Sets the right margin of the element. Docs

50% (1/2)

pub fn mr_neg_1_2(self) -> Self

Sets the right margin of the element. Docs

50% (1/2)

pub fn mr_1_3(self) -> Self

Sets the right margin of the element. Docs

33% (1/3)

pub fn mr_neg_1_3(self) -> Self

Sets the right margin of the element. Docs

33% (1/3)

pub fn mr_2_3(self) -> Self

Sets the right margin of the element. Docs

66% (2/3)

pub fn mr_neg_2_3(self) -> Self

Sets the right margin of the element. Docs

66% (2/3)

pub fn mr_1_4(self) -> Self

Sets the right margin of the element. Docs

25% (1/4)

pub fn mr_neg_1_4(self) -> Self

Sets the right margin of the element. Docs

25% (1/4)

pub fn mr_2_4(self) -> Self

Sets the right margin of the element. Docs

50% (2/4)

pub fn mr_neg_2_4(self) -> Self

Sets the right margin of the element. Docs

50% (2/4)

pub fn mr_3_4(self) -> Self

Sets the right margin of the element. Docs

75% (3/4)

pub fn mr_neg_3_4(self) -> Self

Sets the right margin of the element. Docs

75% (3/4)

pub fn mr_1_5(self) -> Self

Sets the right margin of the element. Docs

20% (1/5)

pub fn mr_neg_1_5(self) -> Self

Sets the right margin of the element. Docs

20% (1/5)

pub fn mr_2_5(self) -> Self

Sets the right margin of the element. Docs

40% (2/5)

pub fn mr_neg_2_5(self) -> Self

Sets the right margin of the element. Docs

40% (2/5)

pub fn mr_3_5(self) -> Self

Sets the right margin of the element. Docs

60% (3/5)

pub fn mr_neg_3_5(self) -> Self

Sets the right margin of the element. Docs

60% (3/5)

pub fn mr_4_5(self) -> Self

Sets the right margin of the element. Docs

80% (4/5)

pub fn mr_neg_4_5(self) -> Self

Sets the right margin of the element. Docs

80% (4/5)

pub fn mr_1_6(self) -> Self

Sets the right margin of the element. Docs

16% (1/6)

pub fn mr_neg_1_6(self) -> Self

Sets the right margin of the element. Docs

16% (1/6)

pub fn mr_5_6(self) -> Self

Sets the right margin of the element. Docs

80% (5/6)

pub fn mr_neg_5_6(self) -> Self

Sets the right margin of the element. Docs

80% (5/6)

pub fn mr_1_12(self) -> Self

Sets the right margin of the element. Docs

8% (1/12)

pub fn mr_neg_1_12(self) -> Self

Sets the right margin of the element. Docs

8% (1/12)

pub fn flex_1(self) -> Self

pub fn flex_none(self) -> Self

pub fn flex_grow(self) -> Self

pub fn flex_shrink(self) -> Self

pub fn flex_shrink_0(self) -> Self