pub struct PopoverMenu<M: ManagedView> { /* private fields */ }Implementations
Sourceimpl<M: ManagedView> PopoverMenu<M>
impl<M: ManagedView> PopoverMenu<M>
Sourcepub fn new(id: impl Into<ElementId>) -> Self
pub fn new(id: impl Into<ElementId>) -> Self
Returns a new PopoverMenu.
pub fn full_width(self, full_width: bool) -> Self
pub fn with_handle(self, handle: PopoverMenuHandle<M>) -> Self
pub fn trigger<T: PopoverTrigger>(self, t: T) -> Self
Sourcepub fn trigger_with_tooltip<T: PopoverTrigger + ButtonCommon>(
self,
t: T,
tooltip_builder: impl Fn(&mut Window, &mut App) -> AnyView + 'static,
) -> Self
pub fn trigger_with_tooltip<T: PopoverTrigger + ButtonCommon>( self, t: T, tooltip_builder: impl Fn(&mut Window, &mut App) -> AnyView + 'static, ) -> Self
This method prevents the trigger button tooltip from being seen when the menu is open.
Sourcepub fn anchor(self, anchor: Anchor) -> Self
pub fn anchor(self, anchor: Anchor) -> Self
Defines which corner of the menu to anchor to the attachment point.
By default, it uses the cursor position. Also see the attach method.
Sourcepub fn attach(self, attach: Anchor) -> Self
pub fn attach(self, attach: Anchor) -> Self
Defines which corner of the handle to attach the menu’s anchor to.