RightClickMenu

Struct RightClickMenu 

pub struct RightClickMenu<M: ManagedView> { /* private fields */ }

Implementations

Source

impl<M: ManagedView> RightClickMenu<M>

pub fn menu( self, f: impl Fn(&mut Window, &mut App) -> Entity<M> + 'static, ) -> Self

pub fn trigger<F, E>(self, e: F) -> Self
where F: FnOnce(bool, &mut Window, &mut App) -> E + 'static, E: IntoElement + 'static,

pub fn anchor(self, anchor: Anchor) -> Self

anchor defines which corner of the menu to anchor to the attachment point (by default the cursor position, but see attach)

pub fn attach(self, attach: Anchor) -> Self

attach defines which corner of the handle to attach the menu’s anchor to