ToggleButtonGroup

Struct ToggleButtonGroup 

pub struct ToggleButtonGroup<T, const COLS: usize = 3, const ROWS: usize = 1>
where T: ButtonBuilder,
{ /* private fields */ }

Implementations

Source

impl<T: ButtonBuilder, const COLS: usize> ToggleButtonGroup<T, COLS>

pub fn single_row( group_name: impl Into<SharedString>, buttons: [T; COLS], ) -> Self

Source

impl<T: ButtonBuilder, const COLS: usize> ToggleButtonGroup<T, COLS, 2>

pub fn two_rows( group_name: impl Into<SharedString>, first_row: [T; COLS], second_row: [T; COLS], ) -> Self

Source

impl<T: ButtonBuilder, const COLS: usize, const ROWS: usize> ToggleButtonGroup<T, COLS, ROWS>

pub fn style(self, style: ToggleButtonGroupStyle) -> Self

pub fn size(self, size: ToggleButtonGroupSize) -> Self

pub fn selected_index(self, index: usize) -> Self

pub fn auto_width(self) -> Self

Makes the button group size itself to fit the content of the buttons, rather than filling the full width of its parent.

pub fn label_size(self, label_size: LabelSize) -> Self

pub fn tab_index(self, tab_index: &mut isize) -> Self

Sets the tab index for the toggle button group. The tab index is set to the initial value provided, then the value is incremented by the number of buttons in the group.