pub struct Vector { /* private fields */ }Expand description
A vector image, such as an SVG.
A Vector is different from an crate::Icon in that it is intended
to be displayed at a specific size, or series of sizes, rather
than conforming to the standard size of an icon.
Implementations
Sourceimpl Vector
impl Vector
Sourcepub fn new(vector: VectorName, width: Rems, height: Rems) -> Self
pub fn new(vector: VectorName, width: Rems, height: Rems) -> Self
Creates a new Vector image with the given VectorName and size.
Sourcepub fn square(vector: VectorName, size: Rems) -> Self
pub fn square(vector: VectorName, size: Rems) -> Self
Creates a new Vector image where the width and height are the same.