pub fn bindings() -> Vec<KeyBinding>Expand description
The palette’s navigation keymap, as data, so an app can have it without having to
take it — see crate::keys for layering over it or taking a chord
away.
pub fn bindings() -> Vec<KeyBinding>The palette’s navigation keymap, as data, so an app can have it without having to
take it — see crate::keys for layering over it or taking a chord
away.