pub trait FixedWidth {
// Required methods
fn width(self, width: impl Into<DefiniteLength>) -> Self;
fn full_width(self) -> Self;
}Expand description
A trait for elements that can have a fixed with. Enables the use of the width and full_width methods.
Required Methods
Sourcefn width(self, width: impl Into<DefiniteLength>) -> Self
fn width(self, width: impl Into<DefiniteLength>) -> Self
Sets the width of the element.
Sourcefn full_width(self) -> Self
fn full_width(self) -> Self
Sets the element’s width to the full width of its container.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".