pub struct Facepile { /* private fields */ }Expand description
An element that displays a collection of (usually) faces stacked horizontally, with the left-most face on top, visually descending from left to right.
Facepiles are used to display a group of people or things, such as a list of participants in a collaboration session.
Examples
Default
A default, horizontal facepile.
use gpui::IntoElement;
use ui::{Avatar, Facepile, EXAMPLE_FACES};
let facepile = Facepile::new(
EXAMPLE_FACES.iter().take(3).map(|&url|
Avatar::new(url).into_any_element()).collect()
);Implementations
Sourceimpl Facepile
impl Facepile
Sourcepub fn new(faces: SmallVec<[AnyElement; 2]>) -> Self
pub fn new(faces: SmallVec<[AnyElement; 2]>) -> Self
Creates a new facepile with the given faces.
Sourcepub fn max_visible(self, max: usize) -> Self
pub fn max_visible(self, max: usize) -> Self
Caps the number of visible faces, replacing the rest with a +N
overflow indicator.
Sourceimpl Facepile
impl Facepile
Sourcepub fn p(self, length: impl Clone + Into<DefiniteLength>) -> Self
pub fn p(self, length: impl Clone + Into<DefiniteLength>) -> Self
Sets the padding of the element. Docs
Sourcepub fn p_neg_full(self) -> Self
pub fn p_neg_full(self) -> Self
Sets the padding of the element. Docs
100%
Sourcepub fn p_neg_1_12(self) -> Self
pub fn p_neg_1_12(self) -> Self
Sets the padding of the element. Docs
8% (1/12)
Sourcepub fn pt(self, length: impl Clone + Into<DefiniteLength>) -> Self
pub fn pt(self, length: impl Clone + Into<DefiniteLength>) -> Self
Sets the top padding of the element. Docs
Sourcepub fn pt_neg_0p5(self) -> Self
pub fn pt_neg_0p5(self) -> Self
Sets the top padding of the element. Docs
2px (0.125rem)
Sourcepub fn pt_neg_1p5(self) -> Self
pub fn pt_neg_1p5(self) -> Self
Sets the top padding of the element. Docs
6px (0.375rem)
Sourcepub fn pt_neg_2p5(self) -> Self
pub fn pt_neg_2p5(self) -> Self
Sets the top padding of the element. Docs
10px (0.625rem)
Sourcepub fn pt_neg_3p5(self) -> Self
pub fn pt_neg_3p5(self) -> Self
Sets the top padding of the element. Docs
14px (0.875rem)
Sourcepub fn pt_neg_112(self) -> Self
pub fn pt_neg_112(self) -> Self
Sets the top padding of the element. Docs
448px (28rem)
Sourcepub fn pt_neg_128(self) -> Self
pub fn pt_neg_128(self) -> Self
Sets the top padding of the element. Docs
512px (32rem)
Sourcepub fn pt_neg_full(self) -> Self
pub fn pt_neg_full(self) -> Self
Sets the top padding of the element. Docs
100%
Sourcepub fn pt_neg_1_2(self) -> Self
pub fn pt_neg_1_2(self) -> Self
Sets the top padding of the element. Docs
50% (1/2)
Sourcepub fn pt_neg_1_3(self) -> Self
pub fn pt_neg_1_3(self) -> Self
Sets the top padding of the element. Docs
33% (1/3)
Sourcepub fn pt_neg_2_3(self) -> Self
pub fn pt_neg_2_3(self) -> Self
Sets the top padding of the element. Docs
66% (2/3)
Sourcepub fn pt_neg_1_4(self) -> Self
pub fn pt_neg_1_4(self) -> Self
Sets the top padding of the element. Docs
25% (1/4)
Sourcepub fn pt_neg_2_4(self) -> Self
pub fn pt_neg_2_4(self) -> Self
Sets the top padding of the element. Docs
50% (2/4)
Sourcepub fn pt_neg_3_4(self) -> Self
pub fn pt_neg_3_4(self) -> Self
Sets the top padding of the element. Docs
75% (3/4)
Sourcepub fn pt_neg_1_5(self) -> Self
pub fn pt_neg_1_5(self) -> Self
Sets the top padding of the element. Docs
20% (1/5)
Sourcepub fn pt_neg_2_5(self) -> Self
pub fn pt_neg_2_5(self) -> Self
Sets the top padding of the element. Docs
40% (2/5)
Sourcepub fn pt_neg_3_5(self) -> Self
pub fn pt_neg_3_5(self) -> Self
Sets the top padding of the element. Docs
60% (3/5)
Sourcepub fn pt_neg_4_5(self) -> Self
pub fn pt_neg_4_5(self) -> Self
Sets the top padding of the element. Docs
80% (4/5)
Sourcepub fn pt_neg_1_6(self) -> Self
pub fn pt_neg_1_6(self) -> Self
Sets the top padding of the element. Docs
16% (1/6)
Sourcepub fn pt_neg_5_6(self) -> Self
pub fn pt_neg_5_6(self) -> Self
Sets the top padding of the element. Docs
80% (5/6)
Sourcepub fn pt_neg_1_12(self) -> Self
pub fn pt_neg_1_12(self) -> Self
Sets the top padding of the element. Docs
8% (1/12)
Sourcepub fn pb(self, length: impl Clone + Into<DefiniteLength>) -> Self
pub fn pb(self, length: impl Clone + Into<DefiniteLength>) -> Self
Sets the bottom padding of the element. Docs
Sourcepub fn pb_neg_0p5(self) -> Self
pub fn pb_neg_0p5(self) -> Self
Sets the bottom padding of the element. Docs
2px (0.125rem)
Sourcepub fn pb_neg_1p5(self) -> Self
pub fn pb_neg_1p5(self) -> Self
Sets the bottom padding of the element. Docs
6px (0.375rem)
Sourcepub fn pb_neg_2p5(self) -> Self
pub fn pb_neg_2p5(self) -> Self
Sets the bottom padding of the element. Docs
10px (0.625rem)
Sourcepub fn pb_neg_3p5(self) -> Self
pub fn pb_neg_3p5(self) -> Self
Sets the bottom padding of the element. Docs
14px (0.875rem)
Sourcepub fn pb_neg_112(self) -> Self
pub fn pb_neg_112(self) -> Self
Sets the bottom padding of the element. Docs
448px (28rem)
Sourcepub fn pb_neg_128(self) -> Self
pub fn pb_neg_128(self) -> Self
Sets the bottom padding of the element. Docs
512px (32rem)
Sourcepub fn pb_neg_full(self) -> Self
pub fn pb_neg_full(self) -> Self
Sets the bottom padding of the element. Docs
100%
Sourcepub fn pb_neg_1_2(self) -> Self
pub fn pb_neg_1_2(self) -> Self
Sets the bottom padding of the element. Docs
50% (1/2)
Sourcepub fn pb_neg_1_3(self) -> Self
pub fn pb_neg_1_3(self) -> Self
Sets the bottom padding of the element. Docs
33% (1/3)
Sourcepub fn pb_neg_2_3(self) -> Self
pub fn pb_neg_2_3(self) -> Self
Sets the bottom padding of the element. Docs
66% (2/3)
Sourcepub fn pb_neg_1_4(self) -> Self
pub fn pb_neg_1_4(self) -> Self
Sets the bottom padding of the element. Docs
25% (1/4)
Sourcepub fn pb_neg_2_4(self) -> Self
pub fn pb_neg_2_4(self) -> Self
Sets the bottom padding of the element. Docs
50% (2/4)
Sourcepub fn pb_neg_3_4(self) -> Self
pub fn pb_neg_3_4(self) -> Self
Sets the bottom padding of the element. Docs
75% (3/4)
Sourcepub fn pb_neg_1_5(self) -> Self
pub fn pb_neg_1_5(self) -> Self
Sets the bottom padding of the element. Docs
20% (1/5)
Sourcepub fn pb_neg_2_5(self) -> Self
pub fn pb_neg_2_5(self) -> Self
Sets the bottom padding of the element. Docs
40% (2/5)
Sourcepub fn pb_neg_3_5(self) -> Self
pub fn pb_neg_3_5(self) -> Self
Sets the bottom padding of the element. Docs
60% (3/5)
Sourcepub fn pb_neg_4_5(self) -> Self
pub fn pb_neg_4_5(self) -> Self
Sets the bottom padding of the element. Docs
80% (4/5)
Sourcepub fn pb_neg_1_6(self) -> Self
pub fn pb_neg_1_6(self) -> Self
Sets the bottom padding of the element. Docs
16% (1/6)
Sourcepub fn pb_neg_5_6(self) -> Self
pub fn pb_neg_5_6(self) -> Self
Sets the bottom padding of the element. Docs
80% (5/6)
Sourcepub fn pb_neg_1_12(self) -> Self
pub fn pb_neg_1_12(self) -> Self
Sets the bottom padding of the element. Docs
8% (1/12)
Sourcepub fn px(self, length: impl Clone + Into<DefiniteLength>) -> Self
pub fn px(self, length: impl Clone + Into<DefiniteLength>) -> Self
Sets the horizontal padding of the element. Docs
Sourcepub fn px_neg_0p5(self) -> Self
pub fn px_neg_0p5(self) -> Self
Sets the horizontal padding of the element. Docs
2px (0.125rem)
Sourcepub fn px_neg_1p5(self) -> Self
pub fn px_neg_1p5(self) -> Self
Sets the horizontal padding of the element. Docs
6px (0.375rem)
Sourcepub fn px_neg_2p5(self) -> Self
pub fn px_neg_2p5(self) -> Self
Sets the horizontal padding of the element. Docs
10px (0.625rem)
Sourcepub fn px_neg_3p5(self) -> Self
pub fn px_neg_3p5(self) -> Self
Sets the horizontal padding of the element. Docs
14px (0.875rem)
Sourcepub fn px_neg_112(self) -> Self
pub fn px_neg_112(self) -> Self
Sets the horizontal padding of the element. Docs
448px (28rem)
Sourcepub fn px_neg_128(self) -> Self
pub fn px_neg_128(self) -> Self
Sets the horizontal padding of the element. Docs
512px (32rem)
Sourcepub fn px_neg_full(self) -> Self
pub fn px_neg_full(self) -> Self
Sets the horizontal padding of the element. Docs
100%
Sourcepub fn px_neg_1_2(self) -> Self
pub fn px_neg_1_2(self) -> Self
Sets the horizontal padding of the element. Docs
50% (1/2)
Sourcepub fn px_neg_1_3(self) -> Self
pub fn px_neg_1_3(self) -> Self
Sets the horizontal padding of the element. Docs
33% (1/3)
Sourcepub fn px_neg_2_3(self) -> Self
pub fn px_neg_2_3(self) -> Self
Sets the horizontal padding of the element. Docs
66% (2/3)
Sourcepub fn px_neg_1_4(self) -> Self
pub fn px_neg_1_4(self) -> Self
Sets the horizontal padding of the element. Docs
25% (1/4)
Sourcepub fn px_neg_2_4(self) -> Self
pub fn px_neg_2_4(self) -> Self
Sets the horizontal padding of the element. Docs
50% (2/4)
Sourcepub fn px_neg_3_4(self) -> Self
pub fn px_neg_3_4(self) -> Self
Sets the horizontal padding of the element. Docs
75% (3/4)
Sourcepub fn px_neg_1_5(self) -> Self
pub fn px_neg_1_5(self) -> Self
Sets the horizontal padding of the element. Docs
20% (1/5)
Sourcepub fn px_neg_2_5(self) -> Self
pub fn px_neg_2_5(self) -> Self
Sets the horizontal padding of the element. Docs
40% (2/5)
Sourcepub fn px_neg_3_5(self) -> Self
pub fn px_neg_3_5(self) -> Self
Sets the horizontal padding of the element. Docs
60% (3/5)
Sourcepub fn px_neg_4_5(self) -> Self
pub fn px_neg_4_5(self) -> Self
Sets the horizontal padding of the element. Docs
80% (4/5)
Sourcepub fn px_neg_1_6(self) -> Self
pub fn px_neg_1_6(self) -> Self
Sets the horizontal padding of the element. Docs
16% (1/6)
Sourcepub fn px_neg_5_6(self) -> Self
pub fn px_neg_5_6(self) -> Self
Sets the horizontal padding of the element. Docs
80% (5/6)
Sourcepub fn px_neg_1_12(self) -> Self
pub fn px_neg_1_12(self) -> Self
Sets the horizontal padding of the element. Docs
8% (1/12)
Sourcepub fn py(self, length: impl Clone + Into<DefiniteLength>) -> Self
pub fn py(self, length: impl Clone + Into<DefiniteLength>) -> Self
Sets the vertical padding of the element. Docs
Sourcepub fn py_neg_0p5(self) -> Self
pub fn py_neg_0p5(self) -> Self
Sets the vertical padding of the element. Docs
2px (0.125rem)
Sourcepub fn py_neg_1p5(self) -> Self
pub fn py_neg_1p5(self) -> Self
Sets the vertical padding of the element. Docs
6px (0.375rem)
Sourcepub fn py_neg_2p5(self) -> Self
pub fn py_neg_2p5(self) -> Self
Sets the vertical padding of the element. Docs
10px (0.625rem)
Sourcepub fn py_neg_3p5(self) -> Self
pub fn py_neg_3p5(self) -> Self
Sets the vertical padding of the element. Docs
14px (0.875rem)
Sourcepub fn py_neg_112(self) -> Self
pub fn py_neg_112(self) -> Self
Sets the vertical padding of the element. Docs
448px (28rem)
Sourcepub fn py_neg_128(self) -> Self
pub fn py_neg_128(self) -> Self
Sets the vertical padding of the element. Docs
512px (32rem)
Sourcepub fn py_neg_full(self) -> Self
pub fn py_neg_full(self) -> Self
Sets the vertical padding of the element. Docs
100%
Sourcepub fn py_neg_1_2(self) -> Self
pub fn py_neg_1_2(self) -> Self
Sets the vertical padding of the element. Docs
50% (1/2)
Sourcepub fn py_neg_1_3(self) -> Self
pub fn py_neg_1_3(self) -> Self
Sets the vertical padding of the element. Docs
33% (1/3)
Sourcepub fn py_neg_2_3(self) -> Self
pub fn py_neg_2_3(self) -> Self
Sets the vertical padding of the element. Docs
66% (2/3)
Sourcepub fn py_neg_1_4(self) -> Self
pub fn py_neg_1_4(self) -> Self
Sets the vertical padding of the element. Docs
25% (1/4)
Sourcepub fn py_neg_2_4(self) -> Self
pub fn py_neg_2_4(self) -> Self
Sets the vertical padding of the element. Docs
50% (2/4)
Sourcepub fn py_neg_3_4(self) -> Self
pub fn py_neg_3_4(self) -> Self
Sets the vertical padding of the element. Docs
75% (3/4)
Sourcepub fn py_neg_1_5(self) -> Self
pub fn py_neg_1_5(self) -> Self
Sets the vertical padding of the element. Docs
20% (1/5)
Sourcepub fn py_neg_2_5(self) -> Self
pub fn py_neg_2_5(self) -> Self
Sets the vertical padding of the element. Docs
40% (2/5)
Sourcepub fn py_neg_3_5(self) -> Self
pub fn py_neg_3_5(self) -> Self
Sets the vertical padding of the element. Docs
60% (3/5)
Sourcepub fn py_neg_4_5(self) -> Self
pub fn py_neg_4_5(self) -> Self
Sets the vertical padding of the element. Docs
80% (4/5)
Sourcepub fn py_neg_1_6(self) -> Self
pub fn py_neg_1_6(self) -> Self
Sets the vertical padding of the element. Docs
16% (1/6)
Sourcepub fn py_neg_5_6(self) -> Self
pub fn py_neg_5_6(self) -> Self
Sets the vertical padding of the element. Docs
80% (5/6)
Sourcepub fn py_neg_1_12(self) -> Self
pub fn py_neg_1_12(self) -> Self
Sets the vertical padding of the element. Docs
8% (1/12)
Sourcepub fn pl(self, length: impl Clone + Into<DefiniteLength>) -> Self
pub fn pl(self, length: impl Clone + Into<DefiniteLength>) -> Self
Sets the left padding of the element. Docs
Sourcepub fn pl_neg_0p5(self) -> Self
pub fn pl_neg_0p5(self) -> Self
Sets the left padding of the element. Docs
2px (0.125rem)
Sourcepub fn pl_neg_1p5(self) -> Self
pub fn pl_neg_1p5(self) -> Self
Sets the left padding of the element. Docs
6px (0.375rem)
Sourcepub fn pl_neg_2p5(self) -> Self
pub fn pl_neg_2p5(self) -> Self
Sets the left padding of the element. Docs
10px (0.625rem)
Sourcepub fn pl_neg_3p5(self) -> Self
pub fn pl_neg_3p5(self) -> Self
Sets the left padding of the element. Docs
14px (0.875rem)
Sourcepub fn pl_neg_112(self) -> Self
pub fn pl_neg_112(self) -> Self
Sets the left padding of the element. Docs
448px (28rem)
Sourcepub fn pl_neg_128(self) -> Self
pub fn pl_neg_128(self) -> Self
Sets the left padding of the element. Docs
512px (32rem)
Sourcepub fn pl_neg_full(self) -> Self
pub fn pl_neg_full(self) -> Self
Sets the left padding of the element. Docs
100%
Sourcepub fn pl_neg_1_2(self) -> Self
pub fn pl_neg_1_2(self) -> Self
Sets the left padding of the element. Docs
50% (1/2)
Sourcepub fn pl_neg_1_3(self) -> Self
pub fn pl_neg_1_3(self) -> Self
Sets the left padding of the element. Docs
33% (1/3)
Sourcepub fn pl_neg_2_3(self) -> Self
pub fn pl_neg_2_3(self) -> Self
Sets the left padding of the element. Docs
66% (2/3)
Sourcepub fn pl_neg_1_4(self) -> Self
pub fn pl_neg_1_4(self) -> Self
Sets the left padding of the element. Docs
25% (1/4)
Sourcepub fn pl_neg_2_4(self) -> Self
pub fn pl_neg_2_4(self) -> Self
Sets the left padding of the element. Docs
50% (2/4)
Sourcepub fn pl_neg_3_4(self) -> Self
pub fn pl_neg_3_4(self) -> Self
Sets the left padding of the element. Docs
75% (3/4)
Sourcepub fn pl_neg_1_5(self) -> Self
pub fn pl_neg_1_5(self) -> Self
Sets the left padding of the element. Docs
20% (1/5)
Sourcepub fn pl_neg_2_5(self) -> Self
pub fn pl_neg_2_5(self) -> Self
Sets the left padding of the element. Docs
40% (2/5)
Sourcepub fn pl_neg_3_5(self) -> Self
pub fn pl_neg_3_5(self) -> Self
Sets the left padding of the element. Docs
60% (3/5)
Sourcepub fn pl_neg_4_5(self) -> Self
pub fn pl_neg_4_5(self) -> Self
Sets the left padding of the element. Docs
80% (4/5)
Sourcepub fn pl_neg_1_6(self) -> Self
pub fn pl_neg_1_6(self) -> Self
Sets the left padding of the element. Docs
16% (1/6)
Sourcepub fn pl_neg_5_6(self) -> Self
pub fn pl_neg_5_6(self) -> Self
Sets the left padding of the element. Docs
80% (5/6)
Sourcepub fn pl_neg_1_12(self) -> Self
pub fn pl_neg_1_12(self) -> Self
Sets the left padding of the element. Docs
8% (1/12)
Sourcepub fn pr(self, length: impl Clone + Into<DefiniteLength>) -> Self
pub fn pr(self, length: impl Clone + Into<DefiniteLength>) -> Self
Sets the right padding of the element. Docs
Sourcepub fn pr_neg_0p5(self) -> Self
pub fn pr_neg_0p5(self) -> Self
Sets the right padding of the element. Docs
2px (0.125rem)
Sourcepub fn pr_neg_1p5(self) -> Self
pub fn pr_neg_1p5(self) -> Self
Sets the right padding of the element. Docs
6px (0.375rem)
Sourcepub fn pr_neg_2p5(self) -> Self
pub fn pr_neg_2p5(self) -> Self
Sets the right padding of the element. Docs
10px (0.625rem)
Sourcepub fn pr_neg_3p5(self) -> Self
pub fn pr_neg_3p5(self) -> Self
Sets the right padding of the element. Docs
14px (0.875rem)
Sourcepub fn pr_neg_112(self) -> Self
pub fn pr_neg_112(self) -> Self
Sets the right padding of the element. Docs
448px (28rem)
Sourcepub fn pr_neg_128(self) -> Self
pub fn pr_neg_128(self) -> Self
Sets the right padding of the element. Docs
512px (32rem)
Sourcepub fn pr_neg_full(self) -> Self
pub fn pr_neg_full(self) -> Self
Sets the right padding of the element. Docs
100%
Sourcepub fn pr_neg_1_2(self) -> Self
pub fn pr_neg_1_2(self) -> Self
Sets the right padding of the element. Docs
50% (1/2)
Sourcepub fn pr_neg_1_3(self) -> Self
pub fn pr_neg_1_3(self) -> Self
Sets the right padding of the element. Docs
33% (1/3)
Sourcepub fn pr_neg_2_3(self) -> Self
pub fn pr_neg_2_3(self) -> Self
Sets the right padding of the element. Docs
66% (2/3)
Sourcepub fn pr_neg_1_4(self) -> Self
pub fn pr_neg_1_4(self) -> Self
Sets the right padding of the element. Docs
25% (1/4)
Sourcepub fn pr_neg_2_4(self) -> Self
pub fn pr_neg_2_4(self) -> Self
Sets the right padding of the element. Docs
50% (2/4)
Sourcepub fn pr_neg_3_4(self) -> Self
pub fn pr_neg_3_4(self) -> Self
Sets the right padding of the element. Docs
75% (3/4)
Sourcepub fn pr_neg_1_5(self) -> Self
pub fn pr_neg_1_5(self) -> Self
Sets the right padding of the element. Docs
20% (1/5)
Sourcepub fn pr_neg_2_5(self) -> Self
pub fn pr_neg_2_5(self) -> Self
Sets the right padding of the element. Docs
40% (2/5)
Sourcepub fn pr_neg_3_5(self) -> Self
pub fn pr_neg_3_5(self) -> Self
Sets the right padding of the element. Docs
60% (3/5)
Sourcepub fn pr_neg_4_5(self) -> Self
pub fn pr_neg_4_5(self) -> Self
Sets the right padding of the element. Docs
80% (4/5)
Sourcepub fn pr_neg_1_6(self) -> Self
pub fn pr_neg_1_6(self) -> Self
Sets the right padding of the element. Docs
16% (1/6)
Sourcepub fn pr_neg_5_6(self) -> Self
pub fn pr_neg_5_6(self) -> Self
Sets the right padding of the element. Docs
80% (5/6)
Sourcepub fn pr_neg_1_12(self) -> Self
pub fn pr_neg_1_12(self) -> Self
Sets the right padding of the element. Docs
8% (1/12)