pub struct IndentGuides { /* private fields */ }Implementations
Sourceimpl IndentGuides
impl IndentGuides
Sourcepub fn on_click(
self,
on_click: impl Fn(&IndentGuideLayout, &mut Window, &mut App) + 'static,
) -> Self
pub fn on_click( self, on_click: impl Fn(&IndentGuideLayout, &mut Window, &mut App) + 'static, ) -> Self
Sets the callback that will be called when the user clicks on an indent guide.
Sourcepub fn with_compute_indents_fn<V: Render>(
self,
entity: Entity<V>,
compute_indents_fn: impl Fn(&mut V, Range<usize>, &mut Window, &mut Context<'_, V>) -> SmallVec<[usize; 64]> + 'static,
) -> Self
pub fn with_compute_indents_fn<V: Render>( self, entity: Entity<V>, compute_indents_fn: impl Fn(&mut V, Range<usize>, &mut Window, &mut Context<'_, V>) -> SmallVec<[usize; 64]> + 'static, ) -> Self
Sets the function that computes indents for uniform list decoration.
Sourcepub fn with_render_fn<V: Render>(
self,
entity: Entity<V>,
render_fn: impl Fn(&mut V, RenderIndentGuideParams, &mut Window, &mut App) -> SmallVec<[RenderedIndentGuide; 12]> + 'static,
) -> Self
pub fn with_render_fn<V: Render>( self, entity: Entity<V>, render_fn: impl Fn(&mut V, RenderIndentGuideParams, &mut Window, &mut App) -> SmallVec<[RenderedIndentGuide; 12]> + 'static, ) -> Self
Sets a custom callback that will be called when the indent guides need to be rendered.