pub struct Label { /* private fields */ }Expand description
A struct representing a label element in the UI.
The Label struct stores the label text and common properties for a label element.
It provides methods for modifying these properties.
Examples
use ui::prelude::*;
Label::new("Hello, World!");A colored label, for example labeling a dangerous action:
use ui::prelude::*;
let my_label = Label::new("Delete").color(Color::Error);A label with a strikethrough, for example labeling something that has been deleted:
use ui::prelude::*;
let my_label = Label::new("Deleted").strikethrough();Implementations
Sourceimpl Label
impl Label
Sourcepub fn new(label: impl Into<SharedString>) -> Self
pub fn new(label: impl Into<SharedString>) -> Self
Sourcepub fn render_code_spans(self) -> Self
pub fn render_code_spans(self) -> Self
When enabled, text wrapped in backticks (e.g. `code`) will be
rendered in the buffer (monospace) font.
Sourcepub fn set_text(&mut self, text: impl Into<SharedString>)
pub fn set_text(&mut self, text: impl Into<SharedString>)
Sets the text of the Label.
Sourcepub fn truncate_start(self) -> Self
pub fn truncate_start(self) -> Self
Truncates the label from the start, keeping the end visible.
Sourceimpl Label
impl Label
Sourcepub fn m_neg_full(self) -> Self
pub fn m_neg_full(self) -> Self
Sets the margin of the element. Docs
100%
Sourcepub fn m_neg_1_12(self) -> Self
pub fn m_neg_1_12(self) -> Self
Sets the margin of the element. Docs
8% (1/12)
Sourcepub fn mt(self, length: impl Clone + Into<Length>) -> Self
pub fn mt(self, length: impl Clone + Into<Length>) -> Self
Sets the top margin of the element. Docs
Sourcepub fn mt_neg_0p5(self) -> Self
pub fn mt_neg_0p5(self) -> Self
Sets the top margin of the element. Docs
2px (0.125rem)
Sourcepub fn mt_neg_1p5(self) -> Self
pub fn mt_neg_1p5(self) -> Self
Sets the top margin of the element. Docs
6px (0.375rem)
Sourcepub fn mt_neg_2p5(self) -> Self
pub fn mt_neg_2p5(self) -> Self
Sets the top margin of the element. Docs
10px (0.625rem)
Sourcepub fn mt_neg_3p5(self) -> Self
pub fn mt_neg_3p5(self) -> Self
Sets the top margin of the element. Docs
14px (0.875rem)
Sourcepub fn mt_neg_112(self) -> Self
pub fn mt_neg_112(self) -> Self
Sets the top margin of the element. Docs
448px (28rem)
Sourcepub fn mt_neg_128(self) -> Self
pub fn mt_neg_128(self) -> Self
Sets the top margin of the element. Docs
512px (32rem)
Sourcepub fn mt_neg_full(self) -> Self
pub fn mt_neg_full(self) -> Self
Sets the top margin of the element. Docs
100%
Sourcepub fn mt_neg_1_2(self) -> Self
pub fn mt_neg_1_2(self) -> Self
Sets the top margin of the element. Docs
50% (1/2)
Sourcepub fn mt_neg_1_3(self) -> Self
pub fn mt_neg_1_3(self) -> Self
Sets the top margin of the element. Docs
33% (1/3)
Sourcepub fn mt_neg_2_3(self) -> Self
pub fn mt_neg_2_3(self) -> Self
Sets the top margin of the element. Docs
66% (2/3)
Sourcepub fn mt_neg_1_4(self) -> Self
pub fn mt_neg_1_4(self) -> Self
Sets the top margin of the element. Docs
25% (1/4)
Sourcepub fn mt_neg_2_4(self) -> Self
pub fn mt_neg_2_4(self) -> Self
Sets the top margin of the element. Docs
50% (2/4)
Sourcepub fn mt_neg_3_4(self) -> Self
pub fn mt_neg_3_4(self) -> Self
Sets the top margin of the element. Docs
75% (3/4)
Sourcepub fn mt_neg_1_5(self) -> Self
pub fn mt_neg_1_5(self) -> Self
Sets the top margin of the element. Docs
20% (1/5)
Sourcepub fn mt_neg_2_5(self) -> Self
pub fn mt_neg_2_5(self) -> Self
Sets the top margin of the element. Docs
40% (2/5)
Sourcepub fn mt_neg_3_5(self) -> Self
pub fn mt_neg_3_5(self) -> Self
Sets the top margin of the element. Docs
60% (3/5)
Sourcepub fn mt_neg_4_5(self) -> Self
pub fn mt_neg_4_5(self) -> Self
Sets the top margin of the element. Docs
80% (4/5)
Sourcepub fn mt_neg_1_6(self) -> Self
pub fn mt_neg_1_6(self) -> Self
Sets the top margin of the element. Docs
16% (1/6)
Sourcepub fn mt_neg_5_6(self) -> Self
pub fn mt_neg_5_6(self) -> Self
Sets the top margin of the element. Docs
80% (5/6)
Sourcepub fn mt_neg_1_12(self) -> Self
pub fn mt_neg_1_12(self) -> Self
Sets the top margin of the element. Docs
8% (1/12)
Sourcepub fn mb(self, length: impl Clone + Into<Length>) -> Self
pub fn mb(self, length: impl Clone + Into<Length>) -> Self
Sets the bottom margin of the element. Docs
Sourcepub fn mb_neg_0p5(self) -> Self
pub fn mb_neg_0p5(self) -> Self
Sets the bottom margin of the element. Docs
2px (0.125rem)
Sourcepub fn mb_neg_1p5(self) -> Self
pub fn mb_neg_1p5(self) -> Self
Sets the bottom margin of the element. Docs
6px (0.375rem)
Sourcepub fn mb_neg_2p5(self) -> Self
pub fn mb_neg_2p5(self) -> Self
Sets the bottom margin of the element. Docs
10px (0.625rem)
Sourcepub fn mb_neg_3p5(self) -> Self
pub fn mb_neg_3p5(self) -> Self
Sets the bottom margin of the element. Docs
14px (0.875rem)
Sourcepub fn mb_neg_112(self) -> Self
pub fn mb_neg_112(self) -> Self
Sets the bottom margin of the element. Docs
448px (28rem)
Sourcepub fn mb_neg_128(self) -> Self
pub fn mb_neg_128(self) -> Self
Sets the bottom margin of the element. Docs
512px (32rem)
Sourcepub fn mb_neg_full(self) -> Self
pub fn mb_neg_full(self) -> Self
Sets the bottom margin of the element. Docs
100%
Sourcepub fn mb_neg_1_2(self) -> Self
pub fn mb_neg_1_2(self) -> Self
Sets the bottom margin of the element. Docs
50% (1/2)
Sourcepub fn mb_neg_1_3(self) -> Self
pub fn mb_neg_1_3(self) -> Self
Sets the bottom margin of the element. Docs
33% (1/3)
Sourcepub fn mb_neg_2_3(self) -> Self
pub fn mb_neg_2_3(self) -> Self
Sets the bottom margin of the element. Docs
66% (2/3)
Sourcepub fn mb_neg_1_4(self) -> Self
pub fn mb_neg_1_4(self) -> Self
Sets the bottom margin of the element. Docs
25% (1/4)
Sourcepub fn mb_neg_2_4(self) -> Self
pub fn mb_neg_2_4(self) -> Self
Sets the bottom margin of the element. Docs
50% (2/4)
Sourcepub fn mb_neg_3_4(self) -> Self
pub fn mb_neg_3_4(self) -> Self
Sets the bottom margin of the element. Docs
75% (3/4)
Sourcepub fn mb_neg_1_5(self) -> Self
pub fn mb_neg_1_5(self) -> Self
Sets the bottom margin of the element. Docs
20% (1/5)
Sourcepub fn mb_neg_2_5(self) -> Self
pub fn mb_neg_2_5(self) -> Self
Sets the bottom margin of the element. Docs
40% (2/5)
Sourcepub fn mb_neg_3_5(self) -> Self
pub fn mb_neg_3_5(self) -> Self
Sets the bottom margin of the element. Docs
60% (3/5)
Sourcepub fn mb_neg_4_5(self) -> Self
pub fn mb_neg_4_5(self) -> Self
Sets the bottom margin of the element. Docs
80% (4/5)
Sourcepub fn mb_neg_1_6(self) -> Self
pub fn mb_neg_1_6(self) -> Self
Sets the bottom margin of the element. Docs
16% (1/6)
Sourcepub fn mb_neg_5_6(self) -> Self
pub fn mb_neg_5_6(self) -> Self
Sets the bottom margin of the element. Docs
80% (5/6)
Sourcepub fn mb_neg_1_12(self) -> Self
pub fn mb_neg_1_12(self) -> Self
Sets the bottom margin of the element. Docs
8% (1/12)
Sourcepub fn my(self, length: impl Clone + Into<Length>) -> Self
pub fn my(self, length: impl Clone + Into<Length>) -> Self
Sets the vertical margin of the element. Docs
Sourcepub fn my_neg_0p5(self) -> Self
pub fn my_neg_0p5(self) -> Self
Sets the vertical margin of the element. Docs
2px (0.125rem)
Sourcepub fn my_neg_1p5(self) -> Self
pub fn my_neg_1p5(self) -> Self
Sets the vertical margin of the element. Docs
6px (0.375rem)
Sourcepub fn my_neg_2p5(self) -> Self
pub fn my_neg_2p5(self) -> Self
Sets the vertical margin of the element. Docs
10px (0.625rem)
Sourcepub fn my_neg_3p5(self) -> Self
pub fn my_neg_3p5(self) -> Self
Sets the vertical margin of the element. Docs
14px (0.875rem)
Sourcepub fn my_neg_112(self) -> Self
pub fn my_neg_112(self) -> Self
Sets the vertical margin of the element. Docs
448px (28rem)
Sourcepub fn my_neg_128(self) -> Self
pub fn my_neg_128(self) -> Self
Sets the vertical margin of the element. Docs
512px (32rem)
Sourcepub fn my_neg_full(self) -> Self
pub fn my_neg_full(self) -> Self
Sets the vertical margin of the element. Docs
100%
Sourcepub fn my_neg_1_2(self) -> Self
pub fn my_neg_1_2(self) -> Self
Sets the vertical margin of the element. Docs
50% (1/2)
Sourcepub fn my_neg_1_3(self) -> Self
pub fn my_neg_1_3(self) -> Self
Sets the vertical margin of the element. Docs
33% (1/3)
Sourcepub fn my_neg_2_3(self) -> Self
pub fn my_neg_2_3(self) -> Self
Sets the vertical margin of the element. Docs
66% (2/3)
Sourcepub fn my_neg_1_4(self) -> Self
pub fn my_neg_1_4(self) -> Self
Sets the vertical margin of the element. Docs
25% (1/4)
Sourcepub fn my_neg_2_4(self) -> Self
pub fn my_neg_2_4(self) -> Self
Sets the vertical margin of the element. Docs
50% (2/4)
Sourcepub fn my_neg_3_4(self) -> Self
pub fn my_neg_3_4(self) -> Self
Sets the vertical margin of the element. Docs
75% (3/4)
Sourcepub fn my_neg_1_5(self) -> Self
pub fn my_neg_1_5(self) -> Self
Sets the vertical margin of the element. Docs
20% (1/5)
Sourcepub fn my_neg_2_5(self) -> Self
pub fn my_neg_2_5(self) -> Self
Sets the vertical margin of the element. Docs
40% (2/5)
Sourcepub fn my_neg_3_5(self) -> Self
pub fn my_neg_3_5(self) -> Self
Sets the vertical margin of the element. Docs
60% (3/5)
Sourcepub fn my_neg_4_5(self) -> Self
pub fn my_neg_4_5(self) -> Self
Sets the vertical margin of the element. Docs
80% (4/5)
Sourcepub fn my_neg_1_6(self) -> Self
pub fn my_neg_1_6(self) -> Self
Sets the vertical margin of the element. Docs
16% (1/6)
Sourcepub fn my_neg_5_6(self) -> Self
pub fn my_neg_5_6(self) -> Self
Sets the vertical margin of the element. Docs
80% (5/6)
Sourcepub fn my_neg_1_12(self) -> Self
pub fn my_neg_1_12(self) -> Self
Sets the vertical margin of the element. Docs
8% (1/12)
Sourcepub fn mx(self, length: impl Clone + Into<Length>) -> Self
pub fn mx(self, length: impl Clone + Into<Length>) -> Self
Sets the horizontal margin of the element. Docs
Sourcepub fn mx_neg_0p5(self) -> Self
pub fn mx_neg_0p5(self) -> Self
Sets the horizontal margin of the element. Docs
2px (0.125rem)
Sourcepub fn mx_neg_1p5(self) -> Self
pub fn mx_neg_1p5(self) -> Self
Sets the horizontal margin of the element. Docs
6px (0.375rem)
Sourcepub fn mx_neg_2p5(self) -> Self
pub fn mx_neg_2p5(self) -> Self
Sets the horizontal margin of the element. Docs
10px (0.625rem)
Sourcepub fn mx_neg_3p5(self) -> Self
pub fn mx_neg_3p5(self) -> Self
Sets the horizontal margin of the element. Docs
14px (0.875rem)
Sourcepub fn mx_neg_112(self) -> Self
pub fn mx_neg_112(self) -> Self
Sets the horizontal margin of the element. Docs
448px (28rem)
Sourcepub fn mx_neg_128(self) -> Self
pub fn mx_neg_128(self) -> Self
Sets the horizontal margin of the element. Docs
512px (32rem)
Sourcepub fn mx_neg_full(self) -> Self
pub fn mx_neg_full(self) -> Self
Sets the horizontal margin of the element. Docs
100%
Sourcepub fn mx_neg_1_2(self) -> Self
pub fn mx_neg_1_2(self) -> Self
Sets the horizontal margin of the element. Docs
50% (1/2)
Sourcepub fn mx_neg_1_3(self) -> Self
pub fn mx_neg_1_3(self) -> Self
Sets the horizontal margin of the element. Docs
33% (1/3)
Sourcepub fn mx_neg_2_3(self) -> Self
pub fn mx_neg_2_3(self) -> Self
Sets the horizontal margin of the element. Docs
66% (2/3)
Sourcepub fn mx_neg_1_4(self) -> Self
pub fn mx_neg_1_4(self) -> Self
Sets the horizontal margin of the element. Docs
25% (1/4)
Sourcepub fn mx_neg_2_4(self) -> Self
pub fn mx_neg_2_4(self) -> Self
Sets the horizontal margin of the element. Docs
50% (2/4)
Sourcepub fn mx_neg_3_4(self) -> Self
pub fn mx_neg_3_4(self) -> Self
Sets the horizontal margin of the element. Docs
75% (3/4)
Sourcepub fn mx_neg_1_5(self) -> Self
pub fn mx_neg_1_5(self) -> Self
Sets the horizontal margin of the element. Docs
20% (1/5)
Sourcepub fn mx_neg_2_5(self) -> Self
pub fn mx_neg_2_5(self) -> Self
Sets the horizontal margin of the element. Docs
40% (2/5)
Sourcepub fn mx_neg_3_5(self) -> Self
pub fn mx_neg_3_5(self) -> Self
Sets the horizontal margin of the element. Docs
60% (3/5)
Sourcepub fn mx_neg_4_5(self) -> Self
pub fn mx_neg_4_5(self) -> Self
Sets the horizontal margin of the element. Docs
80% (4/5)
Sourcepub fn mx_neg_1_6(self) -> Self
pub fn mx_neg_1_6(self) -> Self
Sets the horizontal margin of the element. Docs
16% (1/6)
Sourcepub fn mx_neg_5_6(self) -> Self
pub fn mx_neg_5_6(self) -> Self
Sets the horizontal margin of the element. Docs
80% (5/6)
Sourcepub fn mx_neg_1_12(self) -> Self
pub fn mx_neg_1_12(self) -> Self
Sets the horizontal margin of the element. Docs
8% (1/12)
Sourcepub fn ml(self, length: impl Clone + Into<Length>) -> Self
pub fn ml(self, length: impl Clone + Into<Length>) -> Self
Sets the left margin of the element. Docs
Sourcepub fn ml_neg_0p5(self) -> Self
pub fn ml_neg_0p5(self) -> Self
Sets the left margin of the element. Docs
2px (0.125rem)
Sourcepub fn ml_neg_1p5(self) -> Self
pub fn ml_neg_1p5(self) -> Self
Sets the left margin of the element. Docs
6px (0.375rem)
Sourcepub fn ml_neg_2p5(self) -> Self
pub fn ml_neg_2p5(self) -> Self
Sets the left margin of the element. Docs
10px (0.625rem)
Sourcepub fn ml_neg_3p5(self) -> Self
pub fn ml_neg_3p5(self) -> Self
Sets the left margin of the element. Docs
14px (0.875rem)
Sourcepub fn ml_neg_112(self) -> Self
pub fn ml_neg_112(self) -> Self
Sets the left margin of the element. Docs
448px (28rem)
Sourcepub fn ml_neg_128(self) -> Self
pub fn ml_neg_128(self) -> Self
Sets the left margin of the element. Docs
512px (32rem)
Sourcepub fn ml_neg_full(self) -> Self
pub fn ml_neg_full(self) -> Self
Sets the left margin of the element. Docs
100%
Sourcepub fn ml_neg_1_2(self) -> Self
pub fn ml_neg_1_2(self) -> Self
Sets the left margin of the element. Docs
50% (1/2)
Sourcepub fn ml_neg_1_3(self) -> Self
pub fn ml_neg_1_3(self) -> Self
Sets the left margin of the element. Docs
33% (1/3)
Sourcepub fn ml_neg_2_3(self) -> Self
pub fn ml_neg_2_3(self) -> Self
Sets the left margin of the element. Docs
66% (2/3)
Sourcepub fn ml_neg_1_4(self) -> Self
pub fn ml_neg_1_4(self) -> Self
Sets the left margin of the element. Docs
25% (1/4)
Sourcepub fn ml_neg_2_4(self) -> Self
pub fn ml_neg_2_4(self) -> Self
Sets the left margin of the element. Docs
50% (2/4)
Sourcepub fn ml_neg_3_4(self) -> Self
pub fn ml_neg_3_4(self) -> Self
Sets the left margin of the element. Docs
75% (3/4)
Sourcepub fn ml_neg_1_5(self) -> Self
pub fn ml_neg_1_5(self) -> Self
Sets the left margin of the element. Docs
20% (1/5)
Sourcepub fn ml_neg_2_5(self) -> Self
pub fn ml_neg_2_5(self) -> Self
Sets the left margin of the element. Docs
40% (2/5)
Sourcepub fn ml_neg_3_5(self) -> Self
pub fn ml_neg_3_5(self) -> Self
Sets the left margin of the element. Docs
60% (3/5)
Sourcepub fn ml_neg_4_5(self) -> Self
pub fn ml_neg_4_5(self) -> Self
Sets the left margin of the element. Docs
80% (4/5)
Sourcepub fn ml_neg_1_6(self) -> Self
pub fn ml_neg_1_6(self) -> Self
Sets the left margin of the element. Docs
16% (1/6)
Sourcepub fn ml_neg_5_6(self) -> Self
pub fn ml_neg_5_6(self) -> Self
Sets the left margin of the element. Docs
80% (5/6)
Sourcepub fn ml_neg_1_12(self) -> Self
pub fn ml_neg_1_12(self) -> Self
Sets the left margin of the element. Docs
8% (1/12)
Sourcepub fn mr(self, length: impl Clone + Into<Length>) -> Self
pub fn mr(self, length: impl Clone + Into<Length>) -> Self
Sets the right margin of the element. Docs
Sourcepub fn mr_neg_0p5(self) -> Self
pub fn mr_neg_0p5(self) -> Self
Sets the right margin of the element. Docs
2px (0.125rem)
Sourcepub fn mr_neg_1p5(self) -> Self
pub fn mr_neg_1p5(self) -> Self
Sets the right margin of the element. Docs
6px (0.375rem)
Sourcepub fn mr_neg_2p5(self) -> Self
pub fn mr_neg_2p5(self) -> Self
Sets the right margin of the element. Docs
10px (0.625rem)
Sourcepub fn mr_neg_3p5(self) -> Self
pub fn mr_neg_3p5(self) -> Self
Sets the right margin of the element. Docs
14px (0.875rem)
Sourcepub fn mr_neg_112(self) -> Self
pub fn mr_neg_112(self) -> Self
Sets the right margin of the element. Docs
448px (28rem)
Sourcepub fn mr_neg_128(self) -> Self
pub fn mr_neg_128(self) -> Self
Sets the right margin of the element. Docs
512px (32rem)
Sourcepub fn mr_neg_full(self) -> Self
pub fn mr_neg_full(self) -> Self
Sets the right margin of the element. Docs
100%
Sourcepub fn mr_neg_1_2(self) -> Self
pub fn mr_neg_1_2(self) -> Self
Sets the right margin of the element. Docs
50% (1/2)
Sourcepub fn mr_neg_1_3(self) -> Self
pub fn mr_neg_1_3(self) -> Self
Sets the right margin of the element. Docs
33% (1/3)
Sourcepub fn mr_neg_2_3(self) -> Self
pub fn mr_neg_2_3(self) -> Self
Sets the right margin of the element. Docs
66% (2/3)
Sourcepub fn mr_neg_1_4(self) -> Self
pub fn mr_neg_1_4(self) -> Self
Sets the right margin of the element. Docs
25% (1/4)
Sourcepub fn mr_neg_2_4(self) -> Self
pub fn mr_neg_2_4(self) -> Self
Sets the right margin of the element. Docs
50% (2/4)
Sourcepub fn mr_neg_3_4(self) -> Self
pub fn mr_neg_3_4(self) -> Self
Sets the right margin of the element. Docs
75% (3/4)
Sourcepub fn mr_neg_1_5(self) -> Self
pub fn mr_neg_1_5(self) -> Self
Sets the right margin of the element. Docs
20% (1/5)
Sourcepub fn mr_neg_2_5(self) -> Self
pub fn mr_neg_2_5(self) -> Self
Sets the right margin of the element. Docs
40% (2/5)
Sourcepub fn mr_neg_3_5(self) -> Self
pub fn mr_neg_3_5(self) -> Self
Sets the right margin of the element. Docs
60% (3/5)
Sourcepub fn mr_neg_4_5(self) -> Self
pub fn mr_neg_4_5(self) -> Self
Sets the right margin of the element. Docs
80% (4/5)
Sourcepub fn mr_neg_1_6(self) -> Self
pub fn mr_neg_1_6(self) -> Self
Sets the right margin of the element. Docs
16% (1/6)
Sourcepub fn mr_neg_5_6(self) -> Self
pub fn mr_neg_5_6(self) -> Self
Sets the right margin of the element. Docs
80% (5/6)
Sourcepub fn mr_neg_1_12(self) -> Self
pub fn mr_neg_1_12(self) -> Self
Sets the right margin of the element. Docs
8% (1/12)
pub fn flex_1(self) -> Self
pub fn flex_none(self) -> Self
pub fn flex_grow(self) -> Self
pub fn flex_shrink(self) -> Self
pub fn flex_shrink_0(self) -> Self