pub struct Table { /* private fields */ }Expand description
A table component
Implementations
Sourceimpl Table
impl Table
Sourcepub fn disable_base_style(self) -> Self
pub fn disable_base_style(self) -> Self
Disables based styling of row cell (paddings, text ellipsis, nowrap, etc), keeping width settings
Doesn’t affect base style of header cell. Doesn’t remove overflow-hidden
Sourcepub fn uniform_list(
self,
id: impl Into<ElementId>,
row_count: usize,
render_item_fn: impl Fn(Range<usize>, &mut Window, &mut App) -> Vec<UncheckedTableRow<AnyElement>> + 'static,
) -> Self
pub fn uniform_list( self, id: impl Into<ElementId>, row_count: usize, render_item_fn: impl Fn(Range<usize>, &mut Window, &mut App) -> Vec<UncheckedTableRow<AnyElement>> + 'static, ) -> Self
Enables uniform list rendering.
The provided function will be passed directly to the uniform_list element.
Therefore, if this method is called, any calls to Table::row before or after
this method is called will be ignored.
Sourcepub fn variable_row_height_list(
self,
row_count: usize,
list_state: ListState,
render_row_fn: impl Fn(usize, &mut Window, &mut App) -> UncheckedTableRow<AnyElement> + 'static,
) -> Self
pub fn variable_row_height_list( self, row_count: usize, list_state: ListState, render_row_fn: impl Fn(usize, &mut Window, &mut App) -> UncheckedTableRow<AnyElement> + 'static, ) -> Self
Enables rendering of tables with variable row heights, allowing each row to have its own height.
This mode is useful for displaying content such as CSV data or multiline cells, where rows may not have uniform heights.
It is generally slower than Table::uniform_list due to the need to measure each row individually, but it provides correct layout for non-uniform or multiline content.
Parameters
row_count: The total number of rows in the table.list_state: TheListStateused for managing scroll position and virtualization. This must be initialized and managed by the caller, and should be kept in sync with the number of rows.render_row_fn: A closure that renders a single row, given the row index, a mutable reference toWindow, and a mutable reference toApp. It should return an array ofAnyElements, one for each column.
Sourcepub fn hide_row_borders(self) -> Self
pub fn hide_row_borders(self) -> Self
Hides the border lines between rows
Sourcepub fn width(self, width: impl Into<DefiniteLength>) -> Self
pub fn width(self, width: impl Into<DefiniteLength>) -> Self
Sets a fixed table width with auto column widths.
This is a shorthand for .width_config(ColumnWidthConfig::auto_with_table_width(width)).
For resizable columns or explicit column widths, use Table::width_config directly.
Sourcepub fn width_config(self, config: ColumnWidthConfig) -> Self
pub fn width_config(self, config: ColumnWidthConfig) -> Self
Sets the column width configuration for the table.
Sourcepub fn interactable(
self,
interaction_state: &Entity<TableInteractionState>,
) -> Self
pub fn interactable( self, interaction_state: &Entity<TableInteractionState>, ) -> Self
Enables interaction (primarily scrolling) with the table.
Vertical scrolling will be enabled by default if the table is taller than its container.
Horizontal scrolling will only be enabled if a table width is set via ColumnWidthConfig,
otherwise the list will always shrink the table columns to fit their contents.
pub fn header(self, headers: UncheckedTableRow<impl IntoElement>) -> Self
Sourcepub fn sortable_header(
self,
headers: UncheckedTableRow<impl Into<SharedString>>,
sort_column: Option<usize>,
direction: SortDirection,
on_sort: impl Fn(usize, &mut Window, &mut App) + 'static,
) -> Self
pub fn sortable_header( self, headers: UncheckedTableRow<impl Into<SharedString>>, sort_column: Option<usize>, direction: SortDirection, on_sort: impl Fn(usize, &mut Window, &mut App) + 'static, ) -> Self
Renders a header row where every column is clickable and shows a sort
direction indicator (chevron up/down/up-down icon), calling on_sort
with the clicked column index.
sort_column (if set) marks which column currently drives the sort
and is rendered with a direction-specific chevron
(SortDirection::Ascending/SortDirection::Descending); all
other columns show a neutral up/down chevron. This is purely additive
to Table::header — existing callers that use .header(...) are
unaffected.
pub fn row(self, items: UncheckedTableRow<impl IntoElement>) -> Self
pub fn no_ui_font(self) -> Self
pub fn map_row( self, callback: impl Fn((usize, Stateful<Div>), &mut Window, &mut App) -> AnyElement + 'static, ) -> Self
Sourcepub fn hide_row_hover(self) -> Self
pub fn hide_row_hover(self) -> Self
Hides the default hover background on table rows.
Use this when you want to handle row hover styling manually via map_row.
Sourcepub fn empty_table_callback(
self,
callback: impl Fn(&mut Window, &mut App) -> AnyElement + 'static,
) -> Self
pub fn empty_table_callback( self, callback: impl Fn(&mut Window, &mut App) -> AnyElement + 'static, ) -> Self
Provide a callback that is invoked when the table is rendered without any rows